@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -69,12 +69,35 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-static char *get_asm_algorithm_str(void)
+static char *
+get_asm_algorithm_str (void)
 {
   if (CONFIG_ASM_ALGORITHM)
-    return (lw_lang_string(LW_LANG_STRING_ADVANCED_YES));
+    return (lw_lang_string (LW_LANG_STRING_ADVANCED_YES));
   else
-    return (lw_lang_string(LW_LANG_STRING_ADVANCED_NO));
+    return (lw_lang_string (LW_LANG_STRING_ADVANCED_NO));
+}
+
+/*------------------------------------------------------------------*/
+static char *
+get_cpu_vs_human_str (void)
+{
+  char *result = "";
+
+  switch (CONFIG_CPU_VS_HUMAN)
+    {
+    case CONFIG_CPU_VS_HUMAN_ALWAYS:
+      result = (lw_lang_string (LW_LANG_STRING_ADVANCED_ALWAYS));
+      break;
+    case CONFIG_CPU_VS_HUMAN_NEVER:
+      result = (lw_lang_string (LW_LANG_STRING_ADVANCED_NEVER));
+      break;
+    default:
+      result = (lw_lang_string (LW_LANG_STRING_ADVANCED_RANDOM));
+      break;
+    }
+
+  return result;
 }
 
 /*==================================================================*/
@@ -82,94 +105,101 @@ static char *get_asm_algorithm_str(void)
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int advanced_options (void)
+int
+advanced_options (void)
 {
   int *temp;
-  DIALOG d[17];
-  int i,retour=0,choix=4;
-  static int y_pos[6]={0,1,2,4,6,8};
+  DIALOG d[19];
+  int i, retour = 0, choix = 4;
+  static int y_pos[7] = { 0, 1, 2, 4, 6, 7, 9 };
 
-  memset(d,0,sizeof(d));
+  memset (d, 0, sizeof (d));
 
-  for (i=0; i<6; ++i)
+  for (i = 0; i < 7; ++i)
     {
-      standard_button (d+i+4,0,y_pos[i],2,9);
-      d[i+4].proc=my_textbox_proc;
+      standard_button (d + i + 4, 0, y_pos[i], 2, 10);
+      d[i + 4].proc = my_textbox_proc;
     }
-  for (i=0; i<6; ++i)
+  for (i = 0; i < 7; ++i)
     {
-      standard_button (d+i+10,1,y_pos[i],2,9);
-      d[i+10].proc=my_slider_proc;
+      standard_button (d + i + 11, 1, y_pos[i], 2, 10);
+      d[i + 11].proc = my_slider_proc;
     }
-  d[15].proc=my_button_proc;
+  d[16].proc = d[17].proc = my_button_proc;
 
-  quick_buttons(d);
-  d[4].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_ATTACK);
-  d[5].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_DEFENSE);
-  d[6].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_BASEHEALTH);
-  d[7].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_WINNERHELP);
-  d[8].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_CPUSTRENGTH);
-  d[9].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_ASMALGORITHM);
-  d[10].d1=d[11].d1=d[12].d1=d[13].d1=16;
-  d[14].d1=4;
-  d[10].dp3=&CONFIG_FIGHTER_ATTACK;
-  d[11].dp3=&CONFIG_FIGHTER_DEFENSE;
-  d[12].dp3=&CONFIG_FIGHTER_NEW_HEALTH;
-  d[13].dp3=&CONFIG_NUMBER_INFLUENCE;
-  d[14].dp3=&CONFIG_CPU_ADVANTAGE;
-  d[15].dp=get_asm_algorithm_str();
-  for (i=10;i<15;++i)
+  quick_buttons (d);
+  d[4].dp = lw_lang_string (LW_LANG_STRING_ADVANCED_ATTACK);
+  d[5].dp = lw_lang_string (LW_LANG_STRING_ADVANCED_DEFENSE);
+  d[6].dp = lw_lang_string (LW_LANG_STRING_ADVANCED_BASEHEALTH);
+  d[7].dp = lw_lang_string (LW_LANG_STRING_ADVANCED_WINNERHELP);
+  d[8].dp = lw_lang_string (LW_LANG_STRING_ADVANCED_CPUSTRENGTH);
+  d[9].dp = lw_lang_string (LW_LANG_STRING_ADVANCED_CPUVSHUMAN);
+  d[10].dp = lw_lang_string (LW_LANG_STRING_ADVANCED_ASMALGORITHM);
+  d[11].d1 = d[12].d1 = d[13].d1 = d[14].d1 = 16;
+  d[15].d1 = 4;
+  d[11].dp3 = &CONFIG_FIGHTER_ATTACK;
+  d[12].dp3 = &CONFIG_FIGHTER_DEFENSE;
+  d[13].dp3 = &CONFIG_FIGHTER_NEW_HEALTH;
+  d[14].dp3 = &CONFIG_NUMBER_INFLUENCE;
+  d[15].dp3 = &CONFIG_CPU_ADVANTAGE;
+  d[16].dp = get_cpu_vs_human_str ();
+  d[17].dp = get_asm_algorithm_str ();
+  for (i = 11; i < 16; ++i)
     {
-      d[i].dp=NULL;
-      d[i].dp2=slider_int;
-      temp=d[i].dp3;
-      d[i].d2=*temp;
+      d[i].dp = NULL;
+      d[i].dp2 = slider_int;
+      temp = d[i].dp3;
+      d[i].d2 = *temp;
     }
 
 #ifndef ASM
   /*
    * If no assembly code has been compiled, we disable the button
    */
-  d[9].flags=D_HIDDEN;
-  d[15].flags=D_HIDDEN;
+  d[10].flags = D_HIDDEN;
+  d[17].flags = D_HIDDEN;
 #endif
 
-  d[16].proc=0;
+  d[18].proc = 0;
 
-  while (retour==0)
+  while (retour == 0)
     {
-      choix=my_do_dialog (d,choix);
+      choix = my_do_dialog (d, choix);
       switch (choix)
 	{
 	case -1:
 	case MENU_QUICK_BACK:
-	  retour=1;
+	  retour = 1;
 	  break;
 	case MENU_QUICK_MAIN:
-	  retour=MENU_TOP;
+	  retour = MENU_TOP;
 	  break;
 	case MENU_QUICK_QUIT:
-	  if (confirm_quit())
-	    retour=MENU_EXIT;
+	  if (confirm_quit ())
+	    retour = MENU_EXIT;
 	  break;
 	case MENU_QUICK_PLAY:
-	  retour=MENU_PLAY;
+	  retour = MENU_PLAY;
 	  break;
-	case 15:
-	  CONFIG_ASM_ALGORITHM=CONFIG_ASM_ALGORITHM ? 0 : 1;
-	  d[15].dp=get_asm_algorithm_str();
-	  scare_mouse();
-	  my_button_proc (MSG_DRAW,d+15,0);
-	  unscare_mouse();
+	case 16:
+	  CONFIG_CPU_VS_HUMAN = (CONFIG_CPU_VS_HUMAN + 1) % 3;
+	  d[16].dp = get_cpu_vs_human_str ();
+	  scare_mouse ();
+	  my_button_proc (MSG_DRAW, d + 16, 0);
+	  unscare_mouse ();
+	  break;
+	case 17:
+	  CONFIG_ASM_ALGORITHM = CONFIG_ASM_ALGORITHM ? 0 : 1;
+	  d[17].dp = get_asm_algorithm_str ();
+	  scare_mouse ();
+	  my_button_proc (MSG_DRAW, d + 17, 0);
+	  unscare_mouse ();
 	  break;
 	}
     }
 
-  if (retour>0)
+  if (retour > 0)
     retour--;
 
   return retour;
 }
-
-
-
