@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -61,55 +61,54 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-PLACE *CURRENT_AREA=NULL;
+PLACE *CURRENT_AREA = NULL;
 
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-void reset_game_area (void)
+void
+reset_game_area (void)
 {
- int i,k;
+  int i, k;
 
- for (i=0;i<CURRENT_MESH_SIZE;++i)
-     for (k=0;k<NB_TEAMS;++k)
-          CURRENT_MESH[i].info[k].state.grad=AREA_START_GRADIENT;
+  for (i = 0; i < CURRENT_MESH_SIZE; ++i)
+    for (k = 0; k < NB_TEAMS; ++k)
+      CURRENT_MESH[i].info[k].state.grad = AREA_START_GRADIENT;
 
- for (i=0;i<CURRENT_AREA_W*CURRENT_AREA_H;++i)
-      CURRENT_AREA[i].fighter=NULL;
+  for (i = 0; i < CURRENT_AREA_W * CURRENT_AREA_H; ++i)
+    CURRENT_AREA[i].fighter = NULL;
 }
 
 /*------------------------------------------------------------------*/
-int create_game_area (void)
+int
+create_game_area (void)
 {
- int x, y,i,test;
+  int x, y, i, test;
 
- CURRENT_AREA=malloc_in_big_data_bottom
-          (CURRENT_AREA_W*CURRENT_AREA_H*sizeof (PLACE));
+  CURRENT_AREA = malloc_in_big_data_bottom
+    (CURRENT_AREA_W * CURRENT_AREA_H * sizeof (PLACE));
 
- if (CURRENT_AREA&&CURRENT_MESH)
+  if (CURRENT_AREA && CURRENT_MESH)
     {
-     i=0;
-     for (y=0;y<CURRENT_AREA_H;++y)
-         for (x=0;x<CURRENT_AREA_W;++x)
-             {
-              CURRENT_AREA[i].mesh=NULL;
-              CURRENT_AREA[i].fighter=NULL;
-              i++;
-             }
-     for (i=0;i<CURRENT_MESH_SIZE;++i)
-          for (y=0;y<CURRENT_MESH[i].side.size;++y)
-              for (x=0;x<CURRENT_MESH[i].side.size;++x)
-                 {
-                  CURRENT_AREA [(CURRENT_MESH[i].y+y)*CURRENT_AREA_W
-                                +CURRENT_MESH[i].x+x].mesh
-                               =CURRENT_MESH+i;
-                  test=CURRENT_MESH[i].info[0].state.grad;
-                 }
+      i = 0;
+      for (y = 0; y < CURRENT_AREA_H; ++y)
+	for (x = 0; x < CURRENT_AREA_W; ++x)
+	  {
+	    CURRENT_AREA[i].mesh = NULL;
+	    CURRENT_AREA[i].fighter = NULL;
+	    i++;
+	  }
+      for (i = 0; i < CURRENT_MESH_SIZE; ++i)
+	for (y = 0; y < CURRENT_MESH[i].side.size; ++y)
+	  for (x = 0; x < CURRENT_MESH[i].side.size; ++x)
+	    {
+	      CURRENT_AREA[(CURRENT_MESH[i].y + y) * CURRENT_AREA_W
+			   + CURRENT_MESH[i].x + x].mesh = CURRENT_MESH + i;
+	      test = CURRENT_MESH[i].info[0].state.grad;
+	    }
     }
 
- return (CURRENT_AREA ? 0 : -1);
+  return (CURRENT_AREA ? 0 : -1);
 }
-
-
