@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -62,19 +62,21 @@
 /*==================================================================*/
 
 typedef struct
-        {
-         short x;
-         short y;
-         short   health;
-         char team;
-         char last_dir;
-        } FIGHTER;
+{
+  short x;
+  short y;
+  short health;
+  char team;
+  char last_dir;
+}
+FIGHTER;
 
 typedef struct
-        {
-         MESH    *mesh;
-         FIGHTER *fighter;
-        } PLACE;
+{
+  MESH *mesh;
+  FIGHTER *fighter;
+}
+PLACE;
 
 /*==================================================================*/
 /* variables globales                                               */
