@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -64,9 +64,14 @@
 
 #define LW_ASM_OFFSET_BITMAP_LINE   64
 
+#define LW_ASM_SIZEOF_int            4
+#define LW_ASM_SIZEOF_long           4
+#define LW_ASM_SIZEOF_short          2
+#define LW_ASM_SIZEOF_char           1
+
 #define LW_ASM_SIZEOF_MESH_UPDATE    4
 #define LW_ASM_SIZEOF_MESH_STATE     4
-#define LW_ASM_SIZEOF_MESH_INFO      8 
+#define LW_ASM_SIZEOF_MESH_INFO      8
 #define LW_ASM_SIZEOF_MESH_SIDE      4
 #define LW_ASM_SIZEOF_MESH         104
 #define LW_ASM_SIZEOF_FIGHTER        8
@@ -76,7 +81,7 @@
 if (sizeof(S)!=LW_ASM_SIZEOF_ ## S) \
 { \
 result=0; \
-log_print_str("Error: struct " #S " size is "); \
+log_print_str("Error: " #S " size is "); \
 log_print_int(sizeof(S)); \
 log_print_str(" and should be "); \
 log_println_int(LW_ASM_SIZEOF_ ## S); \
@@ -87,37 +92,51 @@ log_println_int(LW_ASM_SIZEOF_ ## S); \
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int lw_asm_check_struct_align (void)
+int
+lw_asm_check_struct_align (void)
 {
-  int result=1;
+  int result = 1;
 
 #ifdef ASM
   {
-    BITMAP *bmp=NULL;
+    BITMAP *bmp = NULL;
     int offset_bitmap_line;
 
-    LW_ASM_CHECK_SIZEOF(MESH_UPDATE);
-    LW_ASM_CHECK_SIZEOF(MESH_STATE);
-    LW_ASM_CHECK_SIZEOF(MESH_INFO);
-    LW_ASM_CHECK_SIZEOF(MESH_SIDE);
-    LW_ASM_CHECK_SIZEOF(MESH);
-    LW_ASM_CHECK_SIZEOF(FIGHTER);
-    LW_ASM_CHECK_SIZEOF(PLACE);
+    LW_ASM_CHECK_SIZEOF (int);
+    LW_ASM_CHECK_SIZEOF (long);
+    LW_ASM_CHECK_SIZEOF (short);
+    LW_ASM_CHECK_SIZEOF (char);
+
+    LW_ASM_CHECK_SIZEOF (MESH_UPDATE);
+    LW_ASM_CHECK_SIZEOF (MESH_STATE);
+    LW_ASM_CHECK_SIZEOF (MESH_INFO);
+    LW_ASM_CHECK_SIZEOF (MESH_SIDE);
+    LW_ASM_CHECK_SIZEOF (MESH);
+    LW_ASM_CHECK_SIZEOF (FIGHTER);
+    LW_ASM_CHECK_SIZEOF (PLACE);
 
     offset_bitmap_line = ((char *) &(bmp->line)) - ((char *) bmp);
     if (offset_bitmap_line != LW_ASM_OFFSET_BITMAP_LINE)
       {
-	result=0;
+	result = 0;
 
-	log_print_str("Error: offset for BITMAP->line is "); 
-	log_print_int(offset_bitmap_line); 
-	log_print_str(" and should be "); 
-	log_println_int(LW_ASM_OFFSET_BITMAP_LINE); 
+	log_print_str ("Error: offset for BITMAP->line is ");
+	log_print_int (offset_bitmap_line);
+	log_print_str (" and should be ");
+	log_println_int (LW_ASM_OFFSET_BITMAP_LINE);
 
-	STARTUP_ASM=0;
-      }	
+	STARTUP_ASM = 0;
+      }
   }
 #endif
 
+  if (!result)
+    {
+      log_println_str ("WARNING!!!");
+      log_println_str
+	("Liquid War might crash unexpectedly... Please read previous error messages.");
+      log_println ();
+    }
+
   return result;
 }
