@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -82,197 +82,221 @@ static int COMPUTER_PATH_WAIT[NB_TEAMS];
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-static void calculate_computer_path  ( int dst_x,
-				       int dst_y,
-				       int cursor)
+static void
+calculate_computer_path (int dst_x, int dst_y, int cursor)
 {
-  int team, src_x, src_y,pos,dir,x,y,dx,dy;
-  MESH *path_mesh,*src_mesh;
-  int sens,start;
+  int team, src_x, src_y, pos, dir, x, y, dx, dy;
+  MESH *path_mesh, *src_mesh;
+  int sens, start;
   int table;
 
-  table=GLOBAL_CLOCK%2;
+  table = GLOBAL_CLOCK % 2;
 
-  team=CURRENT_CURSOR[cursor].team;
+  team = CURRENT_CURSOR[cursor].team;
 
-  src_x=CURRENT_CURSOR[cursor].x;
-  src_y=CURRENT_CURSOR[cursor].y;
-  src_mesh=CURRENT_AREA[src_y*CURRENT_AREA_W+src_x].mesh;
+  src_x = CURRENT_CURSOR[cursor].x;
+  src_y = CURRENT_CURSOR[cursor].y;
+  src_mesh = CURRENT_AREA[src_y * CURRENT_AREA_W + src_x].mesh;
 
-  x=dst_x;
-  y=dst_y;
-  path_mesh=CURRENT_AREA[y*CURRENT_AREA_W+x].mesh;
-  pos=sens=start=0;
-  while (pos<COMPUTER_PATH_MAX
-	 && path_mesh!=0
-	 && path_mesh!=src_mesh)
+  x = dst_x;
+  y = dst_y;
+  path_mesh = CURRENT_AREA[y * CURRENT_AREA_W + x].mesh;
+  pos = sens = start = 0;
+  while (pos < COMPUTER_PATH_MAX && path_mesh != 0 && path_mesh != src_mesh)
     {
-      dir=get_main_dir (path_mesh,team, sens, start);
+      dir = get_main_dir (path_mesh, team, sens, start);
 
-      x+=(dx=FIGHTER_MOVE_X[table][dir][0]);
-      y+=(dy=FIGHTER_MOVE_Y[table][dir][0]);
+      x += (dx = FIGHTER_MOVE_X[table][dir][0]);
+      y += (dy = FIGHTER_MOVE_Y[table][dir][0]);
 
-      path_mesh=CURRENT_AREA[y*CURRENT_AREA_W+x].mesh;
+      path_mesh = CURRENT_AREA[y * CURRENT_AREA_W + x].mesh;
       if (path_mesh)
 	{
-	  COMPUTER_PATH_KEYS[cursor][pos]=0;
-	  if (dy>0)
-	    COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_UP;
-	  if (dx<0)
-	    COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_RIGHT;
-	  if (dy<0)
-	    COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_DOWN;
-	  if (dx>0)
-	    COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_LEFT;
+	  COMPUTER_PATH_KEYS[cursor][pos] = 0;
+	  if (dy > 0)
+	    COMPUTER_PATH_KEYS[cursor][pos] += CURSOR_KEY_UP;
+	  if (dx < 0)
+	    COMPUTER_PATH_KEYS[cursor][pos] += CURSOR_KEY_RIGHT;
+	  if (dy < 0)
+	    COMPUTER_PATH_KEYS[cursor][pos] += CURSOR_KEY_DOWN;
+	  if (dx > 0)
+	    COMPUTER_PATH_KEYS[cursor][pos] += CURSOR_KEY_LEFT;
 	  pos++;
 	}
       start++;
-      if (start==NB_DIRS)
+      if (start == NB_DIRS)
 	{
-	  start=0;
-	  sens=!sens;
+	  start = 0;
+	  sens = !sens;
 	}
     }
 
-  if (path_mesh==src_mesh)
+  if (path_mesh == src_mesh)
     {
-      while (pos < COMPUTER_PATH_MAX
-	     && (x!=src_x || y!=src_y))
+      while (pos < COMPUTER_PATH_MAX && (x != src_x || y != src_y))
 	{
-	  COMPUTER_PATH_KEYS[cursor][pos]=0;
- 
-	  if (y<src_y)
+	  COMPUTER_PATH_KEYS[cursor][pos] = 0;
+
+	  if (y < src_y)
 	    {
 	      y++;
-	      COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_UP;
+	      COMPUTER_PATH_KEYS[cursor][pos] += CURSOR_KEY_UP;
 	    }
-	  if (x>src_x)
+	  if (x > src_x)
 	    {
 	      x--;
-	      COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_RIGHT;
+	      COMPUTER_PATH_KEYS[cursor][pos] += CURSOR_KEY_RIGHT;
 	    }
-	  if (y>src_y)
+	  if (y > src_y)
 	    {
 	      y--;
-	      COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_DOWN;
+	      COMPUTER_PATH_KEYS[cursor][pos] += CURSOR_KEY_DOWN;
 	    }
-	  if (x<src_x)
+	  if (x < src_x)
 	    {
 	      x++;
-	      COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_LEFT;
+	      COMPUTER_PATH_KEYS[cursor][pos] += CURSOR_KEY_LEFT;
 	    }
 	  pos++;
 	}
-      COMPUTER_PATH_SIZE[cursor]=pos;
+      COMPUTER_PATH_SIZE[cursor] = pos;
     }
   else
-    COMPUTER_PATH_SIZE[cursor]=0;
+    COMPUTER_PATH_SIZE[cursor] = 0;
 
-  COMPUTER_PATH_WAIT[cursor]= COMPUTER_PATH_SIZE[cursor];
+  COMPUTER_PATH_WAIT[cursor] = COMPUTER_PATH_SIZE[cursor];
 }
 
 /*------------------------------------------------------------------*/
-void reset_computer_path  (void)
+void
+reset_computer_path (void)
 {
   int i;
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
-      COMPUTER_PATH_SIZE[i]=0;
-      COMPUTER_PATH_WAIT[i]=0;
+      COMPUTER_PATH_SIZE[i] = 0;
+      COMPUTER_PATH_WAIT[i] = 0;
     }
 }
 
 /*------------------------------------------------------------------*/
-static void random_free_xy_different_team (int *x, int *y, int team)
+static int
+random_free_xy_by_control_type (int *x, int *y, int team, int control_type)
 {
-  int i,found=0,foundable=0,foundable_human=0;
-  int control_type[NB_TEAMS];
+  int i, found = 0, foundable = 0;
+  int control_type_array[NB_TEAMS];
   int random_limit;
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
-      control_type[i]=CONFIG_CONTROL_TYPE_OFF;
+      control_type_array[i] = CONFIG_CONTROL_TYPE_OFF;
     }
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
-      if (CURRENT_CURSOR[i].control_type == CONFIG_CONTROL_TYPE_HUMAN
+      if ((CURRENT_CURSOR[i].control_type == control_type
+	   || control_type == CONFIG_CONTROL_TYPE_OFF)
 	  && CURRENT_CURSOR[i].active)
 	{
-	  control_type[CURRENT_CURSOR[i].team]=CURRENT_CURSOR[i].control_type;
+	  control_type_array[CURRENT_CURSOR[i].team] = control_type;
 	}
     }
 
-  for (i=0;i<CURRENT_ARMY_SIZE && !foundable_human;++i)
+  for (i = 0; i < CURRENT_ARMY_SIZE && !foundable; ++i)
     {
-      foundable|=CURRENT_ARMY[i].team!=team;
-      foundable_human|=(control_type[(int)(CURRENT_ARMY[i].team)] == 
-			CONFIG_CONTROL_TYPE_HUMAN);
-    }
-
-  if (foundable_human)
-    {
-      random_limit=0;
-
-      while ((!found) && random_limit<LW_AUTOPLAY_RANDOM_LIMIT)
-	{
-	  i=rand()%CURRENT_ARMY_SIZE;
-	  found=(control_type[(int)(CURRENT_ARMY[i].team)] ==
-		 CONFIG_CONTROL_TYPE_HUMAN);
-	  random_limit++;
-	}
+      foundable |= ((CURRENT_ARMY[i].team != team) &&
+		    (control_type_array[(int) (CURRENT_ARMY[i].team)] ==
+		     control_type
+		     || control_type == CONFIG_CONTROL_TYPE_OFF));
     }
 
   if (foundable)
     {
-      random_limit=0;
-      
-      while ((!found) && random_limit<LW_AUTOPLAY_RANDOM_LIMIT)
+      random_limit = 0;
+
+      while ((!found) && random_limit < LW_AUTOPLAY_RANDOM_LIMIT)
 	{
-	  i=rand()%CURRENT_ARMY_SIZE;
-	  found=(CURRENT_ARMY[i].team!=team);
+	  i = random () % CURRENT_ARMY_SIZE;
+	  found = ((CURRENT_ARMY[i].team != team) &&
+		   (control_type_array[(int) (CURRENT_ARMY[i].team)] ==
+		    control_type || control_type == CONFIG_CONTROL_TYPE_OFF));
 	  random_limit++;
 	}
     }
 
   if (!found)
-    i=rand()%CURRENT_ARMY_SIZE;
+    {
+      /*
+       * OK, we found nothing, we a default random value
+       */
+      i = random () % CURRENT_ARMY_SIZE;
+    }
 
-  (*x)=CURRENT_ARMY[i].x;
-  (*y)=CURRENT_ARMY[i].y;
+  (*x) = CURRENT_ARMY[i].x;
+  (*y) = CURRENT_ARMY[i].y;
+
+  return found;
 }
 
 /*------------------------------------------------------------------*/
-char get_computer_next_move  ( int cursor)
+static void
+random_free_xy_different_team (int *x, int *y, int team)
+{
+  int control_type = 0;
+
+  switch (LW_CONFIG_CURRENT_RULES.cpu_vs_human)
+    {
+    case CONFIG_CPU_VS_HUMAN_ALWAYS:
+      control_type = CONFIG_CONTROL_TYPE_HUMAN;
+      break;
+    case CONFIG_CPU_VS_HUMAN_NEVER:
+      control_type = CONFIG_CONTROL_TYPE_CPU;
+      break;
+    default:
+      control_type = CONFIG_CONTROL_TYPE_OFF;
+      break;
+    }
+
+  if (!random_free_xy_by_control_type (x, y, team, control_type))
+    {
+      /*
+       * We found nobody in the right category, we fallback
+       * on the the default search.
+       */
+      random_free_xy_by_control_type (x, y, team, CONFIG_CONTROL_TYPE_OFF);
+    }
+}
+
+/*------------------------------------------------------------------*/
+char
+get_computer_next_move (int cursor)
 {
   FIGHTER *f;
   char key_info;
-  int x,y;
-  int meme_equipe,team;
+  int x, y;
+  int meme_equipe, team;
 
-  if (COMPUTER_PATH_SIZE[cursor]>0)
+  if (COMPUTER_PATH_SIZE[cursor] > 0)
     {
-      key_info=COMPUTER_PATH_KEYS [cursor]
-	[--COMPUTER_PATH_SIZE[cursor]];
+      key_info = COMPUTER_PATH_KEYS[cursor][--COMPUTER_PATH_SIZE[cursor]];
     }
   else
     {
-      key_info=0;
-      team=CURRENT_CURSOR[cursor].team;
-      f=CURRENT_AREA [CURRENT_CURSOR[cursor].y*CURRENT_AREA_W
-		      +CURRENT_CURSOR[cursor].x].fighter;
+      key_info = 0;
+      team = CURRENT_CURSOR[cursor].team;
+      f = CURRENT_AREA[CURRENT_CURSOR[cursor].y * CURRENT_AREA_W
+		       + CURRENT_CURSOR[cursor].x].fighter;
       if (f)
-	meme_equipe=(f->team==team);
+	meme_equipe = (f->team == team);
       else
-	meme_equipe=1;
-      if ((--COMPUTER_PATH_WAIT[cursor])<0 || meme_equipe)
+	meme_equipe = 1;
+      if ((--COMPUTER_PATH_WAIT[cursor]) < 0 || meme_equipe)
 	{
-          random_free_xy_different_team (&x,&y,team);
-          calculate_computer_path (x,y,cursor);
+	  random_free_xy_different_team (&x, &y, team);
+	  calculate_computer_path (x, y, cursor);
 	}
     }
 
   return key_info;
 }
-
