@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -70,10 +70,10 @@
 #define BIG_DATA_NUMBER 64
 #define MEMORY_TO_LEAVE 1024
 
-static void *BIG_DATA_PTR=0;
-static int BIG_DATA_SIZE=0;
-static int BIG_DATA_BOTTOM=0;
-static int BIG_DATA_TOP=BIG_DATA_NUMBER-1;
+static void *BIG_DATA_PTR = 0;
+static int BIG_DATA_SIZE = 0;
+static int BIG_DATA_BOTTOM = 0;
+static int BIG_DATA_TOP = BIG_DATA_NUMBER - 1;
 static int BIG_DATA_TABLE[BIG_DATA_NUMBER];
 
 /*==================================================================*/
@@ -85,143 +85,147 @@ static int BIG_DATA_TABLE[BIG_DATA_NUMBER];
 /*------------------------------------------------------------------*/
 
 /*------------------------------------------------------------------*/
-void reset_big_data (void)
+void
+reset_big_data (void)
 {
-  BIG_DATA_BOTTOM=0;
-  BIG_DATA_TOP=BIG_DATA_NUMBER-1;
-  BIG_DATA_TABLE[BIG_DATA_BOTTOM]=0;
-  BIG_DATA_TABLE[BIG_DATA_TOP]=BIG_DATA_SIZE;
+  BIG_DATA_BOTTOM = 0;
+  BIG_DATA_TOP = BIG_DATA_NUMBER - 1;
+  BIG_DATA_TABLE[BIG_DATA_BOTTOM] = 0;
+  BIG_DATA_TABLE[BIG_DATA_TOP] = BIG_DATA_SIZE;
 
   if (BIG_DATA_PTR)
     {
-      memset(BIG_DATA_PTR,0,BIG_DATA_SIZE);
+      memset (BIG_DATA_PTR, 0, BIG_DATA_SIZE);
     }
 }
 
 /*------------------------------------------------------------------*/
-void *malloc_big_data (void)
+void *
+malloc_big_data (void)
 {
-  int nb_try=0;
+  int nb_try = 0;
 
   log_print_str ("Allocating ");
-  log_print_int(STARTUP_BIG_DATA);
-  log_print_str(" Mb");
-  log_flush();
+  log_print_int (STARTUP_BIG_DATA);
+  log_print_str (" Mb");
+  log_flush ();
 
   if (BIG_DATA_PTR)
     {
-      free(BIG_DATA_PTR);
-      BIG_DATA_PTR=NULL;
+      free (BIG_DATA_PTR);
+      BIG_DATA_PTR = NULL;
     }
 
   STARTUP_BIG_DATA++;
 
-  while (STARTUP_BIG_DATA>=2 &&
-	 BIG_DATA_PTR==NULL &&
-	 (STARTUP_AUTO || nb_try==0))
+  while (STARTUP_BIG_DATA >= 2 &&
+	 BIG_DATA_PTR == NULL && (STARTUP_AUTO || nb_try == 0))
     {
       nb_try++;
       STARTUP_BIG_DATA--;
-      BIG_DATA_SIZE=STARTUP_BIG_DATA*1024*1024;
-      BIG_DATA_PTR=malloc(BIG_DATA_SIZE);
+      BIG_DATA_SIZE = STARTUP_BIG_DATA * 1024 * 1024;
+      BIG_DATA_PTR = malloc (BIG_DATA_SIZE);
     }
 
-  if (nb_try>1){
-    log_print_str ("Last try with ");
-    log_print_int(STARTUP_BIG_DATA);
-    log_print_str(" Mb");
-  }
+  if (nb_try > 1)
+    {
+      log_print_str ("Last try with ");
+      log_print_int (STARTUP_BIG_DATA);
+      log_print_str (" Mb");
+    }
 
-  if (BIG_DATA_PTR==NULL)
-    BIG_DATA_SIZE=0;
+  if (BIG_DATA_PTR == NULL)
+    BIG_DATA_SIZE = 0;
 
   display_success (BIG_DATA_SIZE);
-  reset_big_data();
+  reset_big_data ();
 
   return (BIG_DATA_PTR);
 }
 
 /*------------------------------------------------------------------*/
-void *malloc_in_big_data_bottom (int size)
+void *
+malloc_in_big_data_bottom (int size)
 {
   char *ptr;
-  int bottom,top,new_offset;
+  int bottom, top, new_offset;
 
-  bottom=BIG_DATA_TABLE[BIG_DATA_BOTTOM];
-  top=BIG_DATA_TABLE[BIG_DATA_TOP];
-  new_offset=((bottom+size+15)/16)*16;
-  if (new_offset<top
-      && BIG_DATA_BOTTOM<(BIG_DATA_TOP-1))
+  bottom = BIG_DATA_TABLE[BIG_DATA_BOTTOM];
+  top = BIG_DATA_TABLE[BIG_DATA_TOP];
+  new_offset = ((bottom + size + 15) / 16) * 16;
+  if (new_offset < top && BIG_DATA_BOTTOM < (BIG_DATA_TOP - 1))
     {
-      ptr=BIG_DATA_PTR;
-      ptr+=bottom;
-      BIG_DATA_TABLE[++BIG_DATA_BOTTOM]=new_offset;
+      ptr = BIG_DATA_PTR;
+      ptr += bottom;
+      BIG_DATA_TABLE[++BIG_DATA_BOTTOM] = new_offset;
 
       /*
        * This is theorically not needed, but in case there's a
        * bug in the assembly code for instance, this will increase
        * the chances that things behave the same on every computer
        */
-      memset(ptr,0,size);
+      memset (ptr, 0, size);
     }
   else
-    ptr=NULL;
+    ptr = NULL;
 
   return ptr;
 }
 
 /*------------------------------------------------------------------*/
-void *malloc_in_big_data_top (int size)
+void *
+malloc_in_big_data_top (int size)
 {
   char *ptr;
-  int bottom,top,new_offset;
+  int bottom, top, new_offset;
 
-  bottom=BIG_DATA_TABLE[BIG_DATA_BOTTOM];
-  top=BIG_DATA_TABLE[BIG_DATA_TOP];
-  new_offset=((top-size)/16)*16;
-  if (new_offset>=bottom
-      && BIG_DATA_BOTTOM<(BIG_DATA_TOP-1))
+  bottom = BIG_DATA_TABLE[BIG_DATA_BOTTOM];
+  top = BIG_DATA_TABLE[BIG_DATA_TOP];
+  new_offset = ((top - size) / 16) * 16;
+  if (new_offset >= bottom && BIG_DATA_BOTTOM < (BIG_DATA_TOP - 1))
     {
-      ptr=BIG_DATA_PTR;
-      ptr+=new_offset;
-      BIG_DATA_TABLE[--BIG_DATA_TOP]=new_offset;
+      ptr = BIG_DATA_PTR;
+      ptr += new_offset;
+      BIG_DATA_TABLE[--BIG_DATA_TOP] = new_offset;
 
       /*
        * This is theorically not needed, but in case there's a
        * bug in the assembly code for instance, this will increase
        * the chances that things behave the same on every computer
        */
-      memset(ptr,0,size);
+      memset (ptr, 0, size);
     }
   else
-    ptr=NULL;
+    ptr = NULL;
 
   return ptr;
 }
 
 /*------------------------------------------------------------------*/
-void free_last_big_data_bottom (void)
+void
+free_last_big_data_bottom (void)
 {
-  if (BIG_DATA_BOTTOM>0)
+  if (BIG_DATA_BOTTOM > 0)
     BIG_DATA_BOTTOM--;
 }
 
 /*------------------------------------------------------------------*/
-void free_last_big_data_top (void)
+void
+free_last_big_data_top (void)
 {
-  if (BIG_DATA_TOP<BIG_DATA_NUMBER-1)
+  if (BIG_DATA_TOP < BIG_DATA_NUMBER - 1)
     BIG_DATA_TOP++;
 }
 
 /*------------------------------------------------------------------*/
-int check_free_memory (void)
+int
+check_free_memory (void)
 {
   BITMAP *result;
 
-  result=my_create_bitmap (MEMORY_TO_LEAVE/2,1024);
+  result = my_create_bitmap (MEMORY_TO_LEAVE / 2, 1024);
   if (result)
     destroy_bitmap (result);
 
-  return result!=NULL;
+  return result != NULL;
 }
-
