@@ -119,6 +119,7 @@
 #define LABEL_ASM_ALGORITHM "ASM_ALGORITHM"
 #define LABEL_PASSWORD "PASSWORD"
 #define LABEL_MIN_MAP_RES "MIN_MAP_RES"
+#define LABEL_USE_DEFAULT_TEXTURE "USE_DEFAULT_TEXTURE"
 
 int CONFIG_GFX_GAME;
 int CONFIG_GFX_MENU;
@@ -165,6 +166,7 @@ int CONFIG_SERVER_PORT;
 int CONFIG_ASM_ALGORITHM;
 char CONFIG_PASSWORD[PASSWORD_SIZE + 1];
 int CONFIG_MIN_MAP_RES;
+int CONFIG_USE_DEFAULT_TEXTURE;
 
 LW_NETCONF LW_CONFIG_CURRENT_RULES;
 
@@ -287,6 +289,8 @@ load_default_options (void)
 
   LW_MACRO_STRCPY (CONFIG_PASSWORD, "toto");
 
+  CONFIG_USE_DEFAULT_TEXTURE = 1;
+
   load_default_rules ();
 }
 
@@ -458,6 +462,10 @@ load_disk_options (void)
 
       CONFIG_MIN_MAP_RES =
 	get_config_int (LABEL_MAIN, LABEL_MIN_MAP_RES, CONFIG_MIN_MAP_RES);
+      CONFIG_USE_DEFAULT_TEXTURE =
+	get_config_int (LABEL_MAIN, LABEL_USE_DEFAULT_TEXTURE,
+			CONFIG_USE_DEFAULT_TEXTURE);
+
       return 1;
     }
   else
@@ -569,6 +577,8 @@ save_config_options (void)
   set_config_string (LABEL_MAIN, LABEL_PASSWORD, CONFIG_PASSWORD);
 
   set_config_int (LABEL_MAIN, LABEL_MIN_MAP_RES, CONFIG_MIN_MAP_RES);
+  set_config_int (LABEL_MAIN, LABEL_USE_DEFAULT_TEXTURE,
+		  CONFIG_USE_DEFAULT_TEXTURE);
 
   return 0;
 }
