@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -72,7 +72,7 @@
  * it would have represented too much work with cursor & teams
  * associations and also with the GUI
  */
-CURSOR CURRENT_CURSOR [NB_TEAMS];
+CURSOR CURRENT_CURSOR[NB_TEAMS];
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -82,13 +82,14 @@ CURSOR CURRENT_CURSOR [NB_TEAMS];
 /*
  * inactivate all cursors
  */
-void reset_all_cursor (void)
+void
+reset_all_cursor (void)
 {
   int i;
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
-      memset(&(CURRENT_CURSOR[i]),0,sizeof(CURSOR));
+      memset (&(CURRENT_CURSOR[i]), 0, sizeof (CURSOR));
     }
 }
 
@@ -96,15 +97,16 @@ void reset_all_cursor (void)
 /*
  * initialization of a cursor, done at each new game
  */
-static void init_cursor (int index, int team, int x,int y, char *name)
+static void
+init_cursor (int index, int team, int x, int y, char *name)
 {
   /*
    * we activate the cursor and set up user parameters
-   */ 
-  CURRENT_CURSOR[index].active=1;
-  CURRENT_CURSOR[index].team=team;
-  CURRENT_CURSOR[index].x=x;
-  CURRENT_CURSOR[index].y=y;
+   */
+  CURRENT_CURSOR[index].active = 1;
+  CURRENT_CURSOR[index].team = team;
+  CURRENT_CURSOR[index].x = x;
+  CURRENT_CURSOR[index].y = y;
   /*
    * the following line reveals an important point of LW's algorithm
    * at game start, one has to set up the value of the cursor with
@@ -122,24 +124,23 @@ static void init_cursor (int index, int team, int x,int y, char *name)
    * "very" far
    * so that's why I use AREA_START_GRADIENT/2
    */
-  CURRENT_CURSOR[index].val=AREA_START_GRADIENT/2;
+  CURRENT_CURSOR[index].val = AREA_START_GRADIENT / 2;
   /*
    * default values...
    */
-  CURRENT_CURSOR[index].loose_time=-1;
-  CURRENT_CURSOR[index].score_order=0;
+  CURRENT_CURSOR[index].loose_time = -1;
+  CURRENT_CURSOR[index].score_order = 0;
   /*
    * the colors allocated for fighters start at 128 in the palette
    * and the COLORS_PER_TEAM value gives how much color per team
    * are available
    */
-  CURRENT_CURSOR[index].color_entry
-    =128+team*COLORS_PER_TEAM;
+  CURRENT_CURSOR[index].color_entry = 128 + team * COLORS_PER_TEAM;
   /*
    * Now we set up the cursor name
    */
-  strncpy(CURRENT_CURSOR[index].name,name,NAME_SIZE);
-  CURRENT_CURSOR[index].name[NAME_SIZE]='\0';
+  strncpy (CURRENT_CURSOR[index].name, name, NAME_SIZE);
+  CURRENT_CURSOR[index].name[NAME_SIZE] = '\0';
 }
 
 /*------------------------------------------------------------------*/
@@ -147,35 +148,36 @@ static void init_cursor (int index, int team, int x,int y, char *name)
  * this is where the cursor is "blitted" on the map, algorythmically
  * speaking, ie the map acknowledges the position of the cursor
  */
-void apply_all_cursor (void)
+void
+apply_all_cursor (void)
 {
-  int i,x,y;
+  int i, x, y;
   MESH *temp;
 
   /*
    * loop for all the active cursors
    */
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     if (CURRENT_CURSOR[i].active)
       {
 	/*
 	 * x and y hold the position of the cursor
 	 */
-	x=CURRENT_CURSOR[i].x;
-	y=CURRENT_CURSOR[i].y;
+	x = CURRENT_CURSOR[i].x;
+	y = CURRENT_CURSOR[i].y;
 	/*
 	 * sanity check, in case the cursor is not on a valid part
 	 * of the map. It should not happen but I hate protection
 	 * faults!
 	 */
-	if ((temp=CURRENT_AREA [y*CURRENT_AREA_W+x].mesh)!=NULL)
+	if ((temp = CURRENT_AREA[y * CURRENT_AREA_W + x].mesh) != NULL)
 	  /*
 	   * we just poke the value of the cursor into its
 	   * corresponding position in the map
 	   * very simple, eh?
 	   */
 	  temp->info[CURRENT_CURSOR[i].team].state.grad
-	    =CURRENT_CURSOR[i].val;
+	    = CURRENT_CURSOR[i].val;
       }
 }
 
@@ -185,37 +187,38 @@ void apply_all_cursor (void)
  * on the map, knowing that we can give a fixed position for each
  * team since all maps are potentially different. 
  */
-void auto_cursor (int index, int team, char *name)
+void
+auto_cursor (int index, int team, char *name)
 {
-  int i,x,y,x_min,x_max,y_min,y_max,ok,x0,y0,n;
+  int i, x, y, x_min, x_max, y_min, y_max, ok, x0, y0, n;
 
-  x=y=n=0;
+  x = y = n = 0;
   /*
    * loop for all the fighters of all teams
    */
-  for (i=0;i<CURRENT_ARMY_SIZE;++i)
+  for (i = 0; i < CURRENT_ARMY_SIZE; ++i)
     /*
      * we exclude fighters who do not belong to the team we want
      */
-    if (CURRENT_ARMY[i].team==team)
+    if (CURRENT_ARMY[i].team == team)
       {
 	/*
 	 * the following totals will be used to get the center
 	 * of all the fighters belonging to this army
 	 * of course it implies fighters have been placed
 	 */
-	x+=CURRENT_ARMY[i].x;
-	y+=CURRENT_ARMY[i].y;
+	x += CURRENT_ARMY[i].x;
+	y += CURRENT_ARMY[i].y;
 	n++;
       }
 
   /*
    * x0 and y0 should now be right in the middle of our fichters
    */
-  x0=x_max=x_min=(x/=n);
-  y0=y_max=y_min=(y/=n);
+  x0 = x_max = x_min = (x /= n);
+  y0 = y_max = y_min = (y /= n);
 
-  ok=0;
+  ok = 0;
   /*
    * loop as long as no correct position has been found
    * we can't admit a random placing for network consideration, so we follow
@@ -228,70 +231,67 @@ void auto_cursor (int index, int team, char *name)
       /* 
        * try and find a good spot going right
        */
-      for (x=x_min; x<=x_max && !ok; ++x)
-	if (CURRENT_AREA[y*CURRENT_AREA_W+x].mesh!=NULL)
+      for (x = x_min; x <= x_max && !ok; ++x)
+	if (CURRENT_AREA[y * CURRENT_AREA_W + x].mesh != NULL)
 	  {
-	    ok=1;
-	    x0=x;
-	    y0=y;
+	    ok = 1;
+	    x0 = x;
+	    y0 = y;
 	  }
       /*
        * if we did not touch the right side yet, let's increase the limit
        */
-      if (x_max<CURRENT_AREA_W-1)
+      if (x_max < CURRENT_AREA_W - 1)
 	++x_max;
 
       /* 
        * try and find a good spot going down
        */
-      for (y=y_min; y<=y_max && !ok; ++y)
-	if (CURRENT_AREA[y*CURRENT_AREA_W+x].mesh!=NULL)
+      for (y = y_min; y <= y_max && !ok; ++y)
+	if (CURRENT_AREA[y * CURRENT_AREA_W + x].mesh != NULL)
 	  {
-	    ok=1;
-	    x0=x;
-	    y0=y;
+	    ok = 1;
+	    x0 = x;
+	    y0 = y;
 	  }
       /*
        * if we did not touch the bottom side yet, let's increase the limit
        */
-      if (y_max<CURRENT_AREA_H-1)
+      if (y_max < CURRENT_AREA_H - 1)
 	++y_max;
 
       /* 
        * try and find a good spot going left
        */
-      for (x=x_max; x>=x_min && !ok; --x)
-	if (CURRENT_AREA[y*CURRENT_AREA_W+x].mesh!=NULL)
+      for (x = x_max; x >= x_min && !ok; --x)
+	if (CURRENT_AREA[y * CURRENT_AREA_W + x].mesh != NULL)
 	  {
-	    ok=1;
-	    x0=x;
-	    y0=y;
+	    ok = 1;
+	    x0 = x;
+	    y0 = y;
 	  }
       /*
        * if we did not touch the left side yet, let's decrease the limit
        */
-      if (x_min>0)
+      if (x_min > 0)
 	--x_min;
 
       /* 
        * try and find a good spot going up 
        */
-      for (y=y_max; y>=y_min && !ok; --y)
-	if (CURRENT_AREA[y*CURRENT_AREA_W+x].mesh!=NULL)
+      for (y = y_max; y >= y_min && !ok; --y)
+	if (CURRENT_AREA[y * CURRENT_AREA_W + x].mesh != NULL)
 	  {
-	    ok=1;
-	    x0=x;
-	    y0=y;
+	    ok = 1;
+	    x0 = x;
+	    y0 = y;
 	  }
       /*
        * if we did not touch the top side yet, let's decrease the limit
        */
-      if (y_min>0)
+      if (y_min > 0)
 	--y_min;
     }
 
-  init_cursor (index,team,x0,y0,name);
+  init_cursor (index, team, x0, y0, name);
 }
-
-
-
