@@ -53,6 +53,9 @@
 /*==================================================================*/
 
 #include <string.h>
+#ifdef UNIX
+#include <unistd.h>
+#endif
 
 #include "dialog.h"
 #include "sound.h"
@@ -309,6 +312,13 @@ my_update_dialog (DIALOG_PLAYER * player)
   lw_capture_dump_menu ();
   my_exit_poll ();
 
+#ifdef UNIX
+  /*
+   * The usleep calls prevents the game from eating 100% of the
+   * CPU time on UNIX platforms.
+   */
+  usleep (100);
+#endif
   yield_timeslice ();
 
   return result;
