@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -87,7 +87,7 @@
 #define MENU_H_TEAM 90
 #define MENU_H_INTERNET_LIST 175
 #define MENU_W_STANDARD 100
-#define MENU_W_QUICK 50
+#define MENU_W_QUICK 60
 #define MENU_W_SPACE 3
 #define MENU_W_LEVEL 40
 #define MENU_W_SAMPLE 160
@@ -100,23 +100,22 @@
 
 int menu_real_x (int x);
 int menu_real_y (int y);
-void menu_real_coord (DIALOG *d);
+void menu_real_coord (DIALOG * d);
 int find_center (int pos, int num, int space, int size);
-void color_one_dialog (DIALOG *d);
-void center_one_dialog (DIALOG *d,int x,int y,int w,int h);
-void quick_buttons (DIALOG *d);
-void standard_button (DIALOG *d, int x_pos, int y_pos,
-		      int x_num, int y_num);
-void standard_small_button (DIALOG *d, int x_pos, int y_pos,
+void color_one_dialog (DIALOG * d);
+void center_one_dialog (DIALOG * d, int x, int y, int w, int h);
+void quick_buttons (DIALOG * d);
+void standard_button (DIALOG * d, int x_pos, int y_pos, int x_num, int y_num);
+void standard_small_button (DIALOG * d, int x_pos, int y_pos,
 			    int x_num, int y_num);
-void standard_big_button (DIALOG *d, int x_pos, int y_pos,
+void standard_big_button (DIALOG * d, int x_pos, int y_pos,
 			  int x_num, int y_num);
-void main_message (DIALOG *d, char *str);
-void main_info (DIALOG *d, char *str);
-DIALOG_PLAYER *my_init_dialog (DIALOG *d, int f);
-int my_do_dialog_no_clear (DIALOG *d, int f);
-int my_do_dialog (DIALOG *d, int f);
-int my_update_dialog (DIALOG_PLAYER *d);
+void main_message (DIALOG * d, char *str);
+void main_info (DIALOG * d, char *str);
+DIALOG_PLAYER *my_init_dialog (DIALOG * d, int f);
+int my_do_dialog_no_clear (DIALOG * d, int f);
+int my_do_dialog (DIALOG * d, int f);
+int my_update_dialog (DIALOG_PLAYER * d);
 void display_center_message (char *str);
 int slider_int (void *dp3, int d2);
 
