@@ -77,11 +77,13 @@
 
 int SAMPLE_WATER_NUMBER = 0;
 int RAW_TEXTURE_NUMBER = 0;
+int RAW_MAPTEX_NUMBER = 0;
 int RAW_MAP_NUMBER = 0;
 int MIDI_MUSIC_NUMBER = 0;
 
 int LOADED_BACK = 0;
 int LOADED_TEXTURE = 0;
+int LOADED_MAPTEX = 0;
 int LOADED_SFX = 0;
 int LOADED_WATER = 0;
 int LOADED_MUSIC = 0;
@@ -97,6 +99,7 @@ SAMPLE *SAMPLE_WATER[SAMPLE_WATER_MAX_NUMBER];
 void *RAW_MAP[RAW_MAP_MAX_NUMBER];
 void *RAW_MAP_ORDERED[RAW_MAP_MAX_NUMBER];
 void *RAW_TEXTURE[RAW_TEXTURE_MAX_NUMBER];
+void *RAW_MAPTEX[RAW_TEXTURE_MAX_NUMBER];
 MIDI *MIDI_MUSIC[MIDI_MUSIC_MAX_NUMBER];
 
 BITMAP *BACK_IMAGE = NULL;
@@ -197,6 +200,20 @@ read_texture_dat (DATAFILE * df)
     }
 }
 
+/*------------------------------------------------------------------*/
+static void
+read_maptex_dat (DATAFILE * df)
+{
+  int i;
+
+  RAW_MAPTEX_NUMBER = 0;
+  for (i = 0; i < RAW_TEXTURE_DAT_NUMBER && df[i].type != DAT_END; ++i)
+    {
+      RAW_MAPTEX[i] = df[i].dat;
+      RAW_MAPTEX_NUMBER++;
+    }
+}
+
 /*------------------------------------------------------------------*/
 static void
 read_map_dat (DATAFILE * df)
@@ -369,6 +386,18 @@ load_dat (void)
       else
 	result &= !STARTUP_CHECK;
       display_success (df != NULL);
+
+      log_print_str ("Loading map textures");
+      log_flush ();
+      df = load_datafile_object (STARTUP_DAT_PATH, "maptex_dat");
+      if (df != NULL)
+	{
+	  read_maptex_dat (df[0].dat);
+	  LOADED_MAPTEX = 1;
+	}
+      else
+	result &= !STARTUP_CHECK;
+      display_success (df != NULL);
     }
 
   if (loadable && STARTUP_WATER_STATE)
@@ -594,8 +623,8 @@ order_map (void)
 
       for (i = 0; i < RAW_MAP_NUMBER - 1; ++i)
 	{
-	  LW_MACRO_STRCPY (name1, lw_map_get_readable_name (i, 0));
-	  LW_MACRO_STRCPY (name2, lw_map_get_readable_name (i + 1, 0));
+	  LW_MACRO_STRCPY (name1, lw_map_get_readable_name (i, 0, 0));
+	  LW_MACRO_STRCPY (name2, lw_map_get_readable_name (i + 1, 0, 0));
 	  if (strcmp (name1, name2) > 0)
 	    {
 	      incorrect_order = 1;
