@@ -79,11 +79,13 @@
 
 extern int SAMPLE_WATER_NUMBER;
 extern int RAW_TEXTURE_NUMBER;
+extern int RAW_MAPTEX_NUMBER;
 extern int RAW_MAP_NUMBER;
 extern int MIDI_MUSIC_NUMBER;
 
 extern int LOADED_BACK;
 extern int LOADED_TEXTURE;
+extern int LOADED_MAPTEX;
 extern int LOADED_SFX;
 extern int LOADED_WATER;
 
@@ -98,6 +100,7 @@ extern SAMPLE *SAMPLE_WATER[SAMPLE_WATER_MAX_NUMBER];
 extern void *RAW_MAP[RAW_MAP_MAX_NUMBER];
 extern void *RAW_MAP_ORDERED[RAW_MAP_MAX_NUMBER];
 extern void *RAW_TEXTURE[RAW_TEXTURE_MAX_NUMBER];
+extern void *RAW_MAPTEX[RAW_TEXTURE_MAX_NUMBER];
 extern MIDI *MIDI_MUSIC[MIDI_MUSIC_MAX_NUMBER];
 
 extern BITMAP *BACK_IMAGE;
