@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -55,6 +55,7 @@
 #include <winsock.h>
 #endif
 #ifdef UNIX
+#include <sys/types.h>
 #include <netdb.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -79,21 +80,19 @@
 /* global functions                                                 */
 /*==================================================================*/
 
-int lw_dnsutil_name_to_ip(char *ip, char *name)
+int
+lw_dnsutil_name_to_ip (char *ip, char *name)
 {
-  int result=0;
+  int result = 0;
 #ifdef DOS
-  memset(ip,0,LW_SOCK_IP_SIZE);
+  memset (ip, 0, LW_SOCK_IP_SIZE);
 #else
   struct hostent *h;
   struct in_addr addr;
 
-  memset(ip,0,LW_SOCK_IP_SIZE);
-  h=gethostbyname(name);
-  if (h && 
-      h->h_addrtype==AF_INET && 
-      h->h_length>=4 && 
-      h->h_addr_list[0])
+  memset (ip, 0, LW_SOCK_IP_SIZE);
+  h = gethostbyname (name);
+  if (h && h->h_addrtype == AF_INET && h->h_length >= 4 && h->h_addr_list[0])
     {
 #ifdef UNIX
       addr = *((struct in_addr *) (h->h_addr_list[0]));
@@ -101,13 +100,11 @@ int lw_dnsutil_name_to_ip(char *ip, char *name)
       addr.s_addr = *((u_long *) (h->h_addr_list[0]));
 #endif
 
-      strncpy(ip,inet_ntoa(addr),LW_SOCK_IP_SIZE-1);
-      ip[LW_SOCK_IP_SIZE-1]='\0';
+      strncpy (ip, inet_ntoa (addr), LW_SOCK_IP_SIZE - 1);
+      ip[LW_SOCK_IP_SIZE - 1] = '\0';
 
-      result=1;
+      result = 1;
     }
 #endif
   return result;
 }
-
-
