@@ -53,6 +53,9 @@
 /*==================================================================*/
 
 #include <stdlib.h>
+#ifdef UNIX
+#include <unistd.h>
+#endif
 #include <allegro.h>
 
 #include "area.h"
@@ -70,6 +73,7 @@
 #include "grad.h"
 #include "info.h"
 #include "map.h"
+#include "maptex.h"
 #include "menu.h"
 #include "message.h"
 #include "mouse.h"
@@ -87,6 +91,7 @@
 #include "exit.h"
 #include "capture.h"
 #include "startup.h"
+#include "random.h"
 
 /*==================================================================*/
 /* definitions de constantes                                        */
@@ -269,13 +274,15 @@ init_game (void)
    * no fighters drawn on it)
    */
   if (!message &&
-      (CURRENT_AREA_BACK = lw_map_create_textured
+      (CURRENT_AREA_BACK = lw_maptex_create_map
        (CONFIG_LEVEL_MAP,
 	CONFIG_LEVEL_FG,
 	CONFIG_LEVEL_BG,
 	LW_NETWORK_ON,
+	LW_RANDOM_ON,
 	MIN_MAP_RES_W[LW_CONFIG_CURRENT_RULES.min_map_res],
-	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res])) == NULL)
+	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res],
+	CONFIG_USE_DEFAULT_TEXTURE)) == NULL)
     message = lw_lang_string (LW_LANG_STRING_GAME_BACKMEMFAIL);
 
   /*
@@ -284,13 +291,15 @@ init_game (void)
    * will be drawn on it
    */
   if (!message &&
-      (CURRENT_AREA_DISP = lw_map_create_textured
+      (CURRENT_AREA_DISP = lw_maptex_create_map
        (CONFIG_LEVEL_MAP,
 	CONFIG_LEVEL_FG,
 	CONFIG_LEVEL_BG,
 	LW_NETWORK_ON,
+	LW_RANDOM_ON,
 	MIN_MAP_RES_W[LW_CONFIG_CURRENT_RULES.min_map_res],
-	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res])) == NULL)
+	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res],
+	CONFIG_USE_DEFAULT_TEXTURE)) == NULL)
     message = lw_lang_string (LW_LANG_STRING_GAME_DISPMEMFAIL);
 
   if (!message)
@@ -779,7 +788,19 @@ game (void)
 	      while (get_ticker () < last_logic_time
 		     + LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT])
 		{
+#ifdef UNIX
+		  /*
+		   * The usleep calls prevents the game from eating 100% of the
+		   * CPU time on UNIX platforms.
+		   */
+		  usleep (1000);
+#else
+		  /*
+		   * Rest does not seem to spare CPU time, but at least it
+		   * slows the game down
+		   */
 		  rest (1);
+#endif
 		  yield_timeslice ();
 		}
 	      last_logic_time = get_ticker ();
