@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -66,8 +66,7 @@ extern int GFX_MODE_H[5];
 /* fonctions globales                                               */
 /*==================================================================*/
 
-int need_to_change_mode(int res1,int res2,int flip);
-int set_resolution (int res, int flip, int fullscreen, 
-		    int *flip_enabled);
+int need_to_change_mode (int res1, int res2, int flip);
+int set_resolution (int res, int flip, int fullscreen, int *flip_enabled);
 
 #endif
