@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -74,29 +74,29 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-BITMAP *create_gradient_bitmap (int team)
+BITMAP *
+create_gradient_bitmap (int team)
 {
   BITMAP *result;
-  int x,y,i,color;
+  int x, y, i, color;
   MESH *temp;
 
-  result=my_create_bitmap (CURRENT_AREA_W, CURRENT_AREA_H);
+  result = my_create_bitmap (CURRENT_AREA_W, CURRENT_AREA_H);
 
   if (result)
     {
-      i=0;
-      for (y=0; y<CURRENT_AREA_H; ++y)
-	for (x=0; x<CURRENT_AREA_W; ++x)
+      i = 0;
+      for (y = 0; y < CURRENT_AREA_H; ++y)
+	for (x = 0; x < CURRENT_AREA_W; ++x)
 	  {
-	    if ((temp=CURRENT_AREA[i++].mesh)!=NULL)
+	    if ((temp = CURRENT_AREA[i++].mesh) != NULL)
 	      {
-		color=(temp->info[team].state.grad
-		       +AREA_START_GRADIENT)%COLORS_PER_TEAM;
-		putpixel (result, x, y,
-			  color+COLOR_FIRST_ENTRY[team]);
+		color = (temp->info[team].state.grad
+			 + AREA_START_GRADIENT) % COLORS_PER_TEAM;
+		putpixel (result, x, y, color + COLOR_FIRST_ENTRY[team]);
 	      }
 	    else
-              putpixel (result, x, y, MENU_BG);
+	      putpixel (result, x, y, MENU_BG);
 	  }
     }
 
@@ -104,22 +104,23 @@ BITMAP *create_gradient_bitmap (int team)
 }
 
 /*------------------------------------------------------------------*/
-BITMAP *create_dir_bitmap (int team)
+BITMAP *
+create_dir_bitmap (int team)
 {
   BITMAP *result;
-  int x,y,i;
+  int x, y, i;
   MESH *temp;
 
-  result=my_create_bitmap (CURRENT_AREA_W, CURRENT_AREA_H);
+  result = my_create_bitmap (CURRENT_AREA_W, CURRENT_AREA_H);
 
-  i=0;
-  for (y=0; y<CURRENT_AREA_H; ++y)
-    for (x=0; x<CURRENT_AREA_W; ++x)
+  i = 0;
+  for (y = 0; y < CURRENT_AREA_H; ++y)
+    for (x = 0; x < CURRENT_AREA_W; ++x)
       {
-	if ((temp=CURRENT_AREA[i++].mesh)!=NULL)
+	if ((temp = CURRENT_AREA[i++].mesh) != NULL)
 	  putpixel (result, x, y, 134
-		    +(temp->info[team].state.dir/4)*42
-		    +(temp->info[team].state.dir%4)*10);
+		    + (temp->info[team].state.dir / 4) * 42
+		    + (temp->info[team].state.dir % 4) * 10);
       }
 
   return result;
@@ -130,117 +131,107 @@ BITMAP *create_dir_bitmap (int team)
 /*------------------------------------------------------------------*/
 
 /*------------------------------------------------------------------*/
-void spread_single_gradient (void)
+void
+spread_single_gradient (void)
 {
-  int i,new_grad,dir;
-  MESH *pos,*last;
+  int i, new_grad, dir;
+  MESH *pos, *last;
   MESH *temp;
 
-  dir=(GLOBAL_CLOCK*7)%NB_DIRS;
+  dir = (GLOBAL_CLOCK * 7) % NB_DIRS;
   switch (dir)
     {
-    case DIR_ENE :
-    case DIR_ESE :
-    case DIR_SE  :
-    case DIR_SSE :
-    case DIR_SSW :
-    case DIR_SW  :
-      pos=CURRENT_MESH;
-      last=CURRENT_MESH+CURRENT_MESH_SIZE;
+    case DIR_ENE:
+    case DIR_ESE:
+    case DIR_SE:
+    case DIR_SSE:
+    case DIR_SSW:
+    case DIR_SW:
+      pos = CURRENT_MESH;
+      last = CURRENT_MESH + CURRENT_MESH_SIZE;
 #ifdef ASM
       if (STARTUP_ASM && LW_CONFIG_CURRENT_RULES.asm_algorithm)
 	switch (PLAYING_TEAMS)
 	  {
-	  case 6 :
+	  case 6:
 	    boost_gradient_down_6
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
-	  case 5 :
+	  case 5:
 	    boost_gradient_down_5
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
-	  case 4 :
+	  case 4:
 	    boost_gradient_down_4
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
-	  case 3 :
+	  case 3:
 	    boost_gradient_down_3
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
-	  default :
+	  default:
 	    boost_gradient_down_2
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
 	  }
       else
 #endif
-	while (pos!=last)
+	while (pos != last)
 	  {
-	    for (i=0;i<PLAYING_TEAMS;++i)
-	      if (   (temp=(pos->link[dir]))
-		     && (temp->info[i].state.grad
-			 >  (new_grad=pos->info[i].state.grad+pos->side.size)))
-		temp->info[i].state.grad=new_grad;
+	    for (i = 0; i < PLAYING_TEAMS; ++i)
+	      if ((temp = (pos->link[dir]))
+		  && (temp->info[i].state.grad
+		      > (new_grad =
+			 pos->info[i].state.grad + pos->side.size)))
+		temp->info[i].state.grad = new_grad;
 	    pos++;
-          }
+	  }
       break;
-    case DIR_WSW :
-    case DIR_WNW :
-    case DIR_NW  :
-    case DIR_NNW :
-    case DIR_NNE :
-    case DIR_NE  :
-      pos=CURRENT_MESH+CURRENT_MESH_SIZE-1;
-      last=CURRENT_MESH-1;
+    case DIR_WSW:
+    case DIR_WNW:
+    case DIR_NW:
+    case DIR_NNW:
+    case DIR_NNE:
+    case DIR_NE:
+      pos = CURRENT_MESH + CURRENT_MESH_SIZE - 1;
+      last = CURRENT_MESH - 1;
 #ifdef ASM
       if (STARTUP_ASM && LW_CONFIG_CURRENT_RULES.asm_algorithm)
 	switch (PLAYING_TEAMS)
 	  {
-	  case 6 :
+	  case 6:
 	    boost_gradient_up_6
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
-	  case 5 :
+	  case 5:
 	    boost_gradient_up_5
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
-	  case 4 :
+	  case 4:
 	    boost_gradient_up_4
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
-	  case 3 :
+	  case 3:
 	    boost_gradient_up_3
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
-	  default :
+	  default:
 	    boost_gradient_up_2
-	      (pos, CURRENT_MESH_SIZE-1,
-	       OFFSET_TO_FIRST_LINK+dir*4);
+	      (pos, CURRENT_MESH_SIZE - 1, OFFSET_TO_FIRST_LINK + dir * 4);
 	    break;
 	  }
       else
 #endif
-	while (pos!=last)
+	while (pos != last)
 	  {
-	    for (i=0;i<PLAYING_TEAMS;++i)
-	      if (   (temp=(pos->link[dir]))
-		     && (temp->info[i].state.grad
-			 >  (new_grad=pos->info[i].state.grad+pos->side.size)))
-		temp->info[i].state.grad=new_grad;
+	    for (i = 0; i < PLAYING_TEAMS; ++i)
+	      if ((temp = (pos->link[dir]))
+		  && (temp->info[i].state.grad
+		      > (new_grad =
+			 pos->info[i].state.grad + pos->side.size)))
+		temp->info[i].state.grad = new_grad;
 	    pos--;
 	  }
       break;
     }
 }
-
-
-
