@@ -61,11 +61,14 @@
 #include "info.h"
 #include "decal.h"
 #include "palette.h"
+#include "maptex.h"
 #include "texture.h"
 #include "time.h"
 #include "viewport.h"
 #include "watchdog.h"
 #include "macro.h"
+#include "network.h"
+#include "random.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -108,8 +111,14 @@ init_info_bar (int w, int h, int epaisseur)
 	  rectfill (INFO_BAR, 0, 0, epaisseur - 1, h - 1, MENU_BG);
 	  vline (INFO_BAR, epaisseur, 0, h - 1, MENU_FG);
 
-	  front = lw_texture_create_fg (CONFIG_LEVEL_FG);
-	  back = lw_texture_create_bg (CONFIG_LEVEL_BG);
+	  front =
+	    lw_maptex_create_fg (CONFIG_LEVEL_MAP, CONFIG_LEVEL_FG,
+				 LW_NETWORK_ON, LW_RANDOM_ON,
+				 CONFIG_USE_DEFAULT_TEXTURE);
+	  back =
+	    lw_maptex_create_bg (CONFIG_LEVEL_MAP, CONFIG_LEVEL_BG,
+				 LW_NETWORK_ON, LW_RANDOM_ON,
+				 CONFIG_USE_DEFAULT_TEXTURE);
 
 	  for (y = 0; y < h; y += front->h)
 	    for (x = epaisseur + 1; x < w; x += front->w)
@@ -142,8 +151,14 @@ init_info_bar (int w, int h, int epaisseur)
 	  rectfill (INFO_BAR, 0, 0, w - 1, epaisseur - 1, MENU_BG);
 	  hline (INFO_BAR, 0, epaisseur, w - 1, MENU_FG);
 
-	  front = lw_texture_create_fg (CONFIG_LEVEL_FG);
-	  back = lw_texture_create_bg (CONFIG_LEVEL_BG);
+	  front =
+	    lw_maptex_create_fg (CONFIG_LEVEL_MAP, CONFIG_LEVEL_FG,
+				 LW_NETWORK_ON, LW_RANDOM_ON,
+				 CONFIG_USE_DEFAULT_TEXTURE);
+	  back =
+	    lw_maptex_create_bg (CONFIG_LEVEL_MAP, CONFIG_LEVEL_BG,
+				 LW_NETWORK_ON, LW_RANDOM_ON,
+				 CONFIG_USE_DEFAULT_TEXTURE);
 
 	  for (y = epaisseur + 1; y < h; y += front->h)
 	    for (x = 0; x < w; x += front->w)
