@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -79,110 +79,125 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-static char ALLOWED_KEYBOARD_KEY[128]=
-  {
-    1,1,1,1, 1,1,1,1, 1,1,1,1, 1,1,1,1,
-    1,1,1,1, 1,1,1,1, 1,1,1,1, 1,1,1,1,
-    1,1,1,1, 1,1,1,1, 1,1,1,1, 1,1,1,1,
-    1,1,1,1, 1,1,1,1, 1,1,1,1, 1,1,1,1,
-    1,1,1,1, 1,1,1,1, 1,1,1,1, 1,1,1,1,
-    1,1,1,1, 1,1,1,1, 1,1,1,1, 1,1,1,1,
-    1,1,1,1, 1,1,1,1, 1,1,0,0, 0,0,0,0,
-    0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,0,
-  };
+static char ALLOWED_KEYBOARD_KEY[128] = {
+  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+};
 
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int is_touched_key (int i)
+int
+is_touched_key (int i)
 {
-  int retval=0;
-  int found=0;
+  int retval = 0;
+  int found = 0;
 
   if (CONFIG_JOYSTICK_ON)
     switch (i)
       {
-      case KEY_JOY1_UP : found=1;
-	retval=joy_up;
+      case KEY_JOY1_UP:
+	found = 1;
+	retval = joy_up;
 	break;
-      case KEY_JOY1_RIGHT : found=1;
-	retval=joy_right;
+      case KEY_JOY1_RIGHT:
+	found = 1;
+	retval = joy_right;
 	break;
-      case KEY_JOY1_DOWN : found=1;
-	retval=joy_down;
+      case KEY_JOY1_DOWN:
+	found = 1;
+	retval = joy_down;
 	break;
-      case KEY_JOY1_LEFT : found=1;
-	retval=joy_left;
+      case KEY_JOY1_LEFT:
+	found = 1;
+	retval = joy_left;
 	break;
 
-      case KEY_JOY1_B1 : found=1;
-	retval=joy_b1;
+      case KEY_JOY1_B1:
+	found = 1;
+	retval = joy_b1;
 	break;
-      case KEY_JOY1_B2 : found=1;
-	retval=joy_b2;
+      case KEY_JOY1_B2:
+	found = 1;
+	retval = joy_b2;
 	break;
 
-      case KEY_JOY2_UP : found=1;
-	retval=joy2_up;
+      case KEY_JOY2_UP:
+	found = 1;
+	retval = joy2_up;
 	break;
-      case KEY_JOY2_RIGHT : found=1;
-	retval=joy2_right;
+      case KEY_JOY2_RIGHT:
+	found = 1;
+	retval = joy2_right;
 	break;
-      case KEY_JOY2_DOWN : found=1;
-	retval=joy2_down;
+      case KEY_JOY2_DOWN:
+	found = 1;
+	retval = joy2_down;
 	break;
-      case KEY_JOY2_LEFT : found=1;
-	retval=joy2_left;
+      case KEY_JOY2_LEFT:
+	found = 1;
+	retval = joy2_left;
 	break;
 
-      case KEY_JOY2_B1 : found=1;
-	retval=joy2_b1;
+      case KEY_JOY2_B1:
+	found = 1;
+	retval = joy2_b1;
 	break;
-      case KEY_JOY2_B2 : found=1;
-	retval=joy2_b2;
+      case KEY_JOY2_B2:
+	found = 1;
+	retval = joy2_b2;
 	break;
       }
 
   if (!found)
     switch (i)
       {
-      case KEY_MOUSE_UP :  retval=MOUSE_CONTROL_UP;
+      case KEY_MOUSE_UP:
+	retval = MOUSE_CONTROL_UP;
 	break;
-      case KEY_MOUSE_RIGHT : retval=MOUSE_CONTROL_RIGHT;
+      case KEY_MOUSE_RIGHT:
+	retval = MOUSE_CONTROL_RIGHT;
 	break;
-      case KEY_MOUSE_DOWN : retval=MOUSE_CONTROL_DOWN;
+      case KEY_MOUSE_DOWN:
+	retval = MOUSE_CONTROL_DOWN;
 	break;
-      case KEY_MOUSE_LEFT : retval=MOUSE_CONTROL_LEFT;
+      case KEY_MOUSE_LEFT:
+	retval = MOUSE_CONTROL_LEFT;
 	break;
       default:
 
-         
-	if (i>=128)
+
+	if (i >= 128)
 	  {
-	    i-=128;
-	    retval= (key[i]&KB_EXTENDED)
-	      && ALLOWED_KEYBOARD_KEY[i];
+	    i -= 128;
+	    retval = (key[i] & KB_EXTENDED) && ALLOWED_KEYBOARD_KEY[i];
 	  }
 	else
-	  retval= (key[i]&KB_NORMAL)
-	    && ALLOWED_KEYBOARD_KEY[i];
- 
+	  retval = (key[i] & KB_NORMAL) && ALLOWED_KEYBOARD_KEY[i];
+
       }
- 
+
 
   return retval ? 1 : 0;
 }
 
 /*------------------------------------------------------------------*/
-void wait_no_key (void)
+void
+wait_no_key (void)
 {
-  int touched,i;
+  int touched, i;
   int start_tick;
   int dummy;
 
-  start_tick=get_ticker();
+  start_tick = get_ticker ();
 
   lw_mouse_reset_control ();
   do
@@ -190,44 +205,45 @@ void wait_no_key (void)
       /*
        * Force a all to poll_keyboard if needed
        */
-      dummy=keypressed();
+      dummy = keypressed ();
 
-      touched=0;
+      touched = 0;
       lw_mouse_update_control ();
       my_poll_joystick ();
-      for (i=0;i<256;++i)
-	if (is_touched_key(i))
-	  touched=1;
+      for (i = 0; i < 256; ++i)
+	if (is_touched_key (i))
+	  touched = 1;
     }
-  while (touched && 
-	 get_ticker()<start_tick+LW_KEYBOARD_WAITNOKEY_TICK_LIMIT);
+  while (touched &&
+	 get_ticker () < start_tick + LW_KEYBOARD_WAITNOKEY_TICK_LIMIT);
 }
 
 /*------------------------------------------------------------------*/
-int wait_key_pressed (void)
+int
+wait_key_pressed (void)
 {
-  int touched=0,i,result=0;
+  int touched = 0, i, result = 0;
   int start_tick;
   int dummy;
 
-  start_tick=get_ticker();
+  start_tick = get_ticker ();
 
   lw_mouse_reset_control ();
-  while ((!touched) && 
-	 get_ticker()<start_tick+LW_KEYBOARD_WAITKEYPRESSED_TICK_LIMIT)
+  while ((!touched) &&
+	 get_ticker () < start_tick + LW_KEYBOARD_WAITKEYPRESSED_TICK_LIMIT)
     {
       /*
        * Force a all to poll_keyboard if needed
        */
-      dummy=keypressed();
+      dummy = keypressed ();
 
       lw_mouse_update_control ();
       my_poll_joystick ();
-      for (i=0;i<256 && !touched;++i)
-	if (is_touched_key(i))
+      for (i = 0; i < 256 && !touched; ++i)
+	if (is_touched_key (i))
 	  {
-	    touched=1;
-	    result=i;
+	    touched = 1;
+	    result = i;
 	  }
     }
 
@@ -236,9 +252,10 @@ int wait_key_pressed (void)
    * is used by allegro as a "modifier" which we do not care about
    * at all
    */
-  if (result>=128) {
-    result-=128;
-  } 
+  if (result >= 128)
+    {
+      result -= 128;
+    }
 
   return result;
 }
@@ -249,23 +266,21 @@ int wait_key_pressed (void)
  * under X, the keyboard functions go crazy. One solution: uninstall
  * and then reinstall the keyboad. It's ugly but it works...
  */
-void lw_keyboard_reset_hack(void)
+void
+lw_keyboard_reset_hack (void)
 {
 #ifdef UNIX
   {
-    int keyboard_state=0;
+    int keyboard_state = 0;
 
-    clear_keybuf();
-    remove_keyboard();
-    keyboard_state=install_keyboard();
+    clear_keybuf ();
+    remove_keyboard ();
+    keyboard_state = install_keyboard ();
 
     if (keyboard_state)
       {
-	log_println_str("Error: unable to reinstall keyboard");
+	log_println_str ("Error: unable to reinstall keyboard");
       }
   }
 #endif
 }
-
-
-
