@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -67,31 +67,30 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-int LW_KEYEXCH_SOCK=-1;
+int LW_KEYEXCH_SOCK = -1;
 
 /*==================================================================*/
 /* static functions                                                 */
 /*==================================================================*/
 
-static int send_keys(int sock, CURSOR *cursors,
-		     unsigned int checksum);
-static int recv_keys(int sock, CURSOR *cursors);
+static int send_keys (int sock, CURSOR * cursors, unsigned int checksum);
+static int recv_keys (int sock, CURSOR * cursors);
 
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-static int send_keys(int sock, CURSOR *cursors,
-		     unsigned int checksum)
+static int
+send_keys (int sock, CURSOR * cursors, unsigned int checksum)
 {
-  int result=0;
+  int result = 0;
   int i;
   LW_NETKEY netkey;
 
-  lw_netkey_reset(&netkey);
+  lw_netkey_reset (&netkey);
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       /*
        * We send informations about cursors who are not network
@@ -99,7 +98,7 @@ static int send_keys(int sock, CURSOR *cursors,
        */
       if (!cursors[i].from_network)
 	{
-	  netkey.key_states[i]=cursors[i].key_state;
+	  netkey.key_states[i] = cursors[i].key_state;
 	}
     }
 
@@ -107,41 +106,42 @@ static int send_keys(int sock, CURSOR *cursors,
    * If there are not enough keys in the buffer, we ask the server
    * to increase the lag
    */
-  if (!lw_netkey_peek(sock,LW_KEYEXCH_LAG_LOWER_LIMIT))
+  if (!lw_netkey_peek (sock, LW_KEYEXCH_LAG_LOWER_LIMIT))
     {
-      netkey.cmd=LW_NETKEY_CMD_INCREASE_LAG;
+      netkey.cmd = LW_NETKEY_CMD_INCREASE_LAG;
     }
 
   /*
    * If there are not enough keys in the buffer, we ask the server
    * to increase the lag
    */
-  if (lw_netkey_peek(sock,LW_KEYEXCH_LAG_UPPER_LIMIT))
+  if (lw_netkey_peek (sock, LW_KEYEXCH_LAG_UPPER_LIMIT))
     {
-      netkey.cmd=LW_NETKEY_CMD_DECREASE_LAG;
+      netkey.cmd = LW_NETKEY_CMD_DECREASE_LAG;
     }
 
   /*
    * Checksum which will help the server to control things and
    * detect consistency problems.
    */
-  netkey.checksum=checksum;
+  netkey.checksum = checksum;
 
-  result=lw_netkey_send(sock,&netkey);
+  result = lw_netkey_send (sock, &netkey);
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-static int recv_keys(int sock, CURSOR *cursors)
+static int
+recv_keys (int sock, CURSOR * cursors)
 {
-  int result=0;
+  int result = 0;
   int i;
   LW_NETKEY netkey;
 
-  result=lw_netkey_recv(sock,&netkey);
+  result = lw_netkey_recv (sock, &netkey);
 
-  for (i=0;i<NB_TEAMS;++i)
+  for (i = 0; i < NB_TEAMS; ++i)
     {
       /*
        * The informations is retrieved from the network for
@@ -150,36 +150,35 @@ static int recv_keys(int sock, CURSOR *cursors)
        * back the information we have sent to him a few game
        * cycles before.
        */
-      cursors[i].key_state=netkey.key_states[i];
+      cursors[i].key_state = netkey.key_states[i];
     }
 
-  if (result) 
+  if (result)
     {
       /*
        * Now we check for checksum errors
        */
-      if (! netkey.checksum)
+      if (!netkey.checksum)
 	{
-	  log_println_str("Error: incorrect checksum, the game is broken, or someone is cheating");
+	  log_println_str
+	    ("Error: incorrect checksum, the game is broken, or someone is cheating");
 	}
-    }      
+    }
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-int lw_keyexch_flush(CURSOR *cursors, unsigned int checksum)
+int
+lw_keyexch_flush (CURSOR * cursors, unsigned int checksum)
 {
-  int result=1;
+  int result = 1;
 
   /*
    * It's important to send keys before we receive them
    */
-  result=result && send_keys(LW_KEYEXCH_SOCK,cursors, checksum);
-  result=result && recv_keys(LW_KEYEXCH_SOCK,cursors);
+  result = result && send_keys (LW_KEYEXCH_SOCK, cursors, checksum);
+  result = result && recv_keys (LW_KEYEXCH_SOCK, cursors);
 
   return result;
 }
-
-
-
