@@ -66,6 +66,7 @@
 #include "startup.h"
 #include "log.h"
 #include "macro.h"
+#include "mutxgen.h"
 
 /*==================================================================*/
 /* constants                                                        */
@@ -86,6 +87,7 @@ FILE *LW_LOG_FILE = NULL;
 /*==================================================================*/
 
 int LW_LOG_BEEP = 1;
+static LW_MUTEX_DATA LOG_MUTEX = { NULL };
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -96,6 +98,8 @@ int LW_LOG_BEEP = 1;
 void
 log_init (void)
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
 #ifndef UNIX
   LW_LOG_FILE = fopen (STARTUP_LOG_PATH, "w");
   if (LW_LOG_FILE == NULL)
@@ -107,24 +111,32 @@ log_init (void)
       LW_LOG_FILE = fopen (LW_LOG_FALLBACK_PATH, "w");
     }
 #endif
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
 void
 log_exit (void)
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
 #ifndef UNIX
   if (LW_LOG_FILE)
     {
       fclose (LW_LOG_FILE);
     }
 #endif
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
 void
 log_print_str (char *str)
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
 #ifndef WIN32
   printf ("%s", str);
 #endif
@@ -134,12 +146,16 @@ log_print_str (char *str)
       fprintf (LW_LOG_FILE, "%s", str);
     }
 #endif
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
 void
 log_print_int (int i)
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
 #ifndef WIN32
   printf ("%d", i);
 #endif
@@ -149,12 +165,16 @@ log_print_int (int i)
       fprintf (LW_LOG_FILE, "%d", i);
     }
 #endif
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
 void
 log_println ()
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
 #ifndef WIN32
   printf ("\n");
 #endif
@@ -165,12 +185,16 @@ log_println ()
       log_flush ();
     }
 #endif
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
 void
 log_println_str (char *str)
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
 #ifndef WIN32
   printf ("%s\n", str);
 #endif
@@ -181,12 +205,16 @@ log_println_str (char *str)
       log_flush ();
     }
 #endif
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
 void
 log_println_int (int i)
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
 #ifndef WIN32
   printf ("%d\n", i);
 #endif
@@ -197,12 +225,16 @@ log_println_int (int i)
       log_flush ();
     }
 #endif
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
 void
 log_flush ()
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
 #ifndef WIN32
   fflush (stdout);
 #endif
@@ -212,12 +244,16 @@ log_flush ()
       fflush (LW_LOG_FILE);
     }
 #endif
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
 void
 log_beep ()
 {
+  lw_mutex_lock (&LOG_MUTEX);
+
   if (LW_LOG_BEEP)
     {
 #ifdef WIN32
@@ -232,6 +268,8 @@ log_beep ()
       fprintf (stderr, "\a");
 #endif
     }
+
+  lw_mutex_unlock (&LOG_MUTEX);
 }
 
 /*------------------------------------------------------------------*/
