@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -72,61 +72,54 @@
 #ifdef ALLEGRO_DJGPP
 
 BEGIN_GFX_DRIVER_LIST
-GFX_DRIVER_VGA
-GFX_DRIVER_MODEX
-GFX_DRIVER_VBEAF
-GFX_DRIVER_VESA2L
-GFX_DRIVER_VESA2B
-GFX_DRIVER_VESA1
-END_GFX_DRIVER_LIST
-
-BEGIN_COLOR_DEPTH_LIST
-COLOR_DEPTH_8
-COLOR_DEPTH_15
-COLOR_DEPTH_16
-COLOR_DEPTH_24
-COLOR_DEPTH_32
-END_COLOR_DEPTH_LIST
-
-BEGIN_DIGI_DRIVER_LIST
-DIGI_DRIVER_SB
-DIGI_DRIVER_SOUNDSCAPE
-DIGI_DRIVER_AUDIODRIVE
-END_DIGI_DRIVER_LIST
-
-BEGIN_MIDI_DRIVER_LIST
-END_MIDI_DRIVER_LIST
-
+  GFX_DRIVER_VGA
+  GFX_DRIVER_MODEX
+  GFX_DRIVER_VBEAF
+  GFX_DRIVER_VESA2L
+  GFX_DRIVER_VESA2B
+  GFX_DRIVER_VESA1
+  END_GFX_DRIVER_LIST
+  BEGIN_COLOR_DEPTH_LIST
+  COLOR_DEPTH_8
+  COLOR_DEPTH_15
+  COLOR_DEPTH_16
+  COLOR_DEPTH_24
+  COLOR_DEPTH_32
+  END_COLOR_DEPTH_LIST
+  BEGIN_DIGI_DRIVER_LIST
+  DIGI_DRIVER_SB
+  DIGI_DRIVER_SOUNDSCAPE
+  DIGI_DRIVER_AUDIODRIVE
+  END_DIGI_DRIVER_LIST BEGIN_MIDI_DRIVER_LIST END_MIDI_DRIVER_LIST
 #endif
-
 /*==================================================================*/
 /* functions                                                        */
 /*==================================================================*/
-
 /*------------------------------------------------------------------*/
-int main (int argc, char **argv)
+  int
+main (int argc, char **argv)
 {
   int init_success;
   int big_data_success;
   int load_dat_success;
   int load_custom_success;
 
-  read_command_line (argc,argv);
+  read_command_line (argc, argv);
 
-  if (lw_basicopt_process("Liquid War - a unique multiplayer wargame"))
+  if (lw_basicopt_process ("Liquid War - a unique multiplayer wargame"))
     {
-      init_success=init_all ();
- 
-      big_data_success=(malloc_big_data ()!=NULL);
-      log_println();
-      load_dat_success=load_dat ();
-      log_println();
-      load_custom_success=load_custom ();
-      log_println();
+      init_success = init_all ();
+
+      big_data_success = (malloc_big_data () != NULL);
+      log_println ();
+      load_dat_success = load_dat ();
+      log_println ();
+      load_custom_success = load_custom ();
+      log_println ();
 
 #ifdef ALLEGRO_DOS
       if (STARTUP_STOP)
-	readkey();
+	readkey ();
       else
 	delay (500);
 #endif
@@ -140,7 +133,7 @@ int main (int argc, char **argv)
       if (!load_custom_success)
 	my_exit (EXIT_CODE_CUSTOM_FAIL);
 
-      order_map();
+      order_map ();
       check_config_range ();
 
       check_free_memory ();
@@ -154,13 +147,10 @@ int main (int argc, char **argv)
 
   return 0;
 }
+
 #ifdef ALLEGRO_WINDOWS
-END_OF_MAIN() 
+END_OF_MAIN ()
 #endif
-
 #ifdef ALLEGRO_UNIX
-     END_OF_MAIN();
+  END_OF_MAIN ();
 #endif
-
-
-     
