@@ -64,6 +64,8 @@
 #include "log.h"
 #include "macro.h"
 #include "serial.h"
+#include "path.h"
+#include "random.h"
 
 /*==================================================================*/
 /* constantes                                                       */
@@ -263,20 +265,18 @@ spread_color_up (BITMAP * bmp, int color1, int color2)
 static int
 check_if_playable (BITMAP * bmp)
 {
-  int x, y, x0, y0;
+  int x = 0, y = 0, x0, y0;
   int unplayable = 0;
   int playable_place = 0;
 
-  for (x = 0; x < bmp->w; ++x)
-    {
-      putpixel (bmp, x, 0, CONSIDERED_AS_DARK);
-      putpixel (bmp, x, bmp->h - 1, CONSIDERED_AS_DARK);
-    }
-  for (y = 0; y < bmp->h; ++y)
-    {
-      putpixel (bmp, 0, y, CONSIDERED_AS_DARK);
-      putpixel (bmp, bmp->w - 1, y, CONSIDERED_AS_DARK);
-    }
+  /*
+   * Now we draw the "outside" of the map. This is usefull
+   * to avoid bugs (core dumps) if the map is not correctly drawn.
+   */
+  hline (bmp, 0, 0, bmp->w - 1, CONSIDERED_AS_DARK);
+  hline (bmp, 0, bmp->h - 1, bmp->w - 1, CONSIDERED_AS_DARK);
+  vline (bmp, 0, 0, bmp->h - 1, CONSIDERED_AS_DARK);
+  vline (bmp, bmp->w - 1, 0, bmp->h - 1, CONSIDERED_AS_DARK);
 
   x0 = y0 = -1;
   for (y = 0; y < bmp->h && y0 < 0; ++y)
@@ -307,6 +307,26 @@ check_if_playable (BITMAP * bmp)
   return (!unplayable);
 }
 
+/*-----------------------------------------------------------------*/
+static void
+fill_with_fg_and_bg (BITMAP * bmp, int fg, int bg)
+{
+  int x, y;
+
+  /*
+   * We set up the real fg and bg color instead of the
+   * CONSIDERED_AS_... constants.
+   */
+  for (y = 0; y < bmp->h; ++y)
+    {
+      for (x = 0; x < bmp->w; ++x)
+	{
+	  putpixel (bmp, x, y,
+		    getpixel (bmp, x, y) == PLAYABLE_AREA ? bg : fg);
+	}
+    }
+}
+
 /*-----------------------------------------------------------------*/
 static void
 convert_to_buffer (BITMAP * bmp, char *buffer, int *size, int *bg_size)
@@ -348,17 +368,16 @@ convert_to_buffer (BITMAP * bmp, char *buffer, int *size, int *bg_size)
 
 /*------------------------------------------------------------------*/
 void *
-lw_map_archive_raw (const char *filename)
+lw_map_archive_raw_bmp (BITMAP * bmp, PALETTE pal, const char *filename)
 {
   int w = 0, h = 0, size, bg_size;
-  BITMAP *bmp, *sub_bmp;
-  PALETTE pal;
+  BITMAP *sub_bmp;
   char *temp = NULL;
   char *result = NULL;
-  char readable_name_buffer[LW_MAP_READABLE_NAME_SIZE + 1];
   static int index = 1;
+  char readable_name_buffer[LW_MAP_READABLE_NAME_SIZE + 1];
+  char system_name_buffer[LW_MAP_SYSTEM_NAME_SIZE + 1];
 
-  bmp = load_bitmap (filename, pal);
   if (bmp)
     {
       sort_light_and_dark (bmp, pal);
@@ -380,7 +399,9 @@ lw_map_archive_raw (const char *filename)
 
   if (temp)
     {
-      result = malloc (size + 8 + LW_MAP_READABLE_NAME_SIZE);
+      result =
+	malloc (size + 8 + LW_MAP_SYSTEM_NAME_SIZE +
+		LW_MAP_READABLE_NAME_SIZE);
       if (result)
 	{
 	  /*
@@ -390,17 +411,37 @@ lw_map_archive_raw (const char *filename)
 				    (short) h);
 
 	  /*
-	   * Then we store its name
+	   * Then we store its system name
+	   */
+	  memset (system_name_buffer, 0, sizeof (system_name_buffer));
+	  LW_MACRO_STRCPY (system_name_buffer,
+			   lw_path_get_system_name (filename));
+	  memcpy (result + 8, system_name_buffer, LW_MAP_SYSTEM_NAME_SIZE);
+
+	  /*
+	   * Then we store its readable name
 	   */
 	  memset (readable_name_buffer, 0, sizeof (readable_name_buffer));
-	  LW_MACRO_SPRINTF1 (readable_name_buffer, "Custom map %d", index++);
-	  memcpy (result + 8, readable_name_buffer,
+	  if (strcmp (filename, "lwmapgen") == 0)
+	    {
+	      /* 
+	       * This is a map generated by lwmapgen, we label it as such.
+	       */
+	      LW_MACRO_SPRINTF0 (readable_name_buffer, "Random map");
+	    }
+	  else
+	    {
+	      LW_MACRO_SPRINTF1 (readable_name_buffer, "Custom map %d",
+				 index++);
+	    }
+	  memcpy (result + 8 + LW_MAP_SYSTEM_NAME_SIZE, readable_name_buffer,
 		  LW_MAP_READABLE_NAME_SIZE);
 
 	  /*
 	   * And at last we write the map itself
 	   */
-	  memcpy (result + 8 + LW_MAP_READABLE_NAME_SIZE, temp, size);
+	  memcpy (result + 8 + LW_MAP_SYSTEM_NAME_SIZE +
+		  LW_MAP_READABLE_NAME_SIZE, temp, size);
 	}
       free_last_big_data_bottom ();
     }
@@ -408,9 +449,26 @@ lw_map_archive_raw (const char *filename)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+void *
+lw_map_archive_raw (const char *filename)
+{
+  BITMAP *bmp;
+  PALETTE pal;
+  void *result = NULL;
+
+  bmp = load_bitmap (filename, pal);
+  if (bmp)
+    {
+      result = lw_map_archive_raw_bmp (bmp, pal, filename);
+    }
+
+  return result;
+}
+
 /*------------------------------------------------------------------*/
 static void *
-lw_map_get_safe (int num, int network)
+lw_map_get_safe (int num, int network, int random)
 {
   void *raw_map = NULL;
 
@@ -420,10 +478,21 @@ lw_map_get_safe (int num, int network)
   if (num < 0)
     num = 0;
 
-  if (network)
-    raw_map = LW_NETWORK_RAW_MAP;
+  if (network && LW_NETWORK_RAW_MAP != NULL)
+    {
+      raw_map = LW_NETWORK_RAW_MAP;
+    }
   else
-    raw_map = RAW_MAP_ORDERED[num];
+    {
+      if (random && LW_RANDOM_RAW_MAP != NULL)
+	{
+	  raw_map = LW_RANDOM_RAW_MAP;
+	}
+      else
+	{
+	  raw_map = RAW_MAP_ORDERED[num];
+	}
+    }
 
   return raw_map;
 }
@@ -431,7 +500,8 @@ lw_map_get_safe (int num, int network)
 /*------------------------------------------------------------------*/
 BITMAP *
 lw_map_create_bicolor (int num, int fg, int bg,
-		       int network, int min_w, int min_h)
+		       int network, int random, int min_w, int min_h,
+		       int *zoom_factor)
 {
   int pos_dst, pos_src, i, j, l, color;
   short w, h;
@@ -440,13 +510,12 @@ lw_map_create_bicolor (int num, int fg, int bg,
   BITMAP *temp;
   void *raw_map;
   int size, surface;
-  int zoom_factor;
   int x, y;
 
-  raw_map = lw_map_get_safe (num, network);
+  raw_map = lw_map_get_safe (num, network, random);
 
   data_src = raw_map;
-  data_src += 8 + LW_MAP_READABLE_NAME_SIZE;
+  data_src += 8 + LW_MAP_SYSTEM_NAME_SIZE + LW_MAP_READABLE_NAME_SIZE;
 
   /* 
    * We read the header (size + geometry)
@@ -454,7 +523,7 @@ lw_map_create_bicolor (int num, int fg, int bg,
   lw_serial_get_map_header (raw_map, &size, &w, &h);
 
   surface = ((int) w) * ((int) h);
-  zoom_factor = calc_zoom_factor (w, h, min_w, min_h);
+  *zoom_factor = calc_zoom_factor (w, h, min_w, min_h);
 
   pos_src = pos_dst = 0;
   temp = my_create_bitmap (w, h);
@@ -465,45 +534,49 @@ lw_map_create_bicolor (int num, int fg, int bg,
       while (pos_src < size && (l = data_src[pos_src++]) != 0)
 	{
 	  if (l > 0)
-	    color = fg;
+	    color = CONSIDERED_AS_DARK;
 	  else
 	    {
 	      l = -l;
-	      color = bg;
+	      color = CONSIDERED_AS_LIGHT;
 	    }
 	  for (i = 0; i < l && pos_dst < surface; ++i)
 	    data_dst[pos_dst++] = color;
 	}
 
       /*
-       * Now we draw the "outside" of the map. This is usefull
-       * to avoid bugs (core dumps) if the map is not correctly drawn.
+       * We check if the map is "playable". Normally unplayable maps
+       * should never make it there but...
        */
-      hline (temp, 0, 0, w - 1, fg);
-      hline (temp, 0, h - 1, w - 1, fg);
-      vline (temp, 0, 0, h - 1, fg);
-      vline (temp, w - 1, 0, h - 1, fg);
-
-      result = my_create_bitmap (w * zoom_factor, h * zoom_factor);
-
-      if (result)
+      if (check_if_playable (temp))
 	{
-	  /*
-	   * Not we magnify the map if needed, so that very small
-	   * maps are interesting to play on fast fancy computers
-	   */
-	  for (y = 0; y < h; ++y)
-	    for (x = 0; x < w; ++x)
-	      {
-		color = getpixel (temp, x, y);
-		for (i = 0; i < zoom_factor; ++i)
-		  for (j = 0; j < zoom_factor; ++j)
-		    {
-		      putpixel (result,
-				x * zoom_factor + j,
-				y * zoom_factor + i, color);
-		    }
-	      }
+	  fill_with_fg_and_bg (temp, fg, bg);
+
+	  result = my_create_bitmap (w * (*zoom_factor), h * (*zoom_factor));
+
+	  if (result)
+	    {
+	      /*
+	       * Not we magnify the map if needed, so that very small
+	       * maps are interesting to play on fast fancy computers
+	       */
+	      for (y = 0; y < h; ++y)
+		for (x = 0; x < w; ++x)
+		  {
+		    color = getpixel (temp, x, y);
+		    for (i = 0; i < *zoom_factor; ++i)
+		      for (j = 0; j < *zoom_factor; ++j)
+			{
+			  putpixel (result,
+				    x * *zoom_factor + j,
+				    y * *zoom_factor + i, color);
+			}
+		  }
+	    }
+	}
+      else
+	{
+	  log_println_str ("Error: unplayable map!");
 	}
 
       destroy_bitmap (temp);
@@ -515,16 +588,17 @@ lw_map_create_bicolor (int num, int fg, int bg,
 /*------------------------------------------------------------------*/
 BITMAP *
 lw_map_create_textured (int num, int fg, int bg,
-			int network, int min_w, int min_h)
+			int network, int random, int min_w, int min_h)
 {
   int x, y, w, h, color;
   BITMAP *result = NULL, *bg_tex, *fg_tex;
   int fg_w, fg_h;
   int bg_w, bg_h;
-
+  int zoom_factor, zoom_factor_fg, zoom_factor_bg;
 
   bg_tex = lw_texture_create_bg (bg);
   fg_tex = lw_texture_create_fg (fg);
+
   if (bg_tex && fg_tex)
     {
       bg_w = bg_tex->w;
@@ -532,18 +606,37 @@ lw_map_create_textured (int num, int fg, int bg,
       fg_w = fg_tex->w;
       fg_h = fg_tex->h;
 
-      result = lw_map_create_bicolor (num, 1, 0, network, min_w, min_h);
+      result =
+	lw_map_create_bicolor (num, 1, 0, network, random,
+			       min_w, min_h, &zoom_factor);
       if (result)
 	{
 	  w = result->w;
 	  h = result->h;
+	  zoom_factor_fg = zoom_factor_bg = zoom_factor;
+	  if (w != zoom_factor * fg_tex->w || h != zoom_factor * fg_tex->h)
+	    {
+	      zoom_factor_fg = 1;
+	    }
+	  if (w != zoom_factor * bg_tex->w || h != zoom_factor * bg_tex->h)
+	    {
+	      zoom_factor_bg = 1;
+	    }
 	  for (y = 0; y < h; ++y)
 	    for (x = 0; x < w; ++x)
 	      {
 		if (getpixel (result, x, y))
-		  color = getpixel (fg_tex, x % fg_w, y % fg_h);
+		  {
+		    color =
+		      getpixel (fg_tex, (x / zoom_factor_fg) % fg_w,
+				(y / zoom_factor_bg) % fg_h);
+		  }
 		else
-		  color = getpixel (bg_tex, x % bg_w, y % bg_h);
+		  {
+		    color =
+		      getpixel (bg_tex, (x / zoom_factor_bg) % bg_w,
+				(y / zoom_factor_bg) % bg_h);
+		  }
 		putpixel (result, x, y, color);
 	      }
 	}
@@ -560,16 +653,36 @@ lw_map_create_textured (int num, int fg, int bg,
 
 /*------------------------------------------------------------------*/
 char *
-lw_map_get_readable_name (int num, int network)
+lw_map_get_system_name (int num, int network, int random)
+{
+  static char result[LW_MAP_SYSTEM_NAME_SIZE + 1];
+  void *raw_map;
+  char *char_ptr;
+
+  raw_map = lw_map_get_safe (num, network, random);
+  char_ptr = (char *) raw_map;
+
+  LW_MACRO_MEMSET0 (result);
+  memcpy (result, char_ptr + 8, LW_MAP_SYSTEM_NAME_SIZE);
+  result[sizeof (result) - 1] = '\0';
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+char *
+lw_map_get_readable_name (int num, int network, int random)
 {
   static char result[LW_MAP_READABLE_NAME_SIZE + 1];
   void *raw_map;
   char *char_ptr;
 
-  raw_map = lw_map_get_safe (num, network);
+  raw_map = lw_map_get_safe (num, network, random);
   char_ptr = (char *) raw_map;
 
-  memcpy (result, char_ptr + 8, LW_MAP_READABLE_NAME_SIZE);
+  LW_MACRO_MEMSET0 (result);
+  memcpy (result, char_ptr + 8 + LW_MAP_SYSTEM_NAME_SIZE,
+	  LW_MAP_READABLE_NAME_SIZE);
   result[sizeof (result) - 1] = '\0';
 
   return result;
@@ -577,13 +690,14 @@ lw_map_get_readable_name (int num, int network)
 
 /*------------------------------------------------------------------*/
 void
-lw_map_get_res (int num, int *w, int *h, int network, int min_w, int min_h)
+lw_map_get_res (int num, int *w, int *h, int network, int random, int min_w,
+		int min_h)
 {
   void *raw_map;
   short res_w, res_h;
   int zoom_factor;
 
-  raw_map = lw_map_get_safe (num, network);
+  raw_map = lw_map_get_safe (num, network, random);
 
   lw_serial_get_map_header (raw_map, NULL, &res_w, &res_h);
 
