@@ -61,6 +61,7 @@
 /* constants                                                        */
 /*==================================================================*/
 
+#define LW_MAP_SYSTEM_NAME_SIZE 16
 #define LW_MAP_READABLE_NAME_SIZE 32
 
 /*==================================================================*/
@@ -68,12 +69,17 @@
 /*==================================================================*/
 
 void *lw_map_archive_raw (const char *filename);
+void *lw_map_archive_raw_bmp (BITMAP * bmp, PALETTE pal,
+			      const char *filename);
 BITMAP *lw_map_create_bicolor (int num, int fg, int bg,
-			       int network, int min_w, int min_h);
+			       int network, int random, int min_w, int min_h,
+			       int *zoom_factor);
 BITMAP *lw_map_create_textured (int num, int fg, int bg,
-				int network, int min_w, int min_h);
-char *lw_map_get_readable_name (int num, int network);
+				int network, int random, int min_w,
+				int min_h);
+char *lw_map_get_system_name (int num, int network, int random);
+char *lw_map_get_readable_name (int num, int network, int random);
 void lw_map_get_res (int num, int *w, int *h,
-		     int network, int min_w, int min_h);
+		     int network, int random, int min_w, int min_h);
 
 #endif
