@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -76,30 +76,31 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int confirm_quit (void)
+int
+confirm_quit (void)
 {
   DIALOG d[3];
 
-  memset(d,0,sizeof(d));
+  memset (d, 0, sizeof (d));
 
-  d[2].proc=NULL;
-  standard_button (d,0,0,2,1);
-  standard_button (d+1,1,0,2,1);
-  d[0].dp=lw_lang_string(LW_LANG_STRING_MENU_EXIT);
+  d[2].proc = NULL;
+  standard_button (d, 0, 0, 2, 1);
+  standard_button (d + 1, 1, 0, 2, 1);
+  d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXIT);
 #ifdef ALLEGRO_DOS
-  d[0].dp=lw_lang_string(LW_LANG_STRING_MENU_EXITDOS);
+  d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXITDOS);
 #endif
 #ifdef ALLEGRO_WINDOWS
-  d[0].dp=lw_lang_string(LW_LANG_STRING_MENU_EXITWINDOWS);
+  d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXITWINDOWS);
 #endif
 #ifdef ALLEGRO_UNIX
-  d[0].dp=lw_lang_string(LW_LANG_STRING_MENU_EXITUNIX);
+  d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXITUNIX);
 #endif
-  d[1].dp=lw_lang_string(LW_LANG_STRING_MENU_BACK);
-  d[0].key='d';
-  d[1].key='w';
+  d[1].dp = lw_lang_string (LW_LANG_STRING_MENU_BACK);
+  d[0].key = 'd';
+  d[1].key = 'w';
 
-  return (my_do_dialog (d,0)==0);
+  return (my_do_dialog (d, 0) == 0);
 }
 
 /*------------------------------------------------------------------*/
@@ -107,90 +108,90 @@ int confirm_quit (void)
 /*------------------------------------------------------------------*/
 
 /*------------------------------------------------------------------*/
-void main_menu (void)
+void
+main_menu (void)
 {
   DIALOG d[11];
-  int i,choix=4,retour=0;
+  int i, choix = 4, retour = 0;
 
-  memset(d,0,sizeof(d));
+  memset (d, 0, sizeof (d));
 
   display_back_image ();
   /*
-    dp=my_init_dialog (d,4);
-    my_update_dialog (dp);
-    shutdown_dialog (dp);
-  */
+     dp=my_init_dialog (d,4);
+     my_update_dialog (dp);
+     shutdown_dialog (dp);
+   */
   my_fade_in ();
 
-  while (retour!=MENU_EXIT)
+  while (retour != MENU_EXIT)
     {
-      for (i=0; i<6; ++i)
-	standard_button (d+i+4,0,i,1,6);
+      for (i = 0; i < 6; ++i)
+	standard_button (d + i + 4, 0, i, 1, 6);
 
-      quick_buttons(d);
-      d[MENU_QUICK_BACK].flags=D_HIDDEN;
-      d[MENU_QUICK_MAIN].flags=D_HIDDEN;
-      d[4].dp=lw_lang_string(LW_LANG_STRING_MENU_PLAY);
-      d[5].dp=lw_lang_string(LW_LANG_STRING_MENU_NETGAME);
-      d[6].dp=lw_lang_string(LW_LANG_STRING_MENU_MAP);
-      d[7].dp=lw_lang_string(LW_LANG_STRING_MENU_TEAMS);
-      d[8].dp=lw_lang_string(LW_LANG_STRING_MENU_OPTIONS);
-      d[9].dp=lw_lang_string(LW_LANG_STRING_MENU_ABOUT);
-      d[10].proc=0;
+      quick_buttons (d);
+      d[MENU_QUICK_BACK].flags = D_HIDDEN;
+      d[MENU_QUICK_MAIN].flags = D_HIDDEN;
+      d[4].dp = lw_lang_string (LW_LANG_STRING_MENU_PLAY);
+      d[5].dp = lw_lang_string (LW_LANG_STRING_MENU_NETGAME);
+      d[6].dp = lw_lang_string (LW_LANG_STRING_MENU_MAP);
+      d[7].dp = lw_lang_string (LW_LANG_STRING_MENU_TEAMS);
+      d[8].dp = lw_lang_string (LW_LANG_STRING_MENU_OPTIONS);
+      d[9].dp = lw_lang_string (LW_LANG_STRING_MENU_ABOUT);
+      d[10].proc = 0;
 
-      choix=my_do_dialog (d,choix);
+      choix = my_do_dialog (d, choix);
       switch (choix)
 	{
 	case -1:
 	case MENU_QUICK_QUIT:
-	  if (confirm_quit())
-	    retour=MENU_EXIT;
+	  if (confirm_quit ())
+	    retour = MENU_EXIT;
 	  break;
 	case MENU_QUICK_PLAY:
-	  retour=MENU_PLAY;
+	  retour = MENU_PLAY;
 	  break;
 	case 4:
-	  LW_NETWORK_ON=0;
-	  retour=play_sequence ();
+	  LW_NETWORK_ON = 0;
+	  retour = play_sequence ();
 	  break;
 	case 5:
 #ifndef ALLEGRO_DOS
-	  retour=network_game ();
+	  retour = network_game ();
 #else
-	  retour=error_no_network_support ();
+	  retour = error_no_network_support ();
 #endif
 	  break;
 	case 6:
-	  retour=choose_map ();
+	  retour = choose_map ();
 	  break;
 	case 7:
-	  retour=choose_teams ();
+	  retour = choose_teams ();
 	  break;
 	case 8:
-	  retour=options ();
+	  retour = options ();
 	  break;
 	case 9:
-	  retour=lw_about ();
+	  retour = lw_about ();
 	  break;
 	}
       /*
        * We handle the quick top-right "Play" button
        */
-      if (retour==MENU_PLAY)
+      if (retour == MENU_PLAY)
 	{
 	  if (LW_NETWORK_ON)
 	    {
 #ifndef ALLEGRO_DOS
-	      retour=netplay_sequence ();
+	      retour = netplay_sequence ();
 #else
-	      retour=play_sequence ();
+	      retour = play_sequence ();
 #endif
 	    }
 	  else
 	    {
-	      retour=play_sequence ();
+	      retour = play_sequence ();
 	    }
 	}
     }
 }
-
