@@ -55,9 +55,11 @@
 #include "bigdata.h"
 #include "config.h"
 #include "map.h"
+#include "maptex.h"
 #include "mesh.h"
 #include "network.h"
 #include "log.h"
+#include "random.h"
 
 /*==================================================================*/
 /* types                                                            */
@@ -334,6 +336,7 @@ create_mesh (void)
   int retour = 0, i;
   BITMAP *map;
   MESHER *mesher;
+  int zoom_factor = 1;
 
   CURRENT_MESH = NULL;
   CURRENT_MESH_SIZE = 0;
@@ -345,8 +348,10 @@ create_mesh (void)
 	MESH_FG,
 	MESH_BG,
 	LW_NETWORK_ON,
+	LW_RANDOM_ON,
 	MIN_MAP_RES_W[LW_CONFIG_CURRENT_RULES.min_map_res],
-	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res])) != NULL)
+	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res],
+	&zoom_factor)) != NULL)
     {
       mesher = create_first_mesher (map);
       if (mesher != NULL)
@@ -378,13 +383,15 @@ create_mesh_bitmap (int mode)
   BITMAP *result;
   int i, j, color;
 
-  result = lw_map_create_textured
+  result = lw_maptex_create_map
     (CONFIG_LEVEL_MAP,
      CONFIG_LEVEL_FG,
      CONFIG_LEVEL_BG,
      LW_NETWORK_ON,
+     LW_RANDOM_ON,
      MIN_MAP_RES_W[LW_CONFIG_CURRENT_RULES.min_map_res],
-     MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res]);
+     MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res],
+     CONFIG_USE_DEFAULT_TEXTURE);
   if (result)
     {
       for (i = 0; i < CURRENT_MESH_SIZE; ++i)
