@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -59,6 +59,7 @@
 #include "message.h"
 #include "ticker.h"
 #include "viewport.h"
+#include "macro.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -67,112 +68,95 @@
 #define MESSAGE_MAX 12
 #define MESSAGE_SIZE 64
 
-static int MESSAGE_NB=0;
-static char MESSAGE[MESSAGE_MAX][MESSAGE_SIZE+1];
+static int MESSAGE_NB = 0;
+static char MESSAGE[MESSAGE_MAX][MESSAGE_SIZE + 1];
 static int MESSAGE_TICKER[MESSAGE_MAX];
 static int MESSAGE_DISPLAYED[MESSAGE_MAX];
-static int MESSAGE_DELAY=1000;
+static int MESSAGE_DELAY = 1000;
 
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-void clear_message (void)
+void
+clear_message (void)
 {
- MESSAGE_NB=0;
+  MESSAGE_NB = 0;
 }
 
 /*------------------------------------------------------------------*/
-void display_message (void)
+void
+display_message (void)
 {
- int i,h,j,new_ticker;
+  int i, h, j, new_ticker;
 
- new_ticker=get_ticker();
- for (i=0;i<MESSAGE_NB;++i)
-     if (!MESSAGE_DISPLAYED[i])
-        {
-         MESSAGE_DISPLAYED[i]=1;
-         MESSAGE_TICKER[i]=new_ticker+MESSAGE_DELAY*(i+1);
-        }
+  new_ticker = get_ticker ();
+  for (i = 0; i < MESSAGE_NB; ++i)
+    if (!MESSAGE_DISPLAYED[i])
+      {
+	MESSAGE_DISPLAYED[i] = 1;
+	MESSAGE_TICKER[i] = new_ticker + MESSAGE_DELAY * (i + 1);
+      }
 
- while (MESSAGE_NB>0
-       && MESSAGE_DISPLAYED[0]
-       && new_ticker>MESSAGE_TICKER[0])
+  while (MESSAGE_NB > 0
+	 && MESSAGE_DISPLAYED[0] && new_ticker > MESSAGE_TICKER[0])
     {
-    for (i=0; i<MESSAGE_NB-1; ++i)
-        for (j=0;j<MESSAGE_SIZE+1;++j)
-            {
-            MESSAGE[i][j]=MESSAGE[i+1][j];
-            MESSAGE_TICKER[i]=MESSAGE_TICKER[i+1];
-            }
-    MESSAGE_NB--;
+      for (i = 0; i < MESSAGE_NB - 1; ++i)
+	for (j = 0; j < MESSAGE_SIZE + 1; ++j)
+	  {
+	    MESSAGE[i][j] = MESSAGE[i + 1][j];
+	    MESSAGE_TICKER[i] = MESSAGE_TICKER[i + 1];
+	  }
+      MESSAGE_NB--;
     }
 
- h=text_height (font);
- text_mode (-1);
- for (i=0;i<MESSAGE_NB;++i)
-     textout (NEXT_SCREEN,font,MESSAGE[i],
-             NEXT_SCREEN->w-text_length(font,MESSAGE[i]),
-             NEXT_SCREEN->h-(MESSAGE_NB-i)*h,-1);
+  h = text_height (font);
+  text_mode (-1);
+  for (i = 0; i < MESSAGE_NB; ++i)
+    textout (NEXT_SCREEN, font, MESSAGE[i],
+	     NEXT_SCREEN->w - text_length (font, MESSAGE[i]),
+	     NEXT_SCREEN->h - (MESSAGE_NB - i) * h, -1);
 }
 
 /*------------------------------------------------------------------*/
-void message_str(char *str)
+void
+message_str (char *str)
 {
- int i,j;
+  int i;
 
- if (MESSAGE_NB==MESSAGE_MAX)
+  while (MESSAGE_NB >= MESSAGE_MAX)
     {
-    for (i=0; i<MESSAGE_NB-1; ++i)
-        for (j=0;j<MESSAGE_SIZE+1;++j)
-            {
-            MESSAGE[i][j]=MESSAGE[i+1][j];
-            MESSAGE_TICKER[i]=MESSAGE_TICKER[i+1]-MESSAGE_DELAY;
-            }
-    MESSAGE_NB--;
+      for (i = 0; i < MESSAGE_NB - 1; ++i)
+	{
+	  LW_MACRO_STRCPY (MESSAGE[i], MESSAGE[i + 1]);
+	  MESSAGE_TICKER[i] = MESSAGE_TICKER[i + 1] - MESSAGE_DELAY;
+	}
+      MESSAGE_NB--;
     }
 
- MESSAGE_DISPLAYED[MESSAGE_NB]=0;
- j=0;
- while (str[j] && j<MESSAGE_SIZE)
-      {
-       MESSAGE[MESSAGE_NB][j]=str[j];
-       j++;
-      }
- MESSAGE[MESSAGE_NB++][j]=0;
+  MESSAGE_DISPLAYED[MESSAGE_NB] = 0;
+  LW_MACRO_STRCPY (MESSAGE[MESSAGE_NB], str);
+
+  MESSAGE_NB++;
 }
 
 /*------------------------------------------------------------------*/
-void message_int (int val)
+void
+message_int (int val)
 {
- static char buffer[34];
+  static char buffer[33 + 1];
 
- buffer[0]=0;
- sprintf (buffer,"%d",val);
- message_str (buffer);
+  LW_MACRO_SPRINTF1 (buffer, "%d", val);
+  message_str (buffer);
 }
 
 /*------------------------------------------------------------------*/
-void message_str_int (char *str, int val)
+void
+message_str_int (char *str, int val)
 {
- int i,n;
- static char buf1[34];
- static char buf2[MESSAGE_SIZE+1];
+  static char buffer[MESSAGE_SIZE + 33 + 1];
 
- buf1[0]=0;
- sprintf (buf1,"%d",val);
- i=0;
- n=MESSAGE_SIZE-strlen(buf1);
- while (str[i] && i<n)
-      {
-       buf2[i]=str[i];
-       i++;
-      }
- buf2[i]=0;
- strcat (buf2,buf1);
- message_str (buf2);
+  LW_MACRO_SPRINTF2 (buffer, "%s%d", str, val);
+  message_str (buffer);
 }
-
-
-
