@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -63,36 +63,30 @@
 /* types                                                            */
 /*==================================================================*/
 
-extern void LW_ASM_FUNC boost_move_fighters (FIGHTER *current_army,
-					    int current_army_size,
-					    PLACE *current_area,
-					    int current_area_w,
-					    int *active_fighters,
-					    int *attack,
-					    int *defense,
-					    int *new_health,
-					    int max_fighter_health_1,
-					    int sens,
-					    int start,
-					    int neg_global_clock,
-					    int *fighter_move_xy,
-					    int *fighter_move_offset,
-					    char *current_area_back_data,
-					    char *current_area_disp_data,
-					    int *color_first_entry,
-					    int colors_per_team,
-					    int *local_dir,
-					    int temp1,
-					    int temp2,
-					    int temp3,
-					    int temp4,
-					    int temp5,
-					    int temp6,
-					    int temp7,
-					    int temp8);
+extern void LW_ASM_FUNC boost_move_fighters (FIGHTER * current_army,
+					     int current_army_size,
+					     PLACE * current_area,
+					     int current_area_w,
+					     int *active_fighters,
+					     int *attack,
+					     int *defense,
+					     int *new_health,
+					     int max_fighter_health_1,
+					     int sens,
+					     int start,
+					     int neg_global_clock,
+					     int *fighter_move_xy,
+					     int *fighter_move_offset,
+					     char *current_area_back_data,
+					     char *current_area_disp_data,
+					     int *color_first_entry,
+					     int colors_per_team,
+					     int *local_dir,
+					     int temp1,
+					     int temp2,
+					     int temp3,
+					     int temp4,
+					     int temp5,
+					     int temp6, int temp7, int temp8);
 
 #endif
-
-
-
-
