@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -58,7 +58,7 @@
 /*==================================================================*/
 
 #define LW_NETKEY_CMD_NONE          'n'
-#define LW_NETKEY_CMD_QUIT          'q'     
+#define LW_NETKEY_CMD_QUIT          'q'
 #define LW_NETKEY_CMD_INCREASE_LAG  '+'
 #define LW_NETKEY_CMD_DECREASE_LAG  '-'
 
@@ -73,19 +73,20 @@
  */
 typedef struct
 {
-  int key_states[NB_TEAMS];     /* the keys states as in the cursor */
-  int cmd;                      /* a special command                */
-  int arg;                      /* an argument for the command      */
+  int key_states[NB_TEAMS];	/* the keys states as in the cursor */
+  int cmd;			/* a special command                */
+  int arg;			/* an argument for the command      */
   unsigned int checksum;
-} LW_NETKEY;
+}
+LW_NETKEY;
 
 /*==================================================================*/
 /* functions                                                        */
 /*==================================================================*/
 
-void lw_netkey_reset(LW_NETKEY *netkey);
-int lw_netkey_send(int sock,LW_NETKEY *netkey);
-int lw_netkey_recv(int sock,LW_NETKEY *netkey);
-int lw_netkey_peek(int sock,int num);
+void lw_netkey_reset (LW_NETKEY * netkey);
+int lw_netkey_send (int sock, LW_NETKEY * netkey);
+int lw_netkey_recv (int sock, LW_NETKEY * netkey);
+int lw_netkey_peek (int sock, int num);
 
 #endif
