@@ -96,27 +96,34 @@ lw_netmap_send (int sock, void *netmap)
   header = (unsigned char *) netmap;
   if (lw_sock_send_buffer (sock, ptr, 8))
     {
-      if (lw_sock_send_buffer (sock, ptr + 8, LW_MAP_READABLE_NAME_SIZE))
+      if (lw_sock_send_buffer (sock, ptr + 8, LW_MAP_SYSTEM_NAME_SIZE))
 	{
-	  lw_serial_get_map_header (netmap, &size, NULL, NULL);
-
-	  result = 1;
-	  sent = 0;
-	  while (sent < size && result)
+	  if (lw_sock_send_buffer
+	      (sock, ptr + 8 + LW_MAP_SYSTEM_NAME_SIZE,
+	       LW_MAP_READABLE_NAME_SIZE))
 	    {
-	      to_send = size - sent;
-	      if (to_send > LW_NETMAP_CHUNK_SIZE)
+	      lw_serial_get_map_header (netmap, &size, NULL, NULL);
+
+	      result = 1;
+	      sent = 0;
+	      while (sent < size && result)
 		{
-		  to_send = LW_NETMAP_CHUNK_SIZE;
-		}
-	      if (lw_sock_send_buffer
-		  (sock, ptr + 8 + LW_MAP_READABLE_NAME_SIZE + sent, to_send))
-		{
-		  sent += to_send;
-		}
-	      else
-		{
-		  result = 0;
+		  to_send = size - sent;
+		  if (to_send > LW_NETMAP_CHUNK_SIZE)
+		    {
+		      to_send = LW_NETMAP_CHUNK_SIZE;
+		    }
+		  if (lw_sock_send_buffer
+		      (sock,
+		       ptr + 8 + LW_MAP_SYSTEM_NAME_SIZE +
+		       LW_MAP_READABLE_NAME_SIZE + sent, to_send))
+		    {
+		      sent += to_send;
+		    }
+		  else
+		    {
+		      result = 0;
+		    }
 		}
 	    }
 	}
@@ -133,7 +140,7 @@ int
 lw_netmap_recv (int sock, void **netmap)
 {
   int result = 0;
-  char buffer[8 + LW_MAP_READABLE_NAME_SIZE];
+  char buffer[8 + LW_MAP_SYSTEM_NAME_SIZE + LW_MAP_READABLE_NAME_SIZE];
   int size;
   short w, h;
   char *ptr;
@@ -149,40 +156,50 @@ lw_netmap_recv (int sock, void **netmap)
 
   if (lw_sock_recv_buffer (sock, buffer, 8))
     {
-      if (lw_sock_recv_buffer (sock, buffer + 8, LW_MAP_READABLE_NAME_SIZE))
+      if (lw_sock_recv_buffer (sock, buffer + 8, LW_MAP_SYSTEM_NAME_SIZE))
 	{
-	  lw_serial_get_map_header ((void *) buffer, &size, &w, &h);
-
-	  /*
-	   * A map under 3 bytes is reasonably not a "real" map...
-	   */
-	  if (size >= 10)
+	  if (lw_sock_recv_buffer
+	      (sock, buffer + 8 + LW_MAP_SYSTEM_NAME_SIZE,
+	       LW_MAP_READABLE_NAME_SIZE))
 	    {
-	      ptr = malloc (size + 8 + LW_MAP_READABLE_NAME_SIZE);
-	      if (ptr != NULL)
+	      lw_serial_get_map_header ((void *) buffer, &size, &w, &h);
+
+	      /*
+	       * A map under 3 bytes is reasonably not a "real" map...
+	       */
+	      if (size >= 10)
 		{
-		  memcpy (ptr, buffer, 8 + LW_MAP_READABLE_NAME_SIZE);
-
-		  result = 1;
-		  received = 0;
-		  while (received < size && result)
+		  ptr =
+		    malloc (size + 8 + LW_MAP_SYSTEM_NAME_SIZE +
+			    LW_MAP_READABLE_NAME_SIZE);
+		  if (ptr != NULL)
 		    {
-		      to_receive = size - received;
-		      if (to_receive > LW_NETMAP_CHUNK_SIZE)
-			{
-			  to_receive = LW_NETMAP_CHUNK_SIZE;
-			}
+		      memcpy (ptr, buffer,
+			      8 + LW_MAP_SYSTEM_NAME_SIZE +
+			      LW_MAP_READABLE_NAME_SIZE);
 
-		      if (lw_sock_recv_buffer
-			  (sock,
-			   ptr + 8 + LW_MAP_READABLE_NAME_SIZE + received,
-			   to_receive))
+		      result = 1;
+		      received = 0;
+		      while (received < size && result)
 			{
-			  received += to_receive;
-			}
-		      else
-			{
-			  result = 0;
+			  to_receive = size - received;
+			  if (to_receive > LW_NETMAP_CHUNK_SIZE)
+			    {
+			      to_receive = LW_NETMAP_CHUNK_SIZE;
+			    }
+
+			  if (lw_sock_recv_buffer
+			      (sock,
+			       ptr + 8 + LW_MAP_SYSTEM_NAME_SIZE +
+			       LW_MAP_READABLE_NAME_SIZE + received,
+			       to_receive))
+			    {
+			      received += to_receive;
+			    }
+			  else
+			    {
+			      result = 0;
+			    }
 			}
 		    }
 		}
