@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -53,7 +53,6 @@
 /*==================================================================*/
 
 #include <stdlib.h>
-#include <malloc.h>
 #include <string.h>
 #include <ctype.h>
 
@@ -63,12 +62,12 @@
 /* static functions declaration                                     */
 /*==================================================================*/
 
-static int eat_space(char **message);
-static int read_separator(char **message);
-static char *read_word(char **message); 
-static int get_code(char **message);
-static int get_argc(char *message);
-static char **get_argv(char *message,int argc);
+static int eat_space (char **message);
+static int read_separator (char **message);
+static char *read_word (char **message);
+static int get_code (char **message);
+static int get_argc (char *message);
+static char **get_argv (char *message, int argc);
 
 /*==================================================================*/
 /* functions                                                        */
@@ -88,11 +87,12 @@ static char **get_argv(char *message,int argc);
 /*
  * Skip spaces, tabs and the likes.
  */
-static int eat_space(char **message)
+static int
+eat_space (char **message)
 {
-  int result=0;
+  int result = 0;
 
-  while (isspace(**message))
+  while (isspace (**message))
     {
       result++;
       ++(*message);
@@ -105,17 +105,18 @@ static int eat_space(char **message)
 /*
  * Reads a separator token. The separator is ',' 
  */
-static int read_separator(char **message)
+static int
+read_separator (char **message)
 {
-  int result=0;
+  int result = 0;
 
-  eat_space(message);
-  if ((**message)==',')
+  eat_space (message);
+  if ((**message) == ',')
     {
       result++;
       ++(*message);
     }
-  eat_space(message);
+  eat_space (message);
 
   return result;
 }
@@ -125,63 +126,65 @@ static int read_separator(char **message)
  * Reads a word, a number, basically what's between separators.
  * The returned pointer must be disallocated with a "free".
  */
-static char *read_word(char **message)
+static char *
+read_word (char **message)
 {
-  char *begin=NULL;
-  char *result=NULL;
+  char *begin = NULL;
+  char *result = NULL;
   int len;
   char quote_char;
 
-  eat_space(message);
+  eat_space (message);
 
-  quote_char=**message;
+  quote_char = **message;
 
-  if (quote_char == '\"' || quote_char == '\'') 
-    {      
+  if (quote_char == '\"' || quote_char == '\'')
+    {
       /*
        * We handle strings quoted with ' or ".
        * No escape character is handled yet...
-       */ 
-      ++(*message);      
+       */
+      ++(*message);
 
-      begin=*message;
+      begin = *message;
 
-      while ((**message)!=quote_char && (**message)!='\0')
+      while ((**message) != quote_char && (**message) != '\0')
 	{
 	  ++(*message);
 	}
 
-      len=(*message)-begin;
+      len = (*message) - begin;
 
-      ++(*message);      
+      ++(*message);
     }
   else
     {
-      begin=*message;
+      begin = *message;
 
-      while ((!isspace(**message)) && (**message)!=',' && (**message)!='\0')
+      while ((!isspace (**message)) && (**message) != ','
+	     && (**message) != '\0')
 	{
 	  ++(*message);
 	}
 
-      len=(*message)-begin;
+      len = (*message) - begin;
     }
 
-  if (len>=0)
+  if (len >= 0)
     {
-      result=(char *) malloc(len+1);
-      if (result!=NULL)
+      result = (char *) malloc (len + 1);
+      if (result != NULL)
 	{
-          if (len>0)
+	  if (len > 0)
 	    {
-	      strncpy(result,begin,len);
+	      strncpy (result, begin, len);
 	    }
-	  result[len]=0;
+	  result[len] = 0;
 
-	  lw_netmess_cleanup_arg(result);
+	  lw_netmess_cleanup_arg (result);
 	}
     }
-  eat_space(message);
+  eat_space (message);
 
   return result;
 }
@@ -190,113 +193,118 @@ static char *read_word(char **message)
 /*
  * Returns the code of the command.
  */
-static int get_code(char **message)
+static int
+get_code (char **message)
 {
   char *command;
-  int result=LW_NETMESS_CODE_UNKNOWN;
+  int result = LW_NETMESS_CODE_UNKNOWN;
 
-  if (read_separator(message)==0)
+  if (read_separator (message) == 0)
     {
-      if ((command=read_word(message))!=NULL)
+      if ((command = read_word (message)) != NULL)
 	{
-	  if (strcasecmp(command,LW_NETMESS_TEXT_OK)==0)
+	  if (strcasecmp (command, LW_NETMESS_TEXT_OK) == 0)
 	    {
-	      result=LW_NETMESS_CODE_OK;
+	      result = LW_NETMESS_CODE_OK;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_ERR)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_ERR) == 0)
 	    {
-	      result=LW_NETMESS_CODE_ERR;
+	      result = LW_NETMESS_CODE_ERR;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_PING)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_PING) == 0)
 	    {
-	      result=LW_NETMESS_CODE_PING;
+	      result = LW_NETMESS_CODE_PING;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_ECHO)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_ECHO) == 0)
 	    {
-	      result=LW_NETMESS_CODE_ECHO;
+	      result = LW_NETMESS_CODE_ECHO;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_PROGRAM)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_PROGRAM) == 0)
 	    {
-	      result=LW_NETMESS_CODE_PROGRAM;
+	      result = LW_NETMESS_CODE_PROGRAM;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_VERSION)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_VERSION) == 0)
 	    {
-	      result=LW_NETMESS_CODE_VERSION;
+	      result = LW_NETMESS_CODE_VERSION;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_PASSWORD)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_PASSWORD) == 0)
 	    {
-	      result=LW_NETMESS_CODE_PASSWORD;
+	      result = LW_NETMESS_CODE_PASSWORD;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_FREE)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_FREE) == 0)
 	    {
-	      result=LW_NETMESS_CODE_FREE;
+	      result = LW_NETMESS_CODE_FREE;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_TEAM)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_TEAM) == 0)
 	    {
-	      result=LW_NETMESS_CODE_TEAM;
+	      result = LW_NETMESS_CODE_TEAM;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_READY)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_READY) == 0)
 	    {
-	      result=LW_NETMESS_CODE_READY;
+	      result = LW_NETMESS_CODE_READY;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_START)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_START) == 0)
 	    {
-	      result=LW_NETMESS_CODE_START;
+	      result = LW_NETMESS_CODE_START;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_WAITING)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_WAITING) == 0)
 	    {
-	      result=LW_NETMESS_CODE_WAITING;
+	      result = LW_NETMESS_CODE_WAITING;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_NEXT)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_NEXT) == 0)
 	    {
-	      result=LW_NETMESS_CODE_NEXT;
+	      result = LW_NETMESS_CODE_NEXT;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_TEAMSTARTINFO)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_TEAMSTARTINFO) == 0)
 	    {
-	      result=LW_NETMESS_CODE_TEAMSTARTINFO;
+	      result = LW_NETMESS_CODE_TEAMSTARTINFO;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_WHO)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_WHO) == 0)
 	    {
-	      result=LW_NETMESS_CODE_WHO;
+	      result = LW_NETMESS_CODE_WHO;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_LOCAL)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_LOCAL) == 0)
 	    {
-	      result=LW_NETMESS_CODE_LOCAL;
+	      result = LW_NETMESS_CODE_LOCAL;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_NETWORK)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_NETWORK) == 0)
 	    {
-	      result=LW_NETMESS_CODE_NETWORK;
+	      result = LW_NETMESS_CODE_NETWORK;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_NOBODY)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_NOBODY) == 0)
 	    {
-	      result=LW_NETMESS_CODE_NOBODY;
+	      result = LW_NETMESS_CODE_NOBODY;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_SENDMAP)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_SENDMAP) == 0)
 	    {
-	      result=LW_NETMESS_CODE_SENDMAP;
+	      result = LW_NETMESS_CODE_SENDMAP;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_RECVMAP)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_RECVMAP) == 0)
 	    {
-	      result=LW_NETMESS_CODE_RECVMAP;
+	      result = LW_NETMESS_CODE_RECVMAP;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_SENDCONFIG)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_SENDCONFIG) == 0)
 	    {
-	      result=LW_NETMESS_CODE_SENDCONFIG;
+	      result = LW_NETMESS_CODE_SENDCONFIG;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_RECVCONFIG)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_RECVCONFIG) == 0)
 	    {
-	      result=LW_NETMESS_CODE_RECVCONFIG;
+	      result = LW_NETMESS_CODE_RECVCONFIG;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_CHATTALK)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_CHATTALK) == 0)
 	    {
-	      result=LW_NETMESS_CODE_CHATTALK;
+	      result = LW_NETMESS_CODE_CHATTALK;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_CHATLISTEN)==0)
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_CHATLISTEN) == 0)
 	    {
-	      result=LW_NETMESS_CODE_CHATLISTEN;
+	      result = LW_NETMESS_CODE_CHATLISTEN;
+	    }
+	  else if (strcasecmp (command, LW_NETMESS_TEXT_QUIT) == 0)
+	    {
+	      result = LW_NETMESS_CODE_QUIT;
 	    }
 
-	  free(command);
+	  free (command);
 	}
     }
 
@@ -309,39 +317,40 @@ static int get_code(char **message)
  * It's a little different from the C convention used in main(),
  * since 0 means "0 args" (whereas in main() 0 args corresponds to argc==1).
  */
-int get_argc(char *message)
+static int
+get_argc (char *message)
 {
-  int result=0;
-  char *word=NULL;
-  int null_arg=0;
+  int result = 0;
+  char *word = NULL;
+  int null_arg = 0;
 
-  if (read_separator(&message)==0)
+  if (read_separator (&message) == 0)
     {
-      if (message[0]=='\0')
+      if (message[0] == '\0')
 	{
-	  null_arg=1;
+	  null_arg = 1;
 	}
 
-      word=read_word(&message);
-      if (word!=NULL)
+      word = read_word (&message);
+      if (word != NULL)
 	{
-	  free(word);
-	  result=1;
-	  while (read_separator(&message)==1)
+	  free (word);
+	  result = 1;
+	  while (read_separator (&message) == 1)
 	    {
-	      word=read_word(&message);
-	      if (word!=NULL)
+	      word = read_word (&message);
+	      if (word != NULL)
 		{
-		  free(word);
+		  free (word);
 		  result++;
 		}
 	    }
 	}
     }
 
-  if (result==1 && null_arg)
+  if (result == 1 && null_arg)
     {
-      result=0;
+      result = 0;
     }
 
   return result;
@@ -351,37 +360,38 @@ int get_argc(char *message)
 /*
  * Parses all the arguments of the message.
  */
-char **get_argv(char *message,int argc)
+static char **
+get_argv (char *message, int argc)
 {
-  char **result=NULL;
+  char **result = NULL;
   char *word;
-  int i=0;
+  int i = 0;
 
-  if (argc>0 && read_separator(&message)==0)
+  if (argc > 0 && read_separator (&message) == 0)
     {
-      result=(char **) malloc(argc*sizeof(char *));
-      if (result!=NULL)
+      result = (char **) malloc (argc * sizeof (char *));
+      if (result != NULL)
 	{
-	  word=read_word(&message);
-	  if (word!=NULL)
+	  word = read_word (&message);
+	  if (word != NULL)
 	    {
-	      result[i]=word;
-	      i=1;
-	      while (i<argc && read_separator(&message)==1)
+	      result[i] = word;
+	      i = 1;
+	      while (i < argc && read_separator (&message) == 1)
 		{
-		  word=read_word(&message);
-		  if (word!=NULL)
+		  word = read_word (&message);
+		  if (word != NULL)
 		    {
-		      result[i]=word;
+		      result[i] = word;
 		      i++;
 		    }
 		}
 	    }
 	}
-      if (i!=argc)
+      if (i != argc)
 	{
-	  free(result);
-	  result=NULL;
+	  free (result);
+	  result = NULL;
 	}
     }
 
@@ -397,16 +407,17 @@ char **get_argv(char *message,int argc)
  * return a LW_NETMESS_CODE_UNKNOWN type with no args at all.
  * It's important to free the obtained pointer with lw_netmess_free.
  */
-LW_NETMESS *lw_netmess_read(char *message)
+LW_NETMESS *
+lw_netmess_read (char *message)
 {
-  LW_NETMESS *result=NULL;
+  LW_NETMESS *result = NULL;
 
-  result=(LW_NETMESS *) malloc(sizeof(LW_NETMESS));
-  if (result!=NULL)
+  result = (LW_NETMESS *) malloc (sizeof (LW_NETMESS));
+  if (result != NULL)
     {
-      result->code=get_code(&message);   
-      result->argc=get_argc(message);
-      result->argv=get_argv(message,result->argc);
+      result->code = get_code (&message);
+      result->argc = get_argc (message);
+      result->argv = get_argv (message, result->argc);
     }
 
   return result;
@@ -417,21 +428,22 @@ LW_NETMESS *lw_netmess_read(char *message)
  * To be called after each successfull call to lw_netmess_read
  * This function calls free() internally.
  */
-void lw_netmess_free(LW_NETMESS *ptr)
+void
+lw_netmess_free (LW_NETMESS * ptr)
 {
   int i;
 
-  if (ptr!=NULL)
+  if (ptr != NULL)
     {
-      if (ptr->argv!=NULL)
+      if (ptr->argv != NULL)
 	{
-	  for (i=0;i<ptr->argc;++i)
+	  for (i = 0; i < ptr->argc; ++i)
 	    {
-	      free(ptr->argv[i]);
+	      free (ptr->argv[i]);
 	    }
-	  if (ptr->argc>0)
+	  if (ptr->argc > 0)
 	    {
-	      free(ptr->argv);
+	      free (ptr->argv);
 	    }
 	}
     }
@@ -442,20 +454,19 @@ void lw_netmess_free(LW_NETMESS *ptr)
  * Cleanups strings so that they can be used as arguments in
  * network messages
  */
-void lw_netmess_cleanup_arg(char *string)
+void
+lw_netmess_cleanup_arg (char *string)
 {
   char *pos;
   unsigned char c;
 
-  pos=string;
-  while ((c=*pos)!='\0')
-    {      
-      if (c<32 || c>127 ||
-	  strchr("'\",",c))
-      {
-	(*pos)=' ';
-      }	  
+  pos = string;
+  while ((c = *pos) != '\0')
+    {
+      if (c < 32 || c > 127 || strchr ("'\",", c))
+	{
+	  (*pos) = ' ';
+	}
       pos++;
-    }  
+    }
 }
-
