@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -61,7 +61,7 @@
 /* structs                                                          */
 /*==================================================================*/
 
-typedef struct 
+typedef struct
 {
   int active;
   int network;
@@ -69,8 +69,9 @@ typedef struct
   int control_type;
   int color;
   int part;
-  char name[NAME_SIZE+1];
-} LW_WHO;
+  char name[NAME_SIZE + 1];
+}
+LW_WHO;
 
 /*==================================================================*/
 /* globals                                                          */
@@ -85,8 +86,7 @@ extern void *LW_NETWORK_RAW_MAP;
 /* functions                                                        */
 /*==================================================================*/
 
-extern void lw_network_attribute_colors();
-extern void lw_network_attribute_parts();
+extern void lw_network_attribute_colors ();
+extern void lw_network_attribute_parts ();
 
 #endif
-
