@@ -58,6 +58,7 @@
 #include "palette.h"
 #include "network.h"
 #include "mouse.h"
+#include "texture.h"
 
 /*==================================================================*/
 /* constantes                                                       */
@@ -176,7 +177,7 @@ set_raw_texture_palette (void *ptr, int first)
   char *data;
 
   data = ptr;
-  data += 4;
+  data += 4 + LW_TEXTURE_SYSTEM_NAME_SIZE;
   for (i = first; i < first + 32; ++i)
     {
       GLOBAL_PALETTE[i].r = *(data++);
@@ -233,36 +234,94 @@ set_mono_texture_palette (int num, int first)
 void
 set_bg_texture_palette (int num)
 {
-  if (num >= CHOOSE_COLOR_NUMBER)
+  if (num < CHOOSE_COLOR_NUMBER)
     {
-      if (LOADED_TEXTURE)
-	set_raw_texture_palette (RAW_TEXTURE
-				 [num - CHOOSE_COLOR_NUMBER],
-				 BG_TEXTURE_FIRST_COLOR);
-      else
-	set_mono_texture_palette (BG_TEXTURE_DEFAULT_COLOR,
-				  BG_TEXTURE_FIRST_COLOR);
+      set_mono_texture_palette (num, BG_TEXTURE_FIRST_COLOR);
     }
   else
-    set_mono_texture_palette (num, BG_TEXTURE_FIRST_COLOR);
+    {
+      if (num >= CHOOSE_COLOR_NUMBER
+	  && num < CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER)
+	{
+	  if (LOADED_TEXTURE)
+	    {
+	      set_raw_texture_palette (RAW_TEXTURE
+				       [num - CHOOSE_COLOR_NUMBER],
+				       BG_TEXTURE_FIRST_COLOR);
+	    }
+	  else
+	    {
+	      set_mono_texture_palette (BG_TEXTURE_DEFAULT_COLOR,
+					BG_TEXTURE_FIRST_COLOR);
+	    }
+	}
+
+      if (num >= CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER
+	  && num <
+	  CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER + RAW_MAPTEX_NUMBER)
+	{
+	  if (LOADED_MAPTEX)
+	    {
+	      set_raw_texture_palette (RAW_MAPTEX
+				       [num -
+					(CHOOSE_COLOR_NUMBER +
+					 RAW_TEXTURE_NUMBER)],
+				       BG_TEXTURE_FIRST_COLOR);
+	    }
+	  else
+	    {
+	      set_mono_texture_palette (BG_TEXTURE_DEFAULT_COLOR,
+					BG_TEXTURE_FIRST_COLOR);
+	    }
+	}
+    }
 }
 
 /*------------------------------------------------------------------*/
 void
 set_fg_texture_palette (int num)
 {
-  if (num >= CHOOSE_COLOR_NUMBER)
+  if (num < CHOOSE_COLOR_NUMBER)
     {
-      if (LOADED_TEXTURE)
-	set_raw_texture_palette (RAW_TEXTURE
-				 [num - CHOOSE_COLOR_NUMBER],
-				 FG_TEXTURE_FIRST_COLOR);
-      else
-	set_mono_texture_palette (FG_TEXTURE_DEFAULT_COLOR,
-				  FG_TEXTURE_FIRST_COLOR);
+      set_mono_texture_palette (num, FG_TEXTURE_FIRST_COLOR);
     }
   else
-    set_mono_texture_palette (num, FG_TEXTURE_FIRST_COLOR);
+    {
+      if (num >= CHOOSE_COLOR_NUMBER
+	  && num < CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER)
+	{
+	  if (LOADED_TEXTURE)
+	    {
+	      set_raw_texture_palette (RAW_TEXTURE
+				       [num - CHOOSE_COLOR_NUMBER],
+				       FG_TEXTURE_FIRST_COLOR);
+	    }
+	  else
+	    {
+	      set_mono_texture_palette (FG_TEXTURE_DEFAULT_COLOR,
+					FG_TEXTURE_FIRST_COLOR);
+	    }
+	}
+
+      if (num >= CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER
+	  && num <
+	  CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER + RAW_MAPTEX_NUMBER)
+	{
+	  if (LOADED_MAPTEX)
+	    {
+	      set_raw_texture_palette (RAW_MAPTEX
+				       [num -
+					(CHOOSE_COLOR_NUMBER +
+					 RAW_TEXTURE_NUMBER)],
+				       FG_TEXTURE_FIRST_COLOR);
+	    }
+	  else
+	    {
+	      set_mono_texture_palette (FG_TEXTURE_DEFAULT_COLOR,
+					FG_TEXTURE_FIRST_COLOR);
+	    }
+	}
+    }
 }
 
 /*------------------------------------------------------------------*/
