@@ -63,6 +63,7 @@
 #include "game.h"
 #include "gfxmode.h"
 #include "palette.h"
+#include "maptex.h"
 #include "play.h"
 #include "score.h"
 #include "sound.h"
@@ -72,6 +73,8 @@
 #include "lang.h"
 #include "mouse.h"
 #include "log.h"
+#include "network.h"
+#include "random.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -137,8 +140,12 @@ play_sequence_ex (void)
    * we set up the 256 color palette so that it corresponds to
    * the textures the user has chosen
    */
-  set_bg_texture_palette (CONFIG_LEVEL_BG);
-  set_fg_texture_palette (CONFIG_LEVEL_FG);
+  lw_maptex_set_fg_palette (CONFIG_LEVEL_MAP, CONFIG_LEVEL_FG,
+			    LW_NETWORK_ON, LW_RANDOM_ON,
+			    CONFIG_USE_DEFAULT_TEXTURE);
+  lw_maptex_set_bg_palette (CONFIG_LEVEL_MAP, CONFIG_LEVEL_BG,
+			    LW_NETWORK_ON, LW_RANDOM_ON,
+			    CONFIG_USE_DEFAULT_TEXTURE);
   /*
    * we calculate how many teams are playing
    */
