@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -66,7 +66,8 @@ typedef struct
   int start;
   int record_number;
   int total_time;
-} PROFILE_REC;
+}
+PROFILE_REC;
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -83,68 +84,72 @@ static int LOGIC_NUMBER;
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-void reset_all_profile (void)
+void
+reset_all_profile (void)
 {
- int i;
+  int i;
 
- for (i=0;i<MAX_PROFILE;++i)
-     reset_profile(i);
+  for (i = 0; i < MAX_PROFILE; ++i)
+    reset_profile (i);
 }
 
 /*------------------------------------------------------------------*/
-void reset_profile (int indice)
+void
+reset_profile (int indice)
 {
- DISPLAY_NUMBER=
- LOGIC_NUMBER=0;
- PROFILE_DATA[indice].record_number=
- PROFILE_DATA[indice].total_time=0;
+  DISPLAY_NUMBER = LOGIC_NUMBER = 0;
+  PROFILE_DATA[indice].record_number = PROFILE_DATA[indice].total_time = 0;
 }
 
 /*------------------------------------------------------------------*/
-void start_profile (int indice)
+void
+start_profile (int indice)
 {
- PROFILE_DATA[indice].start=get_ticker();
+  PROFILE_DATA[indice].start = get_ticker ();
 }
 
 /*------------------------------------------------------------------*/
-void stop_profile (int indice)
+void
+stop_profile (int indice)
 {
- PROFILE_DATA[indice].record_number++;
- PROFILE_DATA[indice].total_time +=get_ticker()
-                                 -PROFILE_DATA[indice].start;
- if (PROFILE_DATA[indice].record_number>=PROFILE_LIMIT)
+  PROFILE_DATA[indice].record_number++;
+  PROFILE_DATA[indice].total_time += get_ticker ()
+    - PROFILE_DATA[indice].start;
+  if (PROFILE_DATA[indice].record_number >= PROFILE_LIMIT)
     {
-     PROFILE_DATA[indice].record_number/=2;
-     PROFILE_DATA[indice].total_time/=2;
+      PROFILE_DATA[indice].record_number /= 2;
+      PROFILE_DATA[indice].total_time /= 2;
     }
 }
 
 /*------------------------------------------------------------------*/
-int get_profile (int indice)
+int
+get_profile (int indice)
 {
- if (PROFILE_DATA[indice].record_number>0)
+  if (PROFILE_DATA[indice].record_number > 0)
     return (PROFILE_DATA[indice].total_time
-           /PROFILE_DATA[indice].record_number);
- else
-     return 0;
+	    / PROFILE_DATA[indice].record_number);
+  else
+    return 0;
 }
 
 /*------------------------------------------------------------------*/
-void update_logic_rate(int logic_number)
+void
+update_logic_rate (int logic_number)
 {
- DISPLAY_NUMBER++;
- LOGIC_NUMBER+=logic_number;
+  DISPLAY_NUMBER++;
+  LOGIC_NUMBER += logic_number;
 
- if (DISPLAY_NUMBER>PROFILE_LIMIT)
+  if (DISPLAY_NUMBER > PROFILE_LIMIT)
     {
-     DISPLAY_NUMBER/=2;
-     LOGIC_NUMBER/=2;
+      DISPLAY_NUMBER /= 2;
+      LOGIC_NUMBER /= 2;
     }
 }
 
 /*------------------------------------------------------------------*/
-int get_logic_rate(void)
+int
+get_logic_rate (void)
 {
- return((get_profile(GLOBAL_PROFILE)*DISPLAY_NUMBER)/LOGIC_NUMBER);
+  return ((get_profile (GLOBAL_PROFILE) * DISPLAY_NUMBER) / LOGIC_NUMBER);
 }
-
