@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -62,40 +62,42 @@
 #include "netmap.h"
 #include "netconf.h"
 #include "protocol.h"
+#include "macro.h"
 
 /*==================================================================*/
 /* static functions                                                 */
 /*==================================================================*/
 
-static int recv_ok(int sock);
+static int recv_ok (int sock);
 
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-static int recv_ok(int sock)
+static int
+recv_ok (int sock)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
   int ret;
   LW_NETMESS *netmess;
-  
-  while ((ret=lw_sock_recv_str(sock,message))==0);
-    
-  if (ret>0)
+
+  while ((ret = lw_sock_recv_str (sock, message)) == 0);
+
+  if (ret > 0)
     {
-      netmess=lw_netmess_read(message);
-      if (netmess!=NULL)
+      netmess = lw_netmess_read (message);
+      if (netmess != NULL)
 	{
-	  if (netmess->code==LW_NETMESS_CODE_OK && netmess->argc==0)
+	  if (netmess->code == LW_NETMESS_CODE_OK && netmess->argc == 0)
 	    {
-	      result=1;
+	      result = 1;
 	    }
-	  lw_netmess_free(netmess);
+	  lw_netmess_free (netmess);
 	}
     }
-    
+
 
   return result;
 }
@@ -105,15 +107,16 @@ static int recv_ok(int sock)
  * Sends a dummy "PING" message to the server, to check that the
  * connection is working OK.
  */
-int lw_protocol_do_ping (int sock)
+int
+lw_protocol_do_ping (int sock)
 {
-  int result=0;
+  int result = 0;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_PING))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_PING))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -126,17 +129,18 @@ int lw_protocol_do_ping (int sock)
  * prevent a liquidwar client to connect itself on something else
  * than a real liquidwar server.
  */
-int lw_protocol_tell_program (int sock, char *program)
+int
+lw_protocol_tell_program (int sock, char *program)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
-  sprintf(message,"%s '%s'",LW_NETMESS_TEXT_PROGRAM,program);
-  if (lw_sock_send_str(sock,message))
+  LW_MACRO_SPRINTF2 (message, "%s '%s'", LW_NETMESS_TEXT_PROGRAM, program);
+  if (lw_sock_send_str (sock, message))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -147,17 +151,18 @@ int lw_protocol_tell_program (int sock, char *program)
 /*
  * Sends the version of the client to the server.
  */
-int lw_protocol_tell_version (int sock, char *version)
+int
+lw_protocol_tell_version (int sock, char *version)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
-  sprintf(message,"%s '%s'",LW_NETMESS_TEXT_VERSION,version);
-  if (lw_sock_send_str(sock,message))
+  LW_MACRO_SPRINTF2 (message, "%s '%s'", LW_NETMESS_TEXT_VERSION, version);
+  if (lw_sock_send_str (sock, message))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -168,17 +173,18 @@ int lw_protocol_tell_version (int sock, char *version)
 /*
  * Sends the game password to the server.
  */
-int lw_protocol_tell_password (int sock, char *password)
+int
+lw_protocol_tell_password (int sock, char *password)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
-  sprintf(message,"%s '%s'",LW_NETMESS_TEXT_PASSWORD,password);
-  if (lw_sock_send_str(sock,message))
+  LW_MACRO_SPRINTF2 (message, "%s '%s'", LW_NETMESS_TEXT_PASSWORD, password);
+  if (lw_sock_send_str (sock, message))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -189,28 +195,29 @@ int lw_protocol_tell_password (int sock, char *password)
 /*
  * Asks the server how many players can connect to it.
  */
-int lw_protocol_ask_free_teams (int sock,int *nb)
+int
+lw_protocol_ask_free_teams (int sock, int *nb)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
   int ret;
   LW_NETMESS *netmess;
 
-  *nb=0;
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_FREE))
+  *nb = 0;
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_FREE))
     {
-      while ((ret=lw_sock_recv_str(sock,message))==0);
-      if (ret>0)
+      while ((ret = lw_sock_recv_str (sock, message)) == 0);
+      if (ret > 0)
 	{
-	  netmess=lw_netmess_read(message);
-	  if (netmess!=NULL)
+	  netmess = lw_netmess_read (message);
+	  if (netmess != NULL)
 	    {
-	      if (netmess->code==LW_NETMESS_CODE_OK && netmess->argc==1)
+	      if (netmess->code == LW_NETMESS_CODE_OK && netmess->argc == 1)
 		{
-		  *nb=atoi(netmess->argv[0]);
-		  result=1;
+		  *nb = atoi (netmess->argv[0]);
+		  result = 1;
 		}
-	      lw_netmess_free(netmess);
+	      lw_netmess_free (netmess);
 	    }
 	}
     }
@@ -222,22 +229,19 @@ int lw_protocol_ask_free_teams (int sock,int *nb)
 /*
  * Inform the server that this player will be playing.
  */
-int lw_protocol_reserve_team (int sock, int num, 
-			      int control_type, char *name)
+int
+lw_protocol_reserve_team (int sock, int num, int control_type, char *name)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
-  sprintf(message,"%s %d,%d,'%s'",
-	  LW_NETMESS_TEXT_TEAM,
-	  num,
-	  control_type,
-	  name);
-  if (lw_sock_send_str(sock,message))
+  LW_MACRO_SPRINTF4 (message, "%s %d,%d,'%s'",
+		     LW_NETMESS_TEXT_TEAM, num, control_type, name);
+  if (lw_sock_send_str (sock, message))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -248,60 +252,59 @@ int lw_protocol_reserve_team (int sock, int num,
 /*
  * Ask the server who is playing on a given channel
  */
-int lw_protocol_ask_who (int sock, 
-			 int num,
-			 LW_WHO *who)
+int
+lw_protocol_ask_who (int sock, int num, LW_WHO * who)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
   int ret;
   LW_NETMESS *netmess;
 
-  who->active=0;
-  who->network=0;
-  who->server_id=-1;
-  who->name[0]='\0';
+  who->active = 0;
+  who->network = 0;
+  who->server_id = -1;
+  who->name[0] = '\0';
 
-  sprintf(message,"%s %d",LW_NETMESS_TEXT_WHO,num);
-  if (lw_sock_send_str(sock,message))
+  LW_MACRO_SPRINTF2 (message, "%s %d", LW_NETMESS_TEXT_WHO, num);
+  if (lw_sock_send_str (sock, message))
     {
-      while ((ret=lw_sock_recv_str(sock,message))==0);
-      if (ret>0)
+      while ((ret = lw_sock_recv_str (sock, message)) == 0);
+      if (ret > 0)
 	{
-	  netmess=lw_netmess_read(message);
-	  if (netmess!=NULL)
+	  netmess = lw_netmess_read (message);
+	  if (netmess != NULL)
 	    {
 	      switch (netmess->code)
 		{
 		case LW_NETMESS_CODE_NOBODY:
-		  if (netmess->argc==0)
+		  if (netmess->argc == 0)
 		    {
 		      /*
 		       * We leave the server id to the default -1 value
 		       */
-		      result=1;
+		      result = 1;
 		    }
 		  break;
 		case LW_NETMESS_CODE_NETWORK:
-		  who->network=1;
+		  who->network = 1;
 		  /*
 		   * no "break" here since the only difference between
 		   * the LOCAL and NETWORK messages is that the network
 		   * flag is set to 1 in the "NETWORK" case.
 		   */
 		case LW_NETMESS_CODE_LOCAL:
-		  if (netmess->argc==3)
+		  if (netmess->argc == 3)
 		    {
-		      who->active=1;
-		      who->server_id=atoi(netmess->argv[0]);
-		      who->control_type=atoi(netmess->argv[1]);
-		      strncpy(who->name,netmess->argv[2],NAME_SIZE);
-		      who->name[NAME_SIZE]='\0';
-		      result=1;
+		      who->active = 1;
+		      who->server_id = atoi (netmess->argv[0]);
+		      who->control_type = atoi (netmess->argv[1]);
+		      strncpy (who->name, netmess->argv[2], NAME_SIZE);
+		      who->name[NAME_SIZE] = '\0';
+		      result = 1;
 		    }
 		  break;
 		}
-	      lw_netmess_free(netmess);
+	      lw_netmess_free (netmess);
 	    }
 	}
     }
@@ -313,17 +316,18 @@ int lw_protocol_ask_who (int sock,
 /*
  * Sends the selected map to the server
  */
-int lw_protocol_send_map (int sock, void *map)
+int
+lw_protocol_send_map (int sock, void *map)
 {
-  int result=0;
+  int result = 0;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_SENDMAP))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_SENDMAP))
     {
-      if (lw_netmap_send(sock,map))
+      if (lw_netmap_send (sock, map))
 	{
-	  if (recv_ok(sock))
+	  if (recv_ok (sock))
 	    {
-	      result=1;
+	      result = 1;
 	    }
 	}
     }
@@ -335,17 +339,18 @@ int lw_protocol_send_map (int sock, void *map)
 /*
  * Receives the map from the server
  */
-int lw_protocol_recv_map (int sock, void **map)
+int
+lw_protocol_recv_map (int sock, void **map)
 {
-  int result=0;
+  int result = 0;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_RECVMAP))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_RECVMAP))
     {
-      if (lw_netmap_recv(sock,map))
+      if (lw_netmap_recv (sock, map))
 	{
-	  if (recv_ok(sock))
+	  if (recv_ok (sock))
 	    {
-	      result=1;
+	      result = 1;
 	    }
 	}
     }
@@ -357,21 +362,22 @@ int lw_protocol_recv_map (int sock, void **map)
 /*
  * Sends the config to the server
  */
-int lw_protocol_send_config (int sock)
+int
+lw_protocol_send_config (int sock)
 {
-  int result=0;
+  int result = 0;
   LW_NETCONF config;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_SENDCONFIG))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_SENDCONFIG))
     {
 
-      memcpy(&config,&LW_CONFIG_CURRENT_RULES,sizeof(LW_NETCONF));
+      memcpy (&config, &LW_CONFIG_CURRENT_RULES, sizeof (LW_NETCONF));
 
-      if (lw_netconf_send(sock,&config))
+      if (lw_netconf_send (sock, &config))
 	{
-	  if (recv_ok(sock))
+	  if (recv_ok (sock))
 	    {
-	      result=1;
+	      result = 1;
 	    }
 	}
     }
@@ -383,20 +389,21 @@ int lw_protocol_send_config (int sock)
 /*
  * Receives the config from the server
  */
-int lw_protocol_recv_config (int sock)
+int
+lw_protocol_recv_config (int sock)
 {
-  int result=0;
+  int result = 0;
   LW_NETCONF config;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_RECVCONFIG))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_RECVCONFIG))
     {
-      if (lw_netconf_recv(sock,&config))
+      if (lw_netconf_recv (sock, &config))
 	{
-	  if (recv_ok(sock))
+	  if (recv_ok (sock))
 	    {
-	      memcpy(&LW_CONFIG_CURRENT_RULES,&config,sizeof(LW_NETCONF));
+	      memcpy (&LW_CONFIG_CURRENT_RULES, &config, sizeof (LW_NETCONF));
 
-	      result=1;
+	      result = 1;
 	    }
 	}
     }
@@ -408,15 +415,16 @@ int lw_protocol_recv_config (int sock)
 /*
  * Tell the server that the client is ready to play
  */
-int lw_protocol_i_am_ready (int sock)
+int
+lw_protocol_i_am_ready (int sock)
 {
-  int result=0;
+  int result = 0;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_READY))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_READY))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -427,9 +435,10 @@ int lw_protocol_i_am_ready (int sock)
 /*
  * Tells the server one is waiting for the game to start
  */
-int lw_protocol_waiting (int sock, int *waited_teams)
+int
+lw_protocol_waiting (int sock, int *waited_teams)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
   int ret;
   LW_NETMESS *netmess;
@@ -447,20 +456,20 @@ int lw_protocol_waiting (int sock, int *waited_teams)
    * (*waited_teams)=NB_TEAMS;
    */
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_WAITING))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_WAITING))
     {
-      while ((ret=lw_sock_recv_str(sock,message))==0);
-      if (ret>0)
+      while ((ret = lw_sock_recv_str (sock, message)) == 0);
+      if (ret > 0)
 	{
-	  netmess=lw_netmess_read(message);
-	  if (netmess!=NULL)
+	  netmess = lw_netmess_read (message);
+	  if (netmess != NULL)
 	    {
-	      if (netmess->code==LW_NETMESS_CODE_OK && netmess->argc==1)
+	      if (netmess->code == LW_NETMESS_CODE_OK && netmess->argc == 1)
 		{
-		  *waited_teams=atoi(netmess->argv[0]);
-		  result=1;
+		  *waited_teams = atoi (netmess->argv[0]);
+		  result = 1;
 		}
-	      lw_netmess_free(netmess);
+	      lw_netmess_free (netmess);
 	    }
 	}
     }
@@ -472,15 +481,16 @@ int lw_protocol_waiting (int sock, int *waited_teams)
 /*
  * Forces the server to start the game
  */
-int lw_protocol_force_start (int sock)
+int
+lw_protocol_force_start (int sock)
 {
-  int result=0;
+  int result = 0;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_START))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_START))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -491,15 +501,16 @@ int lw_protocol_force_start (int sock)
 /*
  * Sends a "NEXT" message
  */
-int lw_protocol_next (int sock)
+int
+lw_protocol_next (int sock)
 {
-  int result=0;
+  int result = 0;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_NEXT))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_NEXT))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -510,40 +521,42 @@ int lw_protocol_next (int sock)
 /*
  * Sends a "TEAMSTARTINFO" message
  */
-int lw_protocol_ask_teamstartinfo (int sock, int team,
-				   LW_TEAMSTARTINFO *team_start_info)
+int
+lw_protocol_ask_teamstartinfo (int sock, int team,
+			       LW_TEAMSTARTINFO * team_start_info)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
   int ret;
   LW_NETMESS *netmess;
 
-  lw_teamstartinfo_reset(team_start_info);
+  lw_teamstartinfo_reset (team_start_info);
 
-  sprintf(message,"%s %d",LW_NETMESS_TEXT_TEAMSTARTINFO,team);
-  if (lw_sock_send_str(sock,message))
+  LW_MACRO_SPRINTF2 (message, "%s %d", LW_NETMESS_TEXT_TEAMSTARTINFO, team);
+  if (lw_sock_send_str (sock, message))
     {
-      while ((ret=lw_sock_recv_str(sock,message))==0);
-      if (ret>0)
+      while ((ret = lw_sock_recv_str (sock, message)) == 0);
+      if (ret > 0)
 	{
-	  netmess=lw_netmess_read(message);
-	  if (netmess!=NULL)
+	  netmess = lw_netmess_read (message);
+	  if (netmess != NULL)
 	    {
 	      switch (netmess->code)
 		{
 		case LW_NETMESS_CODE_OK:
-		  if (netmess->argc==3)
+		  if (netmess->argc == 3)
 		    {
-		      team_start_info->active=atoi(netmess->argv[0]);
-		      team_start_info->start=atoi(netmess->argv[1]);
-		      strncpy(team_start_info->name,netmess->argv[2],NAME_SIZE);
-		      team_start_info->name[NAME_SIZE]='\0';
+		      team_start_info->active = atoi (netmess->argv[0]);
+		      team_start_info->start = atoi (netmess->argv[1]);
+		      strncpy (team_start_info->name, netmess->argv[2],
+			       NAME_SIZE);
+		      team_start_info->name[NAME_SIZE] = '\0';
 
-		      result=1;
+		      result = 1;
 		    }
 		  break;
 		}
-	      lw_netmess_free(netmess);
+	      lw_netmess_free (netmess);
 	    }
 	}
     }
@@ -555,20 +568,19 @@ int lw_protocol_ask_teamstartinfo (int sock, int team,
 /*
  * Sends a "CHATTALK" message
  */
-int lw_protocol_chat_talk(int sock, char *text)
+int
+lw_protocol_chat_talk (int sock, char *text)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
-  sprintf(message,"%s '%s'",
-	  LW_NETMESS_TEXT_CHATTALK,
-	  text);
+  LW_MACRO_SPRINTF2 (message, "%s '%s'", LW_NETMESS_TEXT_CHATTALK, text);
 
-  if (lw_sock_send_str(sock,message))
+  if (lw_sock_send_str (sock, message))
     {
-      if (recv_ok(sock))
+      if (recv_ok (sock))
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
@@ -579,21 +591,21 @@ int lw_protocol_chat_talk(int sock, char *text)
 /*
  * Sends a "CHATLISTEN" message
  */
-int lw_protocol_chat_listen(int sock, 
-			    LW_CHAT_HISTORY *chat_history)
+int
+lw_protocol_chat_listen (int sock, LW_CHAT_HISTORY * chat_history)
 {
-  int result=0;
+  int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
   int ret;
   LW_NETMESS *netmess;
 
-  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_CHATLISTEN))
+  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_CHATLISTEN))
     {
-      while ((ret=lw_sock_recv_str(sock,message))==0);
-      if (ret>0)
+      while ((ret = lw_sock_recv_str (sock, message)) == 0);
+      if (ret > 0)
 	{
-	  netmess=lw_netmess_read(message);
-	  if (netmess!=NULL)
+	  netmess = lw_netmess_read (message);
+	  if (netmess != NULL)
 	    {
 	      switch (netmess->code)
 		{
@@ -604,21 +616,20 @@ int lw_protocol_chat_listen(int sock,
 		      /*
 		       * No message, we do nothing
 		       */
-		      result=1;
+		      result = 1;
 		      break;
 		    case 2:
 		      /*
 		       * Message received, enqueue it
 		       */
-		      lw_chat_push(chat_history,
-				   netmess->argv[0],
-				   netmess->argv[1]);
-		      result=1;
+		      lw_chat_push (chat_history,
+				    netmess->argv[0], netmess->argv[1]);
+		      result = 1;
 		      break;
 		    }
 		  break;
 		}
-	      lw_netmess_free(netmess);
+	      lw_netmess_free (netmess);
 	    }
 	}
     }
@@ -626,7 +637,23 @@ int lw_protocol_chat_listen(int sock,
   return result;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Sends a "QUIT" message to the server, in case it wants to make
+ * the difference between a client that disconnects on purpose
+ * and someones that has network problems.
+ */
+int
+lw_protocol_quit (int sock)
+{
+  int result = 0;
 
+  lw_sock_send_str (sock, LW_NETMESS_TEXT_QUIT);
 
+  /*
+   * We leave result to 0, the sockets needs to be closed wether
+   * the QUIT message was sent or not.
+   */
 
-
+  return result;
+}
