@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -65,6 +65,7 @@
 #include "log.h"
 #include "wwwsrv.h"
 #include "thrdgen.h"
+#include "macro.h"
 
 /*==================================================================*/
 /* constants                                                        */
@@ -78,6 +79,7 @@
 #define LW_SERVER_IDENT_PASSWORD   "password"
 #define LW_SERVER_IDENT_COMMENT    "comment"
 #define LW_SERVER_IDENT_LOG        "log"
+#define LW_SERVER_IDENT_CALLBACK   "callback"
 
 /*==================================================================*/
 /* globals                                                          */
@@ -87,13 +89,14 @@
 /* fonctions                                                        */
 /*==================================================================*/
 
-static int get_nb_teams();
-static int get_lag();
-static int get_port();
-static int get_privacy(char *metaserver);
-static char *get_metaserver();
-static char *get_password();
-static char *get_comment();
+static int get_nb_teams ();
+static int get_lag ();
+static int get_port ();
+static int get_privacy (char *metaserver);
+static char *get_metaserver ();
+static char *get_password ();
+static char *get_comment ();
+static char *get_callback ();
 
 /*------------------------------------------------------------------*/
 /*
@@ -101,35 +104,36 @@ static char *get_comment();
  * it checks the command line parameters, and if the number
  * of teams has not be told, then it prompts the user for it.
  */
-static int get_nb_teams()
+static int
+get_nb_teams ()
 {
   int i;
   char str_i[33];
-  int result=0;
+  int result = 0;
   char c;
 
-  for (i=1;i<=NB_TEAMS;++i)
+  for (i = 1; i <= NB_TEAMS; ++i)
     {
-      sprintf(str_i,"%d",i);
-      if (exist_argument(str_i))
+      LW_MACRO_SPRINTF1 (str_i, "%d", i);
+      if (exist_argument (str_i))
 	{
-	  result=i;
+	  result = i;
 	}
     }
 
-  if (result<2 || result>NB_TEAMS)
+  if (result < 2 || result > NB_TEAMS)
     {
-      log_print_str("How many teams will connect to this server? ");
+      log_print_str ("How many teams will connect to this server? ");
 
-      while ((c=getchar())=='\n');
+      while ((c = getchar ()) == '\n');
 
-      if (c>='2' && c<='0'+NB_TEAMS)
+      if (c >= '2' && c <= '0' + NB_TEAMS)
 	{
-	  result=c-'0';
+	  result = c - '0';
 
-	  log_print_str("Use \"-");
-	  log_print_int(result);
-	  log_println_str("\" to get rid of this question.");
+	  log_print_str ("Use \"-");
+	  log_print_int (result);
+	  log_println_str ("\" to get rid of this question.");
 	}
     }
 
@@ -144,16 +148,17 @@ static int get_nb_teams()
  * key strokes and the moment when he will receive them back from
  * the server, along with the information from other players.
  */
-static int get_lag()
+static int
+get_lag ()
 {
-  int result=LW_SERVER_DEFAULT_LAG;
+  int result = LW_SERVER_DEFAULT_LAG;
 
-  if (exist_argument(LW_SERVER_IDENT_LAG))
+  if (exist_argument (LW_SERVER_IDENT_LAG))
     {
-      result=get_argument_int(LW_SERVER_IDENT_LAG);
-      if (result<0)
+      result = get_argument_int (LW_SERVER_IDENT_LAG);
+      if (result < 0)
 	{
-	  result=0;
+	  result = 0;
 	}
     }
 
@@ -164,16 +169,17 @@ static int get_lag()
 /*
  * Returns the port which should be used to communicate with clients
  */
-static int get_port()
+static int
+get_port ()
 {
-  int result=LW_SERVER_DEFAULT_PORT;
+  int result = LW_SERVER_DEFAULT_PORT;
 
-  if (exist_argument(LW_SERVER_IDENT_PORT))
+  if (exist_argument (LW_SERVER_IDENT_PORT))
     {
-      result=get_argument_int(LW_SERVER_IDENT_PORT);
-      if (result<=0)
+      result = get_argument_int (LW_SERVER_IDENT_PORT);
+      if (result <= 0)
 	{
-	  result=LW_SERVER_DEFAULT_PORT;
+	  result = LW_SERVER_DEFAULT_PORT;
 	}
     }
 
@@ -185,13 +191,14 @@ static int get_port()
  * This function returns 1 if the server should register on
  * the meta server and 0 if it should not do it
  */
-static int get_privacy(char *metaserver)
+static int
+get_privacy (char *metaserver)
 {
-  int result=0;
-  int chosen=0;
+  int result = 0;
+  int chosen = 0;
   char c;
 
-  if (exist_argument(LW_SERVER_IDENT_PUBLIC))
+  if (exist_argument (LW_SERVER_IDENT_PUBLIC))
     {
       /*
        * The command line explicitely says -public,
@@ -201,7 +208,7 @@ static int get_privacy(char *metaserver)
       result = 1;
     }
 
-  if (exist_argument(LW_SERVER_IDENT_PRIVATE))
+  if (exist_argument (LW_SERVER_IDENT_PRIVATE))
     {
       /*
        * The command line explicitely says -private,
@@ -216,24 +223,24 @@ static int get_privacy(char *metaserver)
        * no command line option, we ask the question
        * interactively
        */
-      log_print_str("Register on \"");
-      log_print_str(metaserver);
-      log_print_str("\" (y/n)? ");
+      log_print_str ("Register on \"");
+      log_print_str (metaserver);
+      log_print_str ("\" (y/n)? ");
 
-      while ((c=getchar())=='\n');
+      while ((c = getchar ()) == '\n');
 
-      if (c == 'y' || c =='Y') 
+      if (c == 'y' || c == 'Y')
 	{
-	  result=1;
+	  result = 1;
 	}
 
       if (result)
 	{
-	  log_println_str("Use \"-public\" to get rid of this question.");
+	  log_println_str ("Use \"-public\" to get rid of this question.");
 	}
       else
 	{
-	  log_println_str("Use \"-private\" to get rid of this question.");
+	  log_println_str ("Use \"-private\" to get rid of this question.");
 	}
     }
 
@@ -244,13 +251,14 @@ static int get_privacy(char *metaserver)
 /*
  * Returns the metaserver name
  */
-static char *get_metaserver()
+static char *
+get_metaserver ()
 {
-  char *result=LW_SERVER_DEFAULT_METASERVER;
+  char *result = LW_SERVER_DEFAULT_METASERVER;
 
-  if (exist_argument(LW_SERVER_IDENT_METASERVER))
+  if (exist_argument (LW_SERVER_IDENT_METASERVER))
     {
-      result=get_argument_str(LW_SERVER_IDENT_METASERVER);
+      result = get_argument_str (LW_SERVER_IDENT_METASERVER);
     }
 
   return result;
@@ -260,11 +268,12 @@ static char *get_metaserver()
 /*
  * Returns the password associated to the server
  */
-static char *get_password()
+static char *
+get_password ()
 {
-  char *result="";
+  char *result = "";
 
-  result=get_argument_str(LW_SERVER_IDENT_PASSWORD);
+  result = get_argument_str (LW_SERVER_IDENT_PASSWORD);
 
   return result;
 }
@@ -273,11 +282,12 @@ static char *get_password()
 /*
  * Returns the comment associated to the server
  */
-static char *get_comment()
+static char *
+get_comment ()
 {
-  char *result="";
+  char *result = "";
 
-  result=get_argument_str(LW_SERVER_IDENT_COMMENT);
+  result = get_argument_str (LW_SERVER_IDENT_COMMENT);
 
   return result;
 }
@@ -286,11 +296,27 @@ static char *get_comment()
 /*
  * Returns the log file name
  */
-char *lw_server_get_log()
+char *
+lw_server_get_log ()
 {
-  char *result="";
+  char *result = "";
 
-  result=get_argument_str(LW_SERVER_IDENT_LOG);
+  result = get_argument_str (LW_SERVER_IDENT_LOG);
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * Returns the callback script/program called when a client connects
+ * on the server.
+ */
+static char *
+get_callback ()
+{
+  char *result = "";
+
+  result = get_argument_str (LW_SERVER_IDENT_CALLBACK);
 
   return result;
 }
@@ -299,13 +325,14 @@ char *lw_server_get_log()
 /*
  * Exits the program and cleans up a few things
  */
-void lw_server_exit(int code)
+void
+lw_server_exit (int code)
 {
-  lw_sock_exit();
+  lw_sock_exit ();
 
-  log_exit();
+  log_exit ();
 
-  exit(code);
+  exit (code);
 }
 
 /*------------------------------------------------------------------*/
@@ -315,50 +342,47 @@ void lw_server_exit(int code)
  * under windows the game will be compiled as a console App
  * (no WinMain needed) and we don't use Allegro at all here anyway...
  */
-int main(int argc, char **argv)
+int
+main (int argc, char **argv)
 {
-  int retcode=0;
+  int retcode = 0;
   LW_SRVCONT cont;
   LW_WWWSRV_DATA www_data;
   char *metaserver;
   int nb_teams;
   int port;
-  int res=1;
+  int res = 1;
 
-  lw_sock_init();
+  lw_sock_init ();
 
-  read_command_line (argc,argv);
+  read_command_line (argc, argv);
 
   /*
    * we initialize the log _after_ read_command_line for
    * a special log file might have been specified
    */
-  log_init();
+  log_init ();
 
-  if (lw_basicopt_process("Liquid War Server"))
+  if (lw_basicopt_process ("Liquid War Server"))
     {
-      nb_teams=get_nb_teams();
+      nb_teams = get_nb_teams ();
 
-      if (nb_teams>=2 && nb_teams<=NB_TEAMS)
+      if (nb_teams >= 2 && nb_teams <= NB_TEAMS)
 	{
-	  port=get_port();
-	  metaserver=get_metaserver();
+	  port = get_port ();
+	  metaserver = get_metaserver ();
 	  /* 
 	   * we initialize the www_data struct which will contain
 	   * all the informations to be transmitted to the metaserver
 	   */
-	  lw_wwwsrv_init(&www_data,
-			 get_privacy(metaserver),
-			 0,
-			 metaserver,
-			 port,
-			 0,
-			 0,
-			 get_password(),
-			 get_comment());
-	  
-	  log_flush();
-	  log_set_server_mode(1);
+	  lw_wwwsrv_init (&www_data,
+			  get_privacy (metaserver),
+			  0,
+			  metaserver,
+			  port, 0, 0, get_password (), get_comment ());
+
+	  log_flush ();
+	  log_set_server_mode (1);
 
 	  /*
 	   * a good old infinite loop, the server has to be stopped
@@ -366,32 +390,29 @@ int main(int argc, char **argv)
 	   */
 	  while (1)
 	    {
-	      if (lw_srvcont_wait_teams(&cont, 
-					&www_data,
-					nb_teams, 
-					port,
-					get_password()))
+	      if (lw_srvcont_wait_teams (&cont,
+					 &www_data,
+					 nb_teams,
+					 port,
+					 get_password (), get_callback ()))
 		{
-		  if (lw_srvcont_tell_who(&cont))
+		  if (lw_srvcont_tell_who (&cont))
 		    {
-		      if (lw_srvcont_final_ok(&cont))
+		      if (lw_srvcont_final_ok (&cont))
 			{
-			  res=lw_srvcont_replicate_keys
-			    (&cont, 
-			     &www_data,
-			     get_lag(),
-			     get_password());
+			  res = lw_srvcont_replicate_keys
+			    (&cont, &www_data, get_lag (), get_password ());
 			}
 		    }
 		}
-	      lw_srvcont_close(&cont);
+	      lw_srvcont_close (&cont);
 
-	      log_flush();
+	      log_flush ();
 	    }
 	}
       else
 	{
-	  log_println_str("Not enough or too many teams!");
+	  log_println_str ("Not enough or too many teams!");
 	}
     }
   else
@@ -400,13 +421,13 @@ int main(int argc, char **argv)
        * we exit with a normal code (--help or --version)
        */
 
-      lw_server_exit(0);
+      lw_server_exit (0);
     }
 
   /*
    * If we get here, there necessarily an error
    */
-  lw_server_exit(1);
+  lw_server_exit (1);
 
   /*
    * Non-reachable code, but GCC would complain if we did not
@@ -415,16 +436,3 @@ int main(int argc, char **argv)
 
   return retcode;
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
