@@ -59,10 +59,21 @@
 /* defines                                                          */
 /*==================================================================*/
 
+#ifdef WIN32
+/*
+ * There are some problems with network under Windows, I suspect this
+ * is due to the fact W98 has some poor support network, and for some
+ * unexplained reasons map send/recv goes very slow, even on a LAN.
+ * So I set a higher value to the client timeout, hoping it will solve
+ * the problem.
+ */
+#define LW_SOCK2CLI_TIMEOUT_MSEC        30000
+#else
 /*
  * there's a 12 sec timeout by default on the client
  */
-#define LW_SOCK2CLI_TIMEOUT_MSEC        12000
+#define LW_SOCK2CLI_TIMEOUT_MSEC        15000
+#endif
 
 /*==================================================================*/
 /* variables globales                                               */
