@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -57,76 +57,85 @@
 /* globals                                                          */
 /*==================================================================*/
 
-int LW_SOCK_LOG=0;
+int LW_SOCK_LOG = 0;
 
 /*==================================================================*/
 /* functions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int lw_sock_init()
+int
+lw_sock_init ()
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_exit()
+int
+lw_sock_exit ()
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_listen(int *sock,char *ip,int port)
+int
+lw_sock_listen (int *sock, char *ip, int port)
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_accept(int *new_sock,char *ip, int *port, int listening_sock)
+int
+lw_sock_accept (int *new_sock, char *ip, int *port, int listening_sock)
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_connect(int *sock, char *ip, int port)
+int
+lw_sock_connect (int *sock, char *ip, int port)
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_peek_ex(int sock,int len)
+int
+lw_sock_peek_ex (int sock, int len)
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_send_str_ex(int sock,char *str)
+int
+lw_sock_send_str_ex (int sock, char *str)
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_recv_str_ex(int sock,char *str)
+int
+lw_sock_recv_str_ex (int sock, char *str)
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_send_buffer_ex(int sock,char *buffer,int len)
+int
+lw_sock_send_buffer_ex (int sock, char *buffer, int len)
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_recv_buffer_ex(int sock,char *buffer,int len)
+int
+lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
 {
   return 0;
 }
 
 /*------------------------------------------------------------------*/
-int lw_sock_close(int *sock)
+int
+lw_sock_close (int *sock)
 {
   return 0;
 }
-
-
