@@ -201,9 +201,9 @@ lw_sock_send_str_ex (int sock, char *str)
       len = strlen (str);
       len = MIN (len, LW_SOCK_MESSAGE_SIZE - 3);
       strncpy (buffer, str, len);
-      buffer[len] = '\r';
+      buffer[len] = '\x0d';
       ++len;
-      buffer[len] = '\n';
+      buffer[len] = '\x0a';
       ++len;
       buffer[len] = '\0';
 
@@ -380,7 +380,7 @@ lw_sock_recv_str_ex (int sock, char *str)
 		      /*
 		       * We seek for character 10, which should be '\n'
 		       */
-		      if ((cr = strchr (str, 10)) != NULL)
+		      if ((cr = strchr (str, '\x0a')) != NULL)
 			{
 			  cr_found = 1;
 			  /*
@@ -390,7 +390,7 @@ lw_sock_recv_str_ex (int sock, char *str)
 			   * that after removing the 10 there's still a 13, then
 			   * we remove the 13 as well.
 			   */
-			  if ((cr - str) >= 1 && (*(cr - 1)) == 13)
+			  if ((cr - str) >= 1 && (*(cr - 1)) == '\x0d')
 			    {
 			      /*
 			       * Let's cut this ugly "ascii 13" character
