@@ -312,7 +312,7 @@ lw_sock_close (int *sock)
        */
     }
 
-  if (close (sock_to_close) != 0)
+  if (closesocket (sock_to_close) != 0)
     {
       /*
        * Strange error, was the socket really opened?
