@@ -54,6 +54,8 @@
 #include "config.h"
 #include "disk.h"
 #include "sound.h"
+#include "mutxgen.h"
+#include "log.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -158,8 +160,27 @@ my_play_sample (SAMPLE * s, int vol)
 void
 play_click (void)
 {
+  static LW_MUTEX_DATA mutex = { NULL };
+
   if (LOADED_SFX)
-    my_play_sample (SAMPLE_SFX_CLICK, CONFIG_CLICK_VOLUME);
+    {
+      /*
+       * We use a mutex for play_click since playing several clicks
+       * together makes no sense. Additionnally, weird bugs (crashes...)
+       * under windows when cycling "too fast" within the maps make
+       * me think that it could be related to playing too many sounds
+       * simultaneously from several threads.
+       */
+      if (lw_mutex_trylock (&mutex))
+	{
+	  my_play_sample (SAMPLE_SFX_CLICK, CONFIG_CLICK_VOLUME);
+	  lw_mutex_unlock (&mutex);
+	}
+      else
+	{
+	  log_println_str ("Warning: too many calls to \"play_click\"...");
+	}
+    }
 }
 
 /*------------------------------------------------------------------*/
