@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -64,48 +64,57 @@
 #include "sound.h"
 #include "time.h"
 #include "lang.h"
+#include "macro.h"
 
 /*==================================================================*/
-/* variables globales                                               */
+/* constants                                                        */
 /*==================================================================*/
 
+#define LW_SPEEDS_FPS_SIZE 33
+#define LW_SPEEDS_RPS_SIZE 33
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-static void write_fps_setting (DIALOG *d)
+static void
+write_fps_setting (DIALOG * d)
 {
   char *str;
 
-  str=d->dp;
-  if (DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT]!=0)
+  str = d->dp;
+  if (DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT] != 0)
     {
-      sprintf (str,
-	       "%d %s",
-	       1000/(DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT]),
-	       lw_lang_string(LW_LANG_STRING_SPEEDS_FPS));
+      LW_MACRO_SNPRINTF2 (str,
+			  LW_SPEEDS_FPS_SIZE,
+			  "%d %s",
+			  1000 /
+			  (DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT]),
+			  lw_lang_string (LW_LANG_STRING_SPEEDS_FPS));
     }
   else
     {
-      sprintf(str,
-	      lw_lang_string(LW_LANG_STRING_SPEEDS_NOFPSLIMIT));
+      LW_MACRO_SNPRINTF0 (str,
+			  LW_SPEEDS_FPS_SIZE,
+			  lw_lang_string (LW_LANG_STRING_SPEEDS_NOFPSLIMIT));
     }
 }
 
 /*------------------------------------------------------------------*/
-static int slider_fps (void *dp3, int d2)
+static int
+slider_fps (void *dp3, int d2)
 {
   DIALOG *d;
 
-  d=dp3;
+  d = dp3;
 
-  CONFIG_FRAMES_PER_SEC_LIMIT=d2;
+  CONFIG_FRAMES_PER_SEC_LIMIT = d2;
   write_fps_setting (d);
 
-  scare_mouse();
+  scare_mouse ();
   my_textbox_proc (MSG_DRAW, d, 0);
-  unscare_mouse();
+  unscare_mouse ();
 
   play_click ();
 
@@ -113,37 +122,43 @@ static int slider_fps (void *dp3, int d2)
 }
 
 /*------------------------------------------------------------------*/
-static void write_rps_setting (DIALOG *d)
+static void
+write_rps_setting (DIALOG * d)
 {
   char *str;
 
-  str=d->dp;
-  if (LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT]!=0)
+  str = d->dp;
+  if (LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT] != 0)
     {
-      sprintf (str,"%d %s",
-	       1000/(LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT]),
-	       lw_lang_string(LW_LANG_STRING_SPEEDS_RPS));
+      LW_MACRO_SNPRINTF2 (str,
+			  LW_SPEEDS_RPS_SIZE,
+			  "%d %s",
+			  1000 /
+			  (LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT]),
+			  lw_lang_string (LW_LANG_STRING_SPEEDS_RPS));
     }
   else
     {
-      sprintf(str,
-	      lw_lang_string(LW_LANG_STRING_SPEEDS_NORPSLIMIT));
+      LW_MACRO_SNPRINTF0 (str,
+			  LW_SPEEDS_RPS_SIZE,
+			  lw_lang_string (LW_LANG_STRING_SPEEDS_NORPSLIMIT));
     }
 }
 
 /*------------------------------------------------------------------*/
-static int slider_rps (void *dp3, int d2)
+static int
+slider_rps (void *dp3, int d2)
 {
   DIALOG *d;
 
-  d=dp3;
+  d = dp3;
 
-  CONFIG_ROUNDS_PER_SEC_LIMIT=d2;
+  CONFIG_ROUNDS_PER_SEC_LIMIT = d2;
   write_rps_setting (d);
 
-  scare_mouse();
+  scare_mouse ();
   my_textbox_proc (MSG_DRAW, d, 0);
-  unscare_mouse();
+  unscare_mouse ();
 
   play_click ();
 
@@ -151,76 +166,76 @@ static int slider_rps (void *dp3, int d2)
 }
 
 /*------------------------------------------------------------------*/
-int speeds_options (void)
+int
+speeds_options (void)
 {
   int *temp;
   DIALOG d[9];
-  int i,choix=4,retour=0;
-  char fps_buffer[30];
-  char rps_buffer[30];
-  
-  memset(d,0,sizeof(d));
+  int i, choix = 4, retour = 0;
+  char fps_buffer[LW_SPEEDS_FPS_SIZE];
+  char rps_buffer[LW_SPEEDS_RPS_SIZE];
 
-  for (i=0; i<2; ++i)
+  memset (d, 0, sizeof (d));
+
+  for (i = 0; i < 2; ++i)
     {
-      standard_button (d+i+4,0,i,2,2);
-      d[i+4].proc=my_textbox_proc;
+      standard_button (d + i + 4, 0, i, 2, 2);
+      d[i + 4].proc = my_textbox_proc;
     }
-  for (i=0; i<2; ++i)
+  for (i = 0; i < 2; ++i)
     {
-      standard_button (d+i+6,1,i,2,2);
-      d[i+6].proc=my_slider_proc;
+      standard_button (d + i + 6, 1, i, 2, 2);
+      d[i + 6].proc = my_slider_proc;
     }
 
-  quick_buttons(d);
-  d[4].dp=fps_buffer;
-  d[5].dp=rps_buffer;
-  d[6].d1=8;
-  d[7].d1=8;
-  d[6].dp3=&CONFIG_FRAMES_PER_SEC_LIMIT;
-  d[7].dp3=&CONFIG_ROUNDS_PER_SEC_LIMIT;
-  for (i=0;i<2;++i)
+  quick_buttons (d);
+  d[4].dp = fps_buffer;
+  d[5].dp = rps_buffer;
+  d[6].d1 = 8;
+  d[7].d1 = 8;
+  d[6].dp3 = &CONFIG_FRAMES_PER_SEC_LIMIT;
+  d[7].dp3 = &CONFIG_ROUNDS_PER_SEC_LIMIT;
+  for (i = 0; i < 2; ++i)
     {
-      d[i+6].dp=NULL;
-      d[i+6].dp2=slider_int;
-      temp=d[i+6].dp3;
-      d[i+6].d2=*temp;
-      d[i+6].dp3=d+i+4;
+      d[i + 6].dp = NULL;
+      d[i + 6].dp2 = slider_int;
+      temp = d[i + 6].dp3;
+      d[i + 6].d2 = *temp;
+      d[i + 6].dp3 = d + i + 4;
     }
 
-  d[6].dp2=slider_fps; 
-  d[7].dp2=slider_rps; 
+  d[6].dp2 = slider_fps;
+  d[7].dp2 = slider_rps;
 
-  write_fps_setting(d+4);
-  write_rps_setting(d+5);
+  write_fps_setting (d + 4);
+  write_rps_setting (d + 5);
 
-  d[8].proc=0;
+  d[8].proc = 0;
 
-  while (retour==0)
+  while (retour == 0)
     {
-      choix=my_do_dialog (d,choix);
+      choix = my_do_dialog (d, choix);
       switch (choix)
 	{
 	case -1:
 	case MENU_QUICK_BACK:
-	  retour=1;
+	  retour = 1;
 	  break;
 	case MENU_QUICK_MAIN:
-	  retour=MENU_TOP;
+	  retour = MENU_TOP;
 	  break;
 	case MENU_QUICK_QUIT:
-	  if (confirm_quit())
-	    retour=MENU_EXIT;
+	  if (confirm_quit ())
+	    retour = MENU_EXIT;
 	  break;
 	case MENU_QUICK_PLAY:
-	  retour=MENU_PLAY;
+	  retour = MENU_PLAY;
 	  break;
 	}
     }
 
-  if (retour>0)
+  if (retour > 0)
     retour--;
 
   return retour;
 }
-
