@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -62,40 +62,26 @@
 /* types                                                            */
 /*==================================================================*/
 
-extern void LW_ASM_FUNC boost_gradient_down_2 (MESH *first, 
-					      int size, 
-					      int offset);
-extern void LW_ASM_FUNC boost_gradient_down_3 (MESH *first, 
-					      int size, 
-					      int offset);
-extern void LW_ASM_FUNC boost_gradient_down_4 (MESH *first, 
-					      int size, 
-					      int offset);
-extern void LW_ASM_FUNC boost_gradient_down_5 (MESH *first, 
-					      int size, 
-					      int offset);
-extern void LW_ASM_FUNC boost_gradient_down_6 (MESH *first, 
-					      int size, 
-					      int offset);
+extern void LW_ASM_FUNC boost_gradient_down_2 (MESH * first,
+					       int size, int offset);
+extern void LW_ASM_FUNC boost_gradient_down_3 (MESH * first,
+					       int size, int offset);
+extern void LW_ASM_FUNC boost_gradient_down_4 (MESH * first,
+					       int size, int offset);
+extern void LW_ASM_FUNC boost_gradient_down_5 (MESH * first,
+					       int size, int offset);
+extern void LW_ASM_FUNC boost_gradient_down_6 (MESH * first,
+					       int size, int offset);
 
-extern void LW_ASM_FUNC boost_gradient_up_2 (MESH *first, 
-					    int size, 
-					    int offset);
-extern void LW_ASM_FUNC boost_gradient_up_3 (MESH *first, 
-					    int size, 
-					    int offset);
-extern void LW_ASM_FUNC boost_gradient_up_4 (MESH *first, 
-					    int size, 
-					    int offset);
-extern void LW_ASM_FUNC boost_gradient_up_5 (MESH *first, 
-					    int size, 
-					    int offset);
-extern void LW_ASM_FUNC boost_gradient_up_6 (MESH *first, 
-					    int size, 
-					    int offset);
+extern void LW_ASM_FUNC boost_gradient_up_2 (MESH * first,
+					     int size, int offset);
+extern void LW_ASM_FUNC boost_gradient_up_3 (MESH * first,
+					     int size, int offset);
+extern void LW_ASM_FUNC boost_gradient_up_4 (MESH * first,
+					     int size, int offset);
+extern void LW_ASM_FUNC boost_gradient_up_5 (MESH * first,
+					     int size, int offset);
+extern void LW_ASM_FUNC boost_gradient_up_6 (MESH * first,
+					     int size, int offset);
 
 #endif
-
-
-
-
