@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -85,40 +85,37 @@ typedef struct
   LW_CHAT_HISTORY chat;
   unsigned int checksum_recv;
   unsigned int checksum_send;
-} LW_SRVCHAN;
+  int normal_quit;
+}
+LW_SRVCHAN;
 
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
 
-int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
-			  int sock, void **map,LW_NETCONF *config,
-			  char *password);
-int lw_srvchan_keepalive(LW_SRVCHAN *chan, int waited_teams,
-			 LW_TEAMSTARTINFO *team_start_info,
-			 LW_CHAT_HISTORY *chat);
-int lw_srvchan_tell_who(LW_SRVCHAN *chan,void *map,LW_NETCONF *config);
-int lw_srvchan_final_ok(LW_SRVCHAN *chan);
-int lw_srvchan_find_team_by_server_id(LW_SRVCHAN *chan,int server_id);
-int lw_srvchan_find_first_free_team(LW_SRVCHAN *chan);
-void lw_srvchan_close(LW_SRVCHAN *chan);
-int lw_srvchan_recv_keys(LW_SRVCHAN *chan, LW_NETKEY *netkey);
-int lw_srvchan_send_keys(LW_SRVCHAN *chan, LW_NETKEY *netkey);
+int lw_srvchan_wait_teams (LW_SRVCHAN * chan, int *free_teams,
+			   int sock, void **map, LW_NETCONF * config,
+			   char *password);
+int lw_srvchan_keepalive (LW_SRVCHAN * chan, int waited_teams,
+			  LW_TEAMSTARTINFO * team_start_info,
+			  LW_CHAT_HISTORY * chat);
+int lw_srvchan_tell_who (LW_SRVCHAN * chan, void *map, LW_NETCONF * config);
+int lw_srvchan_final_ok (LW_SRVCHAN * chan);
+int lw_srvchan_find_team_by_server_id (LW_SRVCHAN * chan, int server_id);
+int lw_srvchan_find_first_free_team (LW_SRVCHAN * chan);
+void lw_srvchan_close (LW_SRVCHAN * chan);
+int lw_srvchan_recv_keys (LW_SRVCHAN * chan, LW_NETKEY * netkey);
+int lw_srvchan_send_keys (LW_SRVCHAN * chan, LW_NETKEY * netkey);
 
-int lw_srvchan_handle_ping(int sock, LW_NETMESS *mess);
-int lw_srvchan_handle_echo(int sock, LW_NETMESS *mess);
-int lw_srvchan_handle_program(int sock, LW_NETMESS *mess, 
-			      int *ok);
-int lw_srvchan_handle_version(int sock, LW_NETMESS *mess, 
-			      int *ok);
-int lw_srvchan_handle_password(int sock, LW_NETMESS *mess, 
-			       int *ok, char *password);
-int lw_srvchan_handle_free(int sock, LW_NETMESS *mess, 
-			   int free_teams, int *ok);
-int lw_srvchan_handle_unknown(int sock, LW_NETMESS *mess);
+int lw_srvchan_handle_ping (int sock, LW_NETMESS * mess);
+int lw_srvchan_handle_echo (int sock, LW_NETMESS * mess);
+int lw_srvchan_handle_program (int sock, LW_NETMESS * mess, int *ok);
+int lw_srvchan_handle_version (int sock, LW_NETMESS * mess, int *ok);
+int lw_srvchan_handle_password (int sock, LW_NETMESS * mess,
+				int *ok, char *password);
+int lw_srvchan_handle_free (int sock, LW_NETMESS * mess,
+			    int free_teams, int *ok);
+int lw_srvchan_handle_unknown (int sock, LW_NETMESS * mess);
+int lw_srvchan_handle_quit (int sock, LW_NETMESS * mess, int *normal_quit);
 
 #endif
-
-
-
-
