@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -67,13 +67,14 @@ typedef struct
   int network;
   int server_id;
   int control_type;
-  char name[NAME_SIZE+1];
-} LW_SRVTEAM;
+  char name[NAME_SIZE + 1];
+}
+LW_SRVTEAM;
 
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
 
-void lw_srvteam_reset(LW_SRVTEAM *team);
+void lw_srvteam_reset (LW_SRVTEAM * team);
 
 #endif
