@@ -86,11 +86,12 @@
 #define IDENT_MAP                 "map"
 #define IDENT_TEX                 "tex"
 #define IDENT_MID                 "mid"
+#define IDENT_SRV                 "server"
+#define IDENT_GEN                 "mapgen"
 #define IDENT_METASERVER          "metaserver"
 #define IDENT_CAPTURE             "capture"
 #define IDENT_TOMBOLA             "tombola"
 
-#define STARTUP_MAX_PATH_LENGTH           1000
 #define STARTUP_MAX_METASERVER_LENGTH      200
 
 #ifdef ALLEGRO_DOS
@@ -122,14 +123,20 @@ static char *DEFAULT_DAT_PATH = CONFIG_UNIX_DAT;
 static char *DEFAULT_MAP_PATH = CONFIG_UNIX_MAP;
 static char *DEFAULT_TEX_PATH = CONFIG_UNIX_TEX;
 static char *DEFAULT_MID_PATH = CONFIG_UNIX_MID;
+static char *DEFAULT_SRV_PATH = CONFIG_UNIX_SRV;
+static char *DEFAULT_GEN_PATH = CONFIG_UNIX_GEN;
 #else
 #ifdef ALLEGRO_WINDOWS
 static char *DEFAULT_CFG_PATH = "data/lwwin.cfg";
 static char *DEFAULT_LOG_PATH = "data/lwwin.log";
+static char *DEFAULT_SRV_PATH = "lwwinsrv.exe";
+static char *DEFAULT_GEN_PATH = "lwwinmap.exe";
 #endif
 #ifdef ALLEGRO_DOS
 static char *DEFAULT_CFG_PATH = "data/lwdos.cfg";
 static char *DEFAULT_LOG_PATH = "data/lwdos.log";
+static char *DEFAULT_SRV_PATH = "";
+static char *DEFAULT_GEN_PATH = "";
 #endif
 static char *DEFAULT_DAT_PATH = "data/lw.dat";
 static char *DEFAULT_MAP_PATH = "custom/map/";
@@ -139,12 +146,14 @@ static char *DEFAULT_MID_PATH = "custom/music/";
 
 static char *DEFAULT_METASERVER = LW_SERVER_DEFAULT_METASERVER;
 
-char STARTUP_CFG_PATH[STARTUP_MAX_PATH_LENGTH];
-char STARTUP_DAT_PATH[STARTUP_MAX_PATH_LENGTH];
-char STARTUP_LOG_PATH[STARTUP_MAX_PATH_LENGTH];
-char STARTUP_MAP_PATH[STARTUP_MAX_PATH_LENGTH];
-char STARTUP_TEX_PATH[STARTUP_MAX_PATH_LENGTH];
-char STARTUP_MID_PATH[STARTUP_MAX_PATH_LENGTH];
+char STARTUP_CFG_PATH[LW_STARTUP_MAX_PATH_LENGTH];
+char STARTUP_DAT_PATH[LW_STARTUP_MAX_PATH_LENGTH];
+char STARTUP_LOG_PATH[LW_STARTUP_MAX_PATH_LENGTH];
+char STARTUP_MAP_PATH[LW_STARTUP_MAX_PATH_LENGTH];
+char STARTUP_TEX_PATH[LW_STARTUP_MAX_PATH_LENGTH];
+char STARTUP_MID_PATH[LW_STARTUP_MAX_PATH_LENGTH];
+char STARTUP_SRV_PATH[LW_STARTUP_MAX_PATH_LENGTH];
+char STARTUP_GEN_PATH[LW_STARTUP_MAX_PATH_LENGTH];
 
 char STARTUP_METASERVER[STARTUP_MAX_METASERVER_LENGTH];
 
@@ -369,6 +378,22 @@ set_path (void)
     {
       LW_MACRO_STRCPY (STARTUP_MID_PATH, DEFAULT_MID_PATH);
     }
+  if (exist_argument_value (IDENT_SRV))
+    {
+      LW_MACRO_STRCPY (STARTUP_SRV_PATH, get_argument_str (IDENT_SRV));
+    }
+  else
+    {
+      LW_MACRO_STRCPY (STARTUP_SRV_PATH, DEFAULT_SRV_PATH);
+    }
+  if (exist_argument_value (IDENT_GEN))
+    {
+      LW_MACRO_STRCPY (STARTUP_GEN_PATH, get_argument_str (IDENT_GEN));
+    }
+  else
+    {
+      LW_MACRO_STRCPY (STARTUP_GEN_PATH, DEFAULT_GEN_PATH);
+    }
 
 
   correct_path_file (STARTUP_CFG_PATH);
@@ -377,6 +402,8 @@ set_path (void)
   correct_path_dir (STARTUP_TEX_PATH);
   correct_path_dir (STARTUP_MAP_PATH);
   correct_path_dir (STARTUP_MID_PATH);
+  correct_path_file (STARTUP_SRV_PATH);
+  correct_path_file (STARTUP_GEN_PATH);
 }
 
 /*------------------------------------------------------------------*/
