@@ -62,6 +62,8 @@
 #define LW_STARTUP_MEM_MAX  128
 #define LW_STARTUP_MEM_STEP   8
 
+#define LW_STARTUP_MAX_PATH_LENGTH           1000
+
 /*==================================================================*/
 /* variables globales                                               */
 /*==================================================================*/
@@ -90,6 +92,8 @@ extern char STARTUP_LOG_PATH[];
 extern char STARTUP_MAP_PATH[];
 extern char STARTUP_TEX_PATH[];
 extern char STARTUP_MID_PATH[];
+extern char STARTUP_SRV_PATH[];
+extern char STARTUP_GEN_PATH[];
 
 extern char STARTUP_METASERVER[];
 
