@@ -60,6 +60,10 @@
 #include "palette.h"
 #include "startup.h"
 #include "log.h"
+#include "serial.h"
+#include "macro.h"
+#include "path.h"
+#include "serial.h"
 
 /*==================================================================*/
 /* constants                                                        */
@@ -216,20 +220,25 @@ red8col (BITMAP * bmp, PALETTE pal, int first_color, int number_of_colors)
 /*------------------------------------------------------------------*/
 static void
 texture_8to5 (BITMAP * bmp, PALETTE pal, void *result,
-	      int first_color, int number_of_colors)
+	      int first_color, int number_of_colors, char *filename)
 {
-  short *size_wh;
   char *buffer;
   int pos = 0, pos8 = 0, x, y, i;
   char octet[5], toadd;
   int coul;
+  char system_name_buffer[LW_TEXTURE_SYSTEM_NAME_SIZE + 1];
 
-  size_wh = result;
+  lw_serial_set_texture_header (result, bmp->w, bmp->h);
 
-  (*(size_wh++)) = bmp->w;
-  (*(size_wh++)) = bmp->h;
+  buffer = ((char *) result) + 2 * sizeof (short);
 
-  buffer = (void *) size_wh;
+  /*
+   * We store the system name
+   */
+  memset (system_name_buffer, 0, sizeof (system_name_buffer));
+  LW_MACRO_STRCPY (system_name_buffer, lw_path_get_system_name (filename));
+  memcpy (buffer, system_name_buffer, LW_TEXTURE_SYSTEM_NAME_SIZE);
+  buffer += LW_TEXTURE_SYSTEM_NAME_SIZE;
 
   for (i = 0; i < number_of_colors; ++i)
     {
@@ -284,11 +293,13 @@ lw_texture_archive_raw (const char *filename)
 	{
 	  temp = malloc (size =
 			 2 * sizeof (short)
+			 + LW_TEXTURE_SYSTEM_NAME_SIZE
 			 + 3 * TEXTURE_COLOR_NUMBER + ((w * h + 7) / 8) * 5);
 	  if (temp)
 	    {
 	      red8col (bmp, pal, 0, TEXTURE_COLOR_NUMBER);
-	      texture_8to5 (bmp, pal, temp, 0, TEXTURE_COLOR_NUMBER);
+	      texture_8to5 (bmp, pal, temp, 0, TEXTURE_COLOR_NUMBER,
+			    (char *) filename);
 	    }
 	}
       destroy_bitmap (bmp);
@@ -297,8 +308,12 @@ lw_texture_archive_raw (const char *filename)
     {
       result = malloc (size);
       if (result)
-	for (i = 0; i < size; ++i)
-	  result[i] = temp[i];
+	{
+	  for (i = 0; i < size; ++i)
+	    {
+	      result[i] = temp[i];
+	    }
+	}
       free (temp);
     }
 
@@ -309,16 +324,14 @@ lw_texture_archive_raw (const char *filename)
 static BITMAP *
 create_raw_texture (void *ptr, int first)
 {
-  int x, y, w, h, pos8 = 0, color;
+  int x, y, pos8 = 0, color;
   char totest, *data;
-  short *data2;
   BITMAP *result;
+  short w, h;
 
   data = ptr;
-  data += 4 + 3 * 32;
-  data2 = ptr;
-  w = data2[0];
-  h = data2[1];
+  lw_serial_get_texture_header (data, &w, &h);
+  data += 2 * sizeof (short) + LW_TEXTURE_SYSTEM_NAME_SIZE + 3 * 32;
 
   result = my_create_bitmap (w, h);
   if (result)
@@ -342,6 +355,31 @@ create_raw_texture (void *ptr, int first)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+static void *
+get_raw_texture (int num)
+{
+  void *texture = NULL;
+
+  if (num > RAW_TEXTURE_NUMBER + RAW_MAPTEX_NUMBER + CHOOSE_COLOR_NUMBER - 1)
+    num = RAW_TEXTURE_NUMBER + RAW_MAPTEX_NUMBER + CHOOSE_COLOR_NUMBER - 1;
+
+  if (num >= CHOOSE_COLOR_NUMBER
+      && num < CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER && LOADED_TEXTURE)
+    {
+      texture = RAW_TEXTURE[num - CHOOSE_COLOR_NUMBER];
+    }
+
+  if (num >= CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER
+      && num < CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER + RAW_MAPTEX_NUMBER
+      && LOADED_MAPTEX)
+    {
+      texture = RAW_MAPTEX[num - (CHOOSE_COLOR_NUMBER + RAW_TEXTURE_NUMBER)];
+    }
+
+  return texture;
+}
+
 /*------------------------------------------------------------------*/
 static BITMAP *
 create_mono_texture (int first)
@@ -358,15 +396,18 @@ static BITMAP *
 create_texture (int num, int first)
 {
   BITMAP *result;
+  void *texture;
 
-  if (num > RAW_TEXTURE_NUMBER + CHOOSE_COLOR_NUMBER - 1)
-    num = RAW_TEXTURE_NUMBER + CHOOSE_COLOR_NUMBER - 1;
+  texture = get_raw_texture (num);
 
-  if (num >= CHOOSE_COLOR_NUMBER && LOADED_TEXTURE)
-    result = create_raw_texture (RAW_TEXTURE
-				 [num - CHOOSE_COLOR_NUMBER], first);
+  if (texture)
+    {
+      result = create_raw_texture (texture, first);
+    }
   else
-    result = create_mono_texture (first);
+    {
+      result = create_mono_texture (first);
+    }
 
   return result;
 }
@@ -384,3 +425,28 @@ lw_texture_create_fg (int num)
 {
   return create_texture (num, FG_TEXTURE_FIRST_COLOR);
 }
+
+/*------------------------------------------------------------------*/
+char *
+lw_texture_get_system_name (int num)
+{
+  static char result[LW_MAP_SYSTEM_NAME_SIZE + 1];
+  void *raw_texture;
+  char *char_ptr;
+
+  raw_texture = get_raw_texture (num);
+
+  LW_MACRO_MEMSET0 (result);
+  if (raw_texture)
+    {
+      char_ptr = (char *) raw_texture;
+      memcpy (result, char_ptr + 4, LW_TEXTURE_SYSTEM_NAME_SIZE);
+    }
+  else
+    {
+      LW_MACRO_SPRINTF1 (result, "Color %d", num);
+    }
+  result[sizeof (result) - 1] = '\0';
+
+  return result;
+}
