@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -75,16 +75,17 @@
 /*
  * Starts a new thread using the given callback
  */
-int lw_thread_start(void (*func)(void *),void *args)
+int
+lw_thread_start (void (*func) (void *), void *args)
 {
   pthread_t thread;
-  int result=0;
+  int result = 0;
 
-  if (pthread_create(&thread,NULL,(void *(*)(void *)) func,args)==0)
+  if (pthread_create (&thread, NULL, (void *(*)(void *)) func, args) == 0)
     {
-      if (pthread_detach(thread)==0)
+      if (pthread_detach (thread) == 0)
 	{
-	  result=1;
+	  result = 1;
 	}
     }
 
