@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -77,15 +77,15 @@
 /*
  * Starts a new thread using the given callback
  */
-int lw_thread_start(void (*func)(void *),void *args)
+int
+lw_thread_start (void (*func) (void *), void *args)
 {
-  int result=0;
+  int result = 0;
 
-  if (_beginthread(func,0,args)!=0)
+  if (_beginthread (func, 0, args) != 0)
     {
-      result=1;
+      result = 1;
     }
 
   return result;
 }
-
