@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -72,89 +72,91 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-int wave_options (void)
+int
+wave_options (void)
 {
   int *temp;
   DIALOG d[24];
   DIALOG_PLAYER *dp;
-  int i,j,k,choix=4,retour=0;
+  int i, j, k, choix = 4, retour = 0;
 
-  memset(d,0,sizeof(d));
+  memset (d, 0, sizeof (d));
 
-  display_back_image();
-  for (i=0; i<5; ++i)
-    for (j=0; j<4; ++j)
-      if (i>0 || j>0)
+  display_back_image ();
+  for (i = 0; i < 5; ++i)
+    for (j = 0; j < 4; ++j)
+      if (i > 0 || j > 0)
 	{
-	  k=i*4+j+3;
-	  standard_small_button (d+k,j,i,4,5);
-	  if (i>0 && j>0)
+	  k = i * 4 + j + 3;
+	  standard_small_button (d + k, j, i, 4, 5);
+	  if (i > 0 && j > 0)
 	    {
-	      d[k].proc=my_slider_proc;
-	      d[k].dp=NULL;
-	      d[k].dp2=slider_int;
+	      d[k].proc = my_slider_proc;
+	      d[k].dp = NULL;
+	      d[k].dp2 = slider_int;
 	      switch (j)
 		{
-		case 1: d[k].d1=16;
-		  d[k].dp3=&(CONFIG_WAVE_AMPLI[i-1]);
+		case 1:
+		  d[k].d1 = 16;
+		  d[k].dp3 = &(CONFIG_WAVE_AMPLI[i - 1]);
 		  break;
-		case 2: d[k].d1=4;
-		  d[k].dp3=&(CONFIG_WAVE_NUMBER[i-1]);
+		case 2:
+		  d[k].d1 = 4;
+		  d[k].dp3 = &(CONFIG_WAVE_NUMBER[i - 1]);
 		  break;
-		case 3: d[k].d1=16;
-		  d[k].dp3=&(CONFIG_WAVE_SPEED[i-1]);
+		case 3:
+		  d[k].d1 = 16;
+		  d[k].dp3 = &(CONFIG_WAVE_SPEED[i - 1]);
 		  break;
 		}
-	      temp=d[k].dp3;
-	      d[k].d2=*temp;
+	      temp = d[k].dp3;
+	      d[k].d2 = *temp;
 	    }
 	  else
-	    d[k].proc=my_textbox_proc;
+	    d[k].proc = my_textbox_proc;
 	}
-  d[23].proc=NULL;
+  d[23].proc = NULL;
 
-  quick_buttons(d);
-  d[4].dp=lw_lang_string(LW_LANG_STRING_WAVE_AMPLI);
-  d[5].dp=lw_lang_string(LW_LANG_STRING_WAVE_NUMBER);
-  d[6].dp=lw_lang_string(LW_LANG_STRING_WAVE_SPEED);
-  d[7].dp=lw_lang_string(LW_LANG_STRING_WAVE_WX);
-  d[11].dp=lw_lang_string(LW_LANG_STRING_WAVE_HY);
-  d[15].dp=lw_lang_string(LW_LANG_STRING_WAVE_WY);
-  d[19].dp=lw_lang_string(LW_LANG_STRING_WAVE_HX);
+  quick_buttons (d);
+  d[4].dp = lw_lang_string (LW_LANG_STRING_WAVE_AMPLI);
+  d[5].dp = lw_lang_string (LW_LANG_STRING_WAVE_NUMBER);
+  d[6].dp = lw_lang_string (LW_LANG_STRING_WAVE_SPEED);
+  d[7].dp = lw_lang_string (LW_LANG_STRING_WAVE_WX);
+  d[11].dp = lw_lang_string (LW_LANG_STRING_WAVE_HY);
+  d[15].dp = lw_lang_string (LW_LANG_STRING_WAVE_WY);
+  d[19].dp = lw_lang_string (LW_LANG_STRING_WAVE_HX);
 
-  display_back_image();
-  while (retour==0)
+  display_back_image ();
+  while (retour == 0)
     {
-      dp=my_init_dialog (d,choix);
-      while (my_update_dialog(dp))
+      dp = my_init_dialog (d, choix);
+      while (my_update_dialog (dp))
 	;
-      choix=shutdown_dialog (dp);
+      choix = shutdown_dialog (dp);
       //choix=my_do_dialog (d,choix);
       switch (choix)
 	{
 	case -1:
 	case MENU_QUICK_BACK:
-	  retour=1;
+	  retour = 1;
 	  break;
 	case MENU_QUICK_MAIN:
-	  retour=MENU_TOP;
+	  retour = MENU_TOP;
 	  break;
 	case MENU_QUICK_QUIT:
-	  if (confirm_quit())
-	    retour=MENU_EXIT;
+	  if (confirm_quit ())
+	    retour = MENU_EXIT;
 	  else
-	    display_back_image();
+	    display_back_image ();
 	  break;
 	case MENU_QUICK_PLAY:
-	  retour=MENU_PLAY;
+	  retour = MENU_PLAY;
 	  break;
 	}
     }
 
-  if (retour>0)
+  if (retour > 0)
     retour--;
 
   return retour;
 }
-
-
