@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -61,6 +61,8 @@
 #include "httputil.h"
 #include "init.h"
 #include "server.h"
+#include "macro.h"
+#include "ping.h"
 
 /*==================================================================*/
 /* constants                                                        */
@@ -72,17 +74,24 @@
 #define LW_WWWCLI_URL_LIST "list.php3"
 #define LW_WWWCLI_TEMP_BUFFER_SIZE 100
 
+/*
+ * If a line is shorter than this, we consider it as an empty
+ * line, this avoids errors with useless stupid malformatted lines
+ */
+#define LW_WWWCLI_MIN_LINE_SIZE 20
+
 /*==================================================================*/
 /* static functions                                                 */
 /*==================================================================*/
 
-static int parse_line(LW_WWWCLI_DATA *result, char **str);
-static void skip_space(char **str);
-static int read_string(char *result,char **str,int size);
-static int read_int(int *result,char **str);
-static int read_separator(char **str);
-static int read_eol(char **str);
-static void next_line(char **str);
+static int parse_line (LW_WWWCLI_DATA * result, char **str);
+static void skip_space (char **str);
+static int read_string (char *result, char **str, int size);
+static int read_int (int *result, char **str);
+static int read_separator (char **str);
+static int read_eol (char **str);
+static int read_eol_n (char **str, int n);
+static void next_line (char **str);
 
 /*==================================================================*/
 /* global functions                                                 */
@@ -93,47 +102,48 @@ static void next_line(char **str);
  * Main function of the server thread which tries to connect
  * on the metaserver
  */
-int lw_wwwcli_get_games(LW_WWWCLI_DATA *buffer, int *size)
+int
+lw_wwwcli_get_games (LW_WWWCLI_DATA * buffer, int *size)
 {
-  int result=0;
+  int result = 0;
   char buffer_content[LW_WWWCLI_HTTP_CONTENT_SIZE];
   char buffer_url[LW_WWWCLI_HTTP_URL_SIZE];
-  char *pos,*pos_tmp;
-  int i=0;
+  char *pos, *pos_tmp;
+  int i = 0;
 
-  log_print_str("Getting server list from \"");
-  log_print_str(STARTUP_METASERVER);
-  log_print_str("\" ");
+  log_print_str ("Getting server list from \"");
+  log_print_str (STARTUP_METASERVER);
+  log_print_str ("\" ");
 
-  memset(&buffer_url,0,sizeof(buffer_url));
-  strcpy(buffer_url,STARTUP_METASERVER);
-  strcat(buffer_url,LW_WWWCLI_URL_LIST);
+  memset (&buffer_url, 0, sizeof (buffer_url));
+  LW_MACRO_SPRINTF3 (buffer_url,
+		     "%s%s?protocol=%s&game=" LW_PROGRAM "&version="
+		     LW_VERSION, STARTUP_METASERVER, LW_WWWCLI_URL_LIST,
+		     LW_SERVER_METASERVER_PROTOCOL);
 
-  strcat(buffer_url,"?protocol=" LW_SERVER_METASERVER_PROTOCOL);
-  strcat(buffer_url,"&game=" LW_PROGRAM "&version=" LW_VERSION);
-
-  if (lw_httputil_get_page(buffer_content,buffer_url,sizeof(buffer_content)))
+  if (lw_httputil_get_page
+      (buffer_content, buffer_url, sizeof (buffer_content)))
     {
-      pos=buffer_content;
+      pos = buffer_content;
 
-      while (read_eol(&pos));
+      while (read_eol (&pos));
 
-      while (i<(*size) && strlen(pos)>0)
+      while (i < (*size) && strlen (pos) > 0)
 	{
-	  pos_tmp=pos;
-	  if (read_eol(&pos_tmp))
+	  pos_tmp = pos;
+	  if (read_eol_n (&pos_tmp, LW_WWWCLI_MIN_LINE_SIZE))
 	    {
 	      /*
-	       * This was just an empty line...
+	       * This was just an empty or too short line...
 	       */
-	      pos=pos_tmp;
+	      pos = pos_tmp;
 	    }
 	  else
 	    {
 	      /*
 	       * We parse the line only if there's something on it...
 	       */
-	      if (parse_line(buffer+i,&pos))
+	      if (parse_line (buffer + i, &pos))
 		{
 		  if (buffer[i].busy_players < buffer[i].max_players)
 		    {
@@ -145,37 +155,37 @@ int lw_wwwcli_get_games(LW_WWWCLI_DATA *buffer, int *size)
 		       * overwritten by the next server.
 		       */
 		      ++i;
-		      log_print_str("+");
+		      log_print_str ("+");
 		    }
 		  else
 		    {
-		      log_print_str("=");
+		      log_print_str ("=");
 		    }
 		}
 	      else
 		{
-		  log_print_str("-");
+		  log_print_str ("-");
 		}
 	    }
 	}
 
-      result=1;
+      result = 1;
     }
 
-  if (result==1)
+  if (result == 1)
     {
-      (*size)=i;
+      (*size) = i;
     }
   else
     {
-      (*size)=0;
+      (*size) = 0;
     }
 
-  display_success(result);
+  display_success (result);
   if (!result)
     {
-      log_print_str("Error: ");
-      log_println_str(buffer_content);
+      log_print_str ("Error: ");
+      log_println_str (buffer_content);
     }
 
   return result;
@@ -185,40 +195,44 @@ int lw_wwwcli_get_games(LW_WWWCLI_DATA *buffer, int *size)
 /*
  * Parses a line returned by the meta-server
  */
-int parse_line(LW_WWWCLI_DATA *result, char **str)
+static int
+parse_line (LW_WWWCLI_DATA * result, char **str)
 {
-  int ok=0;
+  int ok = 0;
   char temp[LW_WWWCLI_TEMP_BUFFER_SIZE];
 
-  memset(result,0,sizeof(LW_WWWCLI_DATA));
+  memset (result, 0, sizeof (LW_WWWCLI_DATA));
 
 
-  if (read_string(result->ip,str,sizeof(result->ip)) &&
-      read_separator(str) &&
-      read_int(&(result->port),str) &&
-      read_separator(str) &&
-      read_string(temp,str,sizeof(temp)) &&
-      read_separator(str) &&
-      read_string(temp,str,sizeof(temp)) &&
-      read_separator(str) &&
-      read_int(&(result->uptime),str) &&
-      read_separator(str) &&
-      read_int(&(result->busy_players),str) &&
-      read_separator(str) &&
-      read_int(&(result->max_players),str) &&
-      read_separator(str) &&
-      read_int(&(result->password),str) &&
-      read_separator(str) &&
-      read_string(result->comment,str,sizeof(result->comment)))
+  if (read_string (result->ip, str, sizeof (result->ip)) &&
+      read_separator (str) &&
+      read_int (&(result->port), str) &&
+      read_separator (str) &&
+      read_string (temp, str, sizeof (temp)) &&
+      read_separator (str) &&
+      read_string (temp, str, sizeof (temp)) &&
+      read_separator (str) &&
+      read_int (&(result->uptime), str) &&
+      read_separator (str) &&
+      read_int (&(result->busy_players), str) &&
+      read_separator (str) &&
+      read_int (&(result->max_players), str) &&
+      read_separator (str) &&
+      read_int (&(result->password), str) &&
+      read_separator (str) &&
+      read_string (result->comment, str, sizeof (result->comment)))
     {
-      sprintf(result->label,"%s (%d/%d)",
-	      result->ip,
-	      result->busy_players,
-	      result->max_players);
-      ok=1;
+      LW_MACRO_SPRINTF3 (result->label,
+			 "%s (%d/%d)",
+			 result->ip,
+			 result->busy_players, result->max_players);
+
+      result->ping_delay = lw_ping_try_server (result->ip, result->port);
+
+      ok = 1;
     }
 
-  next_line(str);
+  next_line (str);
 
   return ok;
 }
@@ -227,9 +241,10 @@ int parse_line(LW_WWWCLI_DATA *result, char **str)
 /*
  * Skip spaces, tabs and the likes.
  */
-void skip_space(char **str)
+static void
+skip_space (char **str)
 {
-  while ((isspace(**str) || (**str)=='\r') && (**str)!='\n')
+  while ((isspace (**str) || (**str) == '\r') && (**str) != '\n')
     {
       ++(*str);
     }
@@ -240,49 +255,50 @@ void skip_space(char **str)
  * Reads a string between ''. Double '' are interpreted as a single '
  * which is the standard SQL convention
  */
-int read_string(char *result,char **str,int size)
+static int
+read_string (char *result, char **str, int size)
 {
-  int i=0;
-  int done=0;
+  int i = 0;
+  int done = 0;
   char c;
 
-  skip_space(str);
+  skip_space (str);
 
-  c=**str;
-  if (c=='\'')
+  c = **str;
+  if (c == '\'')
     {
       ++(*str);
-      while ((c=**str)!='\0' && c!='\n' && !done)
+      while ((c = **str) != '\0' && c != '\n' && !done)
 	{
 	  ++(*str);
-	  if (c=='\'')
+	  if (c == '\'')
 	    {
-	      if ((**str)=='\'')
+	      if ((**str) == '\'')
 		{
 		  ++(*str);
-		  if (i<size-1)
+		  if (i < size - 1)
 		    {
-		      result[i++]='\'';
+		      result[i++] = '\'';
 		    }
 		}
 	      else
 		{
-		  done=1;
+		  done = 1;
 		}
 	    }
 	  else
 	    {
-	      if (i<size-1)
+	      if (i < size - 1)
 		{
-		  result[i++]=c;
+		  result[i++] = c;
 		}
 	    }
 	}
     }
 
-  result[i++]='\0';
+  result[i++] = '\0';
 
-  skip_space(str);
+  skip_space (str);
 
   return done;
 }
@@ -291,26 +307,27 @@ int read_string(char *result,char **str,int size)
 /*
  * Reads an integer
  */
-int read_int(int *result,char **str)
+static int
+read_int (int *result, char **str)
 {
-  int ok=0;
+  int ok = 0;
   char c;
 
-  (*result)=0;
+  (*result) = 0;
 
-  skip_space(str);
+  skip_space (str);
 
-  while (isdigit(c=(**str)))
+  while (isdigit (c = (**str)))
     {
       ++(*str);
 
-      (*result)*=10;
-      (*result)+=c-'0';
+      (*result) *= 10;
+      (*result) += c - '0';
 
-      ok=1;
+      ok = 1;
     }
 
-  skip_space(str);
+  skip_space (str);
 
   return ok;
 }
@@ -319,22 +336,23 @@ int read_int(int *result,char **str)
 /*
  * Reads a field separator
  */
-int read_separator(char **str)
+static int
+read_separator (char **str)
 {
-  int ok=0;
+  int ok = 0;
   char c;
 
-  skip_space(str);
+  skip_space (str);
 
-  c=**str;
+  c = **str;
 
-  if (c==',')
+  if (c == ',')
     {
       ++(*str);
-      ok=1;
+      ok = 1;
     }
 
-  skip_space(str);
+  skip_space (str);
 
   return ok;
 }
@@ -343,22 +361,49 @@ int read_separator(char **str)
 /*
  * Reads a new-line character
  */
-int read_eol(char **str)
+static int
+read_eol (char **str)
 {
-  int ok=0;
+  int ok = 0;
   char c;
 
-  skip_space(str);
+  skip_space (str);
 
-  c=**str;
+  c = **str;
 
-  if (c=='\n')
+  if (c == '\n')
     {
       ++(*str);
-      ok=1;
+      ok = 1;
     }
 
-  skip_space(str);
+  skip_space (str);
+
+  return ok;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * Reads "less than n chars", then a "\n"
+ */
+static int
+read_eol_n (char **str, int n)
+{
+  int ok = 0;
+  char *tmp;
+
+  skip_space (str);
+
+  tmp = strchr (*str, '\n');
+  if (tmp != NULL)
+    {
+      if (tmp - (*str) < n)
+	{
+	  ok = 1;
+	  (*str) = tmp + 1;
+	  skip_space (str);
+	}
+    }
 
   return ok;
 }
@@ -367,17 +412,18 @@ int read_eol(char **str)
 /*
  * Reads an end of line
  */
-void next_line(char **str)
+static void
+next_line (char **str)
 {
   char *pos;
   int len;
 
-  skip_space(str);
+  skip_space (str);
 
-  pos=strchr(*str,'\n');
+  pos = strchr (*str, '\n');
   if (pos)
     {
-      (*str)=pos+1;
+      (*str) = pos + 1;
     }
   else
     {
@@ -385,10 +431,9 @@ void next_line(char **str)
        * No '\n' found, we decided to go to the
        * very end of the string
        */
-      len=strlen(*str);
-      (*str)+=len;
+      len = strlen (*str);
+      (*str) += len;
     }
 
-  skip_space(str);
+  skip_space (str);
 }
-
