@@ -21,8 +21,8 @@
 /********************************************************************/
 
 /*****************************************************************************/
-/* Liquid War is a unique multiplayer wargame                                */
-/* Copyright (C) 1998-2002 Christian Mauduit                                 */
+/* Liquid War is a multiplayer wargame                                       */
+/* Copyright (C) 1998-2003 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -67,20 +67,22 @@
 
 typedef struct
 {
-  char label[LW_SOCK_IP_SIZE+1+33];
+  char label[LW_SOCK_IP_SIZE + 1 + 33];
   char ip[LW_SOCK_IP_SIZE];
   int port;
   int uptime;
   int busy_players;
   int max_players;
   int password;
-  char comment[COMMENT_SIZE+1];
-} LW_WWWCLI_DATA;
+  char comment[COMMENT_SIZE + 1];
+  int ping_delay;
+}
+LW_WWWCLI_DATA;
 
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
 
-int lw_wwwcli_get_games(LW_WWWCLI_DATA *buffer, int *size);
+int lw_wwwcli_get_games (LW_WWWCLI_DATA * buffer, int *size);
 
 #endif
